(function ( $ ) {
	'use strict';

	// This case is important when theme is not active
	if ( typeof qodef !== 'object' ) {
		window.qodef = {};
	}

	window.qodefCore                = {};
	qodefCore.shortcodes            = {};
	qodefCore.listShortcodesScripts = {
		qodefSwiper: qodef.qodefSwiper,
		qodefPagination: qodef.qodefPagination,
		qodefFilter: qodef.qodefFilter,
		qodefMasonryLayout: qodef.qodefMasonryLayout,
		qodefJustifiedGallery: qodef.qodefJustifiedGallery,
	};

	qodefCore.body         = $( 'body' );
	qodefCore.html         = $( 'html' );
	qodefCore.windowWidth  = $( window ).width();
	qodefCore.windowHeight = $( window ).height();
	qodefCore.scroll       = 0;

	$( document ).ready(
		function () {
			qodefCore.scroll = $( window ).scrollTop();
			qodefInlinePageStyle.init();
			qodefUncoverSection.init();
		}
	);

	$( window ).resize(
		function () {
			qodefCore.windowWidth  = $( window ).width();
			qodefCore.windowHeight = $( window ).height();
		}
	);

	$( window ).scroll(
		function () {
			qodefCore.scroll = $( window ).scrollTop();
		}
	);

	var qodefScroll = {
		disable: function () {
			if ( window.addEventListener ) {
				window.addEventListener(
					'wheel',
					qodefScroll.preventDefaultValue,
					{ passive: false }
				);
			}

			// window.onmousewheel = document.onmousewheel = qodefScroll.preventDefaultValue;
			document.onkeydown = qodefScroll.keyDown;
		},
		enable: function () {
			if ( window.removeEventListener ) {
				window.removeEventListener(
					'wheel',
					qodefScroll.preventDefaultValue,
					{ passive: false }
				);
			}
			window.onmousewheel = document.onmousewheel = document.onkeydown = null;
		},
		preventDefaultValue: function ( e ) {
			e = e || window.event;
			if ( e.preventDefault ) {
				e.preventDefault();
			}
			e.returnValue = false;
		},
		keyDown: function ( e ) {
			var keys = [37, 38, 39, 40];
			for ( var i = keys.length; i--; ) {
				if ( e.keyCode === keys[i] ) {
					qodefScroll.preventDefaultValue( e );
					return;
				}
			}
		}
	};

	qodefCore.qodefScroll = qodefScroll;

	var qodefScrollbarWidth = {
		getWidth: function () {
			return window.innerWidth - document.documentElement.clientWidth;
		},
	};

	qodefCore.qodefScrollbarWidth = qodefScrollbarWidth;

	var qodefPerfectScrollbar = {
		init: function ( $holder ) {
			if ( $holder.length ) {
				qodefPerfectScrollbar.qodefInitScroll( $holder );
			}
		},
		qodefInitScroll: function ( $holder ) {
			var $defaultParams = {
				wheelSpeed: 0.6,
				suppressScrollX: true
			};

			var $ps = new PerfectScrollbar(
				$holder[0],
				$defaultParams
			);

			$( window ).resize(
				function () {
					$ps.update();
				}
			);
		}
	};

	qodefCore.qodefPerfectScrollbar = qodefPerfectScrollbar;
	
	/*
	 *  Add uncovering section
	 */
	var qodefUncoverSection = {
		init: function () {
			this.holder = $('#qodef-custom-section--uncover');
			
			if (this.holder.length && !qodefCore.html.hasClass('touchevents') && qodef.windowWidth > 1024) {
				qodefUncoverSection.addClass(this.holder);
				qodefUncoverSection.setHeight(this.holder);
				
				$(window).resize(function () {
					qodefUncoverSection.setHeight(qodefUncoverSection.holder);
				});
			}
		},
		setHeight: function ($holder) {
			$holder.css('height', 'auto');
			
			var sectionHeight = $holder.outerHeight();
			
			if (sectionHeight > 0) {
				$('#qodef-page-content').css({ 'margin-bottom': sectionHeight });
				$holder.css('height', sectionHeight);
			}
			
			document.addEventListener('scroll', function () {
				var scrolledNearBottomOfPage = document.documentElement.scrollHeight - qodefCore.scroll - qodefCore.windowHeight < 100;
				
				if ( scrolledNearBottomOfPage ) {
					$holder.css('z-index', '2');
				} else {
					$holder.css('z-index', '0');
				}
				
			}, {
				passive: true
			});
		},
		addClass: function () {
			qodefCore.body.addClass('qodef-page-has-custom-section--uncover');
		},
	};
	
	qodefCore.qodefUncoverSection = qodefUncoverSection;

	var qodefInlinePageStyle = {
		init: function () {
			this.holder = $( '#micdrop-core-page-inline-style' );

			if ( this.holder.length ) {
				var style = this.holder.data( 'style' );

				if ( style.length ) {
					$( 'head' ).append( '<style type="text/css">' + style + '</style>' );
				}
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
	    function () {
            qodefBackToTop.init();
        }
	);

	var qodefBackToTop = {
		init: function () {
			this.holder = $( '#qodef-back-to-top' );

			if ( this.holder.length ) {
				// Scroll To Top
				this.holder.on(
					'click',
					function ( e ) {
						e.preventDefault();
						qodefBackToTop.animateScrollToTop();
					}
				);

				qodefBackToTop.showHideBackToTop();
			}
		},
		animateScrollToTop: function () {
			var startPos = qodef.scroll,
				newPos   = qodef.scroll,
				step     = .9,
				animationFrameId;

			var startAnimation = function () {
				if ( newPos === 0 ) {
					return;
				}

				newPos < 0.0001 ? newPos = 0 : null;

				var ease = qodefBackToTop.easingFunction( (startPos - newPos) / startPos );
				$( 'html, body' ).scrollTop( startPos - (startPos - newPos) * ease );
				newPos = newPos * step;

				animationFrameId = requestAnimationFrame( startAnimation );
			};
			startAnimation();
			$( window ).one(
				'wheel touchstart',
				function () {
					cancelAnimationFrame( animationFrameId );
				}
			);
		},
		easingFunction: function ( n ) {
			return 0 == n ? 0 : Math.pow( 1024, n - 1 );
		},
		showHideBackToTop: function () {
			$( window ).scroll(
				function () {
					var $thisItem = $( this ),
						b         = $thisItem.scrollTop(),
						c         = $thisItem.height(),
						d;

					if ( b > 0 ) {
						d = b + c / 2;
					} else {
						d = 1;
					}

					if ( d < 1e3 ) {
						qodefBackToTop.addClass( 'off' );
					} else {
						qodefBackToTop.addClass( 'on' );
					}
				}
			);
		},
		addClass: function ( a ) {
			this.holder.removeClass( 'qodef--off qodef--on' );

			if ( a === 'on' ) {
				this.holder.addClass( 'qodef--on' );
			} else {
				this.holder.addClass( 'qodef--off' );
			}
		}
	};

})( jQuery );

(function ($) {
	"use strict";

	$( window ).on(
		'load',
		function () {
			qodefBackgroundText.init();
		}
	);

	$( window ).resize(
		function () {
			qodefBackgroundText.init();
		}
	);

	var qodefBackgroundText = {
		init                    : function () {
			var $holder = $( '.qodef-background-text' );

			if ($holder.length) {
				$holder.each(
					function () {
						qodefBackgroundText.responsiveOutputHandler( $( this ) );
					}
				);
			}
		},
		responsiveOutputHandler : function ($holder) {
			var breakpoints = {
				3840: 1441,
				1440: 1367,
				1366: 1025,
				1024: 1
			};

			$.each(
				breakpoints,
				function (max, min) {
					if (qodef.windowWidth <= max && qodef.windowWidth >= min) {
						qodefBackgroundText.generateResponsiveOutput( $holder, max );
					}
				}
			);
		},
		generateResponsiveOutput: function ($holder, width) {
			var $textHolder = $holder.find( '.qodef-m-background-text' );

			if ($textHolder.length) {
				$textHolder.css(
					{
						'font-size': $textHolder.data( 'size-' + width ) + 'px',
						'top'      : $textHolder.data( 'vertical-offset-' + width ) + 'px',
					}
				);
			}
		},
	};

	window.qodefBackgroundText = qodefBackgroundText;
})( jQuery );

(function ( $ ) {
	'use strict';

	$( window ).on(
		'load',
		function () {
			fadeBgOnScroll.init();
		}
	);

	var fadeBgOnScroll = {
		section: '',
		docYScroll: 0,
		scrollAmount: 650,
		scrollAmountTouch: 300,
		init: function () {
			var displayAmount = fadeBgOnScroll.displayAmount();

			// Set variables
			fadeBgOnScroll.section 	  = $( '.qodef-fade-bg-on-scroll' );
			fadeBgOnScroll.docYScroll = $( document ).scrollTop();

			// Set background visibility
			fadeBgOnScroll.setVisibility( displayAmount );

			$( window ).scroll(
				function () {
					fadeBgOnScroll.setVisibility( displayAmount );
				}
			);
		},
		displayAmount: function () {
			if ( qodef.windowWidth > 1024 ) {
				return parseInt(
					fadeBgOnScroll.scrollAmount,
					10
				);
			} else {
				return parseInt(
					fadeBgOnScroll.scrollAmountTouch,
					10
				);
			}
		},
		setVisibility: function ( displayAmount ) {
			var isShown = qodefCore.scroll < displayAmount;

			fadeBgOnScroll.showHideHeader( isShown );
		},
		showHideHeader: function ( isShown ) {
			if ( isShown ) {
				fadeBgOnScroll.section.removeClass( 'qodef-fade-bg' );
			} else {
				fadeBgOnScroll.section.addClass( 'qodef-fade-bg' );
			}
		},
	};

	qodefCore.fadeBgOnScroll = fadeBgOnScroll.init;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( window ).on(
		'load',
		function () {
			qodefUncoverFooter.init();
		}
	);

	var qodefUncoverFooter = {
		holder: '',
		init: function () {
			this.holder = $( '#qodef-page-footer.qodef--uncover' );

			if ( this.holder.length && ! qodefCore.html.hasClass( 'touchevents' ) ) {
				qodefUncoverFooter.addClass();
				qodefUncoverFooter.setHeight( this.holder );

				$( window ).resize(
					function () {
						qodefUncoverFooter.setHeight( qodefUncoverFooter.holder );
					}
				);
			}
		},
		setHeight: function ( $holder ) {
			$holder.css( 'height', 'auto' );

			var footerHeight = $holder.outerHeight();

			if ( footerHeight > 0 ) {
				$( '#qodef-page-outer' ).css(
					{
						'margin-bottom': footerHeight,
						'background-color': qodefCore.body.css( 'backgroundColor' )
					}
				);

				$holder.css( 'height', footerHeight );
			}
		},
		addClass: function () {
			qodefCore.body.addClass( 'qodef-page-footer--uncover' );
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefFullscreenMenu.init();
		}
	);

	var qodefFullscreenMenu = {
		init: function () {
			var $fullscreenMenuOpener = $( 'a.qodef-fullscreen-menu-opener' ),
				$menuItems            = $( '#qodef-fullscreen-area nav ul li a' );

			// Open popup menu
			$fullscreenMenuOpener.on(
				'click',
				function ( e ) {
					e.preventDefault();
					var $thisOpener = $( this );

					if ( ! qodefCore.body.hasClass( 'qodef-fullscreen-menu--opened' ) ) {
						qodefFullscreenMenu.openFullscreen( $thisOpener );

						$( document ).keyup(
							function ( e ) {
								if ( e.keyCode === 27 ) {
									qodefFullscreenMenu.closeFullscreen( $thisOpener );
								}
							}
						);
					} else {
						qodefFullscreenMenu.closeFullscreen( $thisOpener );
					}
				}
			);

			//open dropdowns
			$menuItems.on(
				'tap click',
				function ( e ) {
					var $thisItem = $( this );

					if ( $thisItem.parent().hasClass( 'menu-item-has-children' ) ) {
						e.preventDefault();
						qodefFullscreenMenu.clickItemWithChild( $thisItem );
					} else if ( $thisItem.attr( 'href' ) !== 'http://#' && $thisItem.attr( 'href' ) !== '#' ) {
						qodefFullscreenMenu.closeFullscreen( $fullscreenMenuOpener );
					}
				}
			);
		},
		openFullscreen: function ( $opener ) {
			$opener.addClass( 'qodef--opened' );
			qodefCore.body.removeClass( 'qodef-fullscreen-menu-animate--out' ).addClass( 'qodef-fullscreen-menu--opened qodef-fullscreen-menu-animate--in' );
			qodefCore.qodefScroll.disable();
		},
		closeFullscreen: function ( $opener ) {
			$opener.removeClass( 'qodef--opened' );
			qodefCore.body.removeClass( 'qodef-fullscreen-menu--opened qodef-fullscreen-menu-animate--in' ).addClass( 'qodef-fullscreen-menu-animate--out' );
			qodefCore.qodefScroll.enable();
			$( 'nav.qodef-fullscreen-menu ul.sub_menu' ).slideUp( 200 );
		},
		clickItemWithChild: function ( thisItem ) {
			var $thisItemParent  = thisItem.parent(),
				$thisItemSubMenu = $thisItemParent.find( '.sub-menu' ).first();

			var currentlyOpenItem =  $( '.qodef-fullscreen-menu ul li.qodef--opened' );
			currentlyOpenItem.removeClass( 'qodef--opened' );

			if ( $thisItemSubMenu.is( ':visible' ) ) {
				$thisItemSubMenu.slideUp( 300 );
				$thisItemParent.removeClass( 'qodef--opened' );
			} else {
				$thisItemSubMenu.slideDown( 300 );
				$thisItemParent.addClass( 'qodef--opened' ).siblings().find( '.sub-menu' ).slideUp( 400 );
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefHeaderScrollAppearance.init();
		}
	);

	var qodefHeaderScrollAppearance = {
		appearanceType: function () {
			return qodefCore.body.attr( 'class' ).indexOf( 'qodef-header-appearance--' ) !== -1 ? qodefCore.body.attr( 'class' ).match( /qodef-header-appearance--([\w]+)/ )[1] : '';
		},
		init: function () {
			var appearanceType = this.appearanceType();

			if ( appearanceType !== '' && appearanceType !== 'none' ) {
				qodefCore[appearanceType + 'HeaderAppearance']();
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
	    function () {
            qodefMobileHeaderAppearance.init();
        }
	);

	/*
	 **	Init mobile header functionality
	 */
	var qodefMobileHeaderAppearance = {
		init: function () {
			if ( qodefCore.body.hasClass( 'qodef-mobile-header-appearance--sticky' ) ) {

				var docYScroll1   = qodefCore.scroll,
					displayAmount = qodefGlobal.vars.mobileHeaderHeight + qodefGlobal.vars.adminBarHeight,
					$pageOuter    = $( '#qodef-page-outer' );

				qodefMobileHeaderAppearance.showHideMobileHeader( docYScroll1, displayAmount, $pageOuter );

				$( window ).scroll(
				    function () {
                        qodefMobileHeaderAppearance.showHideMobileHeader( docYScroll1, displayAmount, $pageOuter );
                        docYScroll1 = qodefCore.scroll;
                    }
				);

				$( window ).resize(
				    function () {
                        $pageOuter.css( 'padding-top', 0 );
                        qodefMobileHeaderAppearance.showHideMobileHeader( docYScroll1, displayAmount, $pageOuter );
                    }
				);
			}
		},
		showHideMobileHeader: function ( docYScroll1, displayAmount, $pageOuter ) {
			if ( qodefCore.windowWidth <= 1024 ) {
				if ( qodefCore.scroll > displayAmount * 2 ) {
					//set header to be fixed
					qodefCore.body.addClass( 'qodef-mobile-header--sticky' );

					//add transition to it
					setTimeout(
						function () {
							qodefCore.body.addClass( 'qodef-mobile-header--sticky-animation' );
						},
						300
					); //300 is duration of sticky header animation

					//add padding to content so there is no 'jumping'
					$pageOuter.css( 'padding-top', qodefGlobal.vars.mobileHeaderHeight );
				} else {
					//unset fixed header
					qodefCore.body.removeClass( 'qodef-mobile-header--sticky' );

					//remove transition
					setTimeout(
						function () {
							qodefCore.body.removeClass( 'qodef-mobile-header--sticky-animation' );
						},
						300
					); //300 is duration of sticky header animation

					//remove padding from content since header is not fixed anymore
					$pageOuter.css( 'padding-top', 0 );
				}

				if ( (qodefCore.scroll > docYScroll1 && qodefCore.scroll > displayAmount) || (qodefCore.scroll < displayAmount * 3) ) {
					//show sticky header
					qodefCore.body.removeClass( 'qodef-mobile-header--sticky-display' );
				} else {
					//hide sticky header
					qodefCore.body.addClass( 'qodef-mobile-header--sticky-display' );
				}
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
		}
	);

	$( window ).on(
		'load',
		function () {
			qodefNavMenu.init();
		}
	);

	var qodefNavMenu = {
		init: function () {
			qodefNavMenu.dropdownBehavior();
			qodefNavMenu.wideDropdownPosition();
			qodefNavMenu.dropdownPosition();
		},
		dropdownBehavior: function () {
			var $menuItems = $( '.qodef-header-navigation > ul > li' );

			$menuItems.each(
				function () {
					var $thisItem = $( this );

					if ( $thisItem.find( '.qodef-drop-down-second' ).length ) {
						$thisItem.waitForImages(
							function () {
								var $dropdownHolder      = $thisItem.find( '.qodef-drop-down-second' ),
									$dropdownMenuItem    = $dropdownHolder.find( '.qodef-drop-down-second-inner ul' ),
									dropDownHolderHeight = $dropdownMenuItem.outerHeight();

								if ( navigator.userAgent.match( /(iPod|iPhone|iPad)/ ) ) {
									$thisItem.on(
										'touchstart mouseenter',
										function () {
											$dropdownHolder.css(
												{
													'height': dropDownHolderHeight,
													'overflow': 'visible',
													'visibility': 'visible',
													'opacity': '1',
												}
											);
										}
									).on(
										'mouseleave',
										function () {
											$dropdownHolder.css(
												{
													'height': '0px',
													'overflow': 'hidden',
													'visibility': 'hidden',
													'opacity': '0',
												}
											);
										}
									);
								} else {
									if ( qodefCore.body.hasClass( 'qodef-drop-down-second--animate-height' ) ) {
										var animateConfig = {
											interval: 0,
											over: function () {
												setTimeout(
													function () {
														$dropdownHolder.addClass( 'qodef-drop-down--start' ).css(
															{
																'visibility': 'visible',
																'height': '0',
																'opacity': '1',
															}
														);
														$dropdownHolder.stop().animate(
															{
																'height': dropDownHolderHeight,
															},
															400,
															'linear',
															function () {
																$dropdownHolder.css( 'overflow', 'visible' );
															}
														);
													},
													100
												);
											},
											timeout: 100,
											out: function () {
												$dropdownHolder.stop().animate(
													{
														'height': '0',
														'opacity': 0,
													},
													100,
													function () {
														$dropdownHolder.css(
															{
																'overflow': 'hidden',
																'visibility': 'hidden',
															}
														);
													}
												);

												$dropdownHolder.removeClass( 'qodef-drop-down--start' );
											}
										};

										$thisItem.hoverIntent( animateConfig );
									} else {
										var config = {
											interval: 0,
											over: function () {
												setTimeout(
													function () {
														$dropdownHolder.addClass( 'qodef-drop-down--start' ).stop().css( { 'height': dropDownHolderHeight } );
													},
													150
												);
											},
											timeout: 150,
											out: function () {
												$dropdownHolder.stop().css( { 'height': '0' } ).removeClass( 'qodef-drop-down--start' );
											}
										};

										$thisItem.hoverIntent( config );
									}
								}
							}
						);
					}
				}
			);
		},
		wideDropdownPosition: function () {
			var $menuItems = $( '.qodef-header-navigation > ul > li.qodef-menu-item--wide' );

			if ( $menuItems.length ) {
				$menuItems.each(
					function () {
						var $menuItem        = $( this );
						var $menuItemSubMenu = $menuItem.find( '.qodef-drop-down-second' );

						if ( $menuItemSubMenu.length ) {
							$menuItemSubMenu.css( 'left', 0 );

							var leftPosition = $menuItemSubMenu.offset().left;

							/*if ( qodefCore.body.hasClass( 'qodef--boxed' ) ) {
								//boxed layout case
								var boxedWidth = $( '.qodef--boxed #qodef-page-wrapper' ).outerWidth();
								leftPosition   = leftPosition - (qodefCore.windowWidth - boxedWidth) / 2;
								$menuItemSubMenu.css( { 'left': -leftPosition, 'width': boxedWidth } );

							} else */
							if ( qodefCore.body.hasClass( 'qodef-drop-down-second--full-width' ) ) {
								//wide dropdown full width case
								var scrollBarAddition = 0;

								if ( 0 === qodefCore.qodefScrollbarWidth.getWidth() ) {
									scrollBarAddition = 17; // adds scroll bar width when there is no scroll bar on the page
								}
								$menuItemSubMenu.css( { 'left': -leftPosition, 'width': qodefCore.windowWidth + scrollBarAddition } );
							} else {
								//wide dropdown in grid case
								$menuItemSubMenu.css( { 'left': -leftPosition + (qodefCore.windowWidth - $menuItemSubMenu.width()) / 2 } );
							}
						}
					}
				);
			}
		},
		dropdownPosition: function () {
			var $menuItems = $( '.qodef-header-navigation > ul > li.qodef-menu-item--narrow.menu-item-has-children' );

			if ( $menuItems.length ) {
				$menuItems.each(
					function () {
						var $thisItem         = $( this ),
							menuItemPosition  = $thisItem.offset().left,
							$dropdownHolder   = $thisItem.find( '.qodef-drop-down-second' ),
							$dropdownMenuItem = $dropdownHolder.find( '.qodef-drop-down-second-inner ul' ),
							dropdownMenuWidth = $dropdownMenuItem.outerWidth(),
							menuItemFromLeft  = $( window ).width() - menuItemPosition;

						if ( qodef.body.hasClass( 'qodef--boxed' ) ) {
							//boxed layout case
							var boxedWidth   = $( '.qodef--boxed #qodef-page-wrapper' ).outerWidth();
							menuItemFromLeft = boxedWidth - menuItemPosition;
						}

						var dropDownMenuFromLeft;

						if ( $thisItem.find( 'li.menu-item-has-children' ).length > 0 ) {
							dropDownMenuFromLeft = menuItemFromLeft - dropdownMenuWidth;
						}

						$dropdownHolder.removeClass( 'qodef-drop-down--right' );
						$dropdownMenuItem.removeClass( 'qodef-drop-down--right' );
						if ( menuItemFromLeft < dropdownMenuWidth || dropDownMenuFromLeft < dropdownMenuWidth ) {
							$dropdownHolder.addClass( 'qodef-drop-down--right' );
							$dropdownMenuItem.addClass( 'qodef-drop-down--right' );
						}
					}
				);
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( window ).on(
		'load',
		function () {
			qodefParallaxBackground.init();
		}
	);

	/**
	 * Init global parallax background functionality
	 */
	var qodefParallaxBackground = {
		init: function ( settings ) {
			this.$sections = $( '.qodef-parallax' );

			// Allow overriding the default config
			$.extend( this.$sections, settings );

			var isSupported = ! qodefCore.html.hasClass( 'touchevents' ) && ! qodefCore.body.hasClass( 'qodef-browser--edge' ) && ! qodefCore.body.hasClass( 'qodef-browser--ms-explorer' );

			if ( this.$sections.length && isSupported ) {
				this.$sections.each(
					function () {
						qodefParallaxBackground.ready( $( this ) );
					}
				);
			}
		},
		ready: function ( $section ) {
			$section.$imgHolder  = $section.find( '.qodef-parallax-img-holder' );
			$section.$imgWrapper = $section.find( '.qodef-parallax-img-wrapper' );
			$section.$img        = $section.find( 'img.qodef-parallax-img' );

			var h           = $section.height(),
				imgWrapperH = $section.$imgWrapper.height();

			$section.movement = 100 * (imgWrapperH - h) / h / 2; //percentage (divided by 2 due to absolute img centering in CSS)

			$section.buffer       = window.pageYOffset;
			$section.scrollBuffer = null;


			//calc and init loop
			requestAnimationFrame(
				function () {
					$section.$imgHolder.animate( { opacity: 1 }, 100 );
					qodefParallaxBackground.calc( $section );
					qodefParallaxBackground.loop( $section );
				}
			);

			//recalc
			$( window ).on(
				'resize',
				function () {
					qodefParallaxBackground.calc( $section );
				}
			);
		},
		calc: function ( $section ) {
			var wH = $section.$imgWrapper.height(),
				wW = $section.$imgWrapper.width();

			if ( $section.$img.width() < wW ) {
				$section.$img.css(
					{
						'width': '100%',
						'height': 'auto',
					}
				);
			}

			if ( $section.$img.height() < wH ) {
				$section.$img.css(
					{
						'height': '100%',
						'width': 'auto',
						'max-width': 'unset',
					}
				);
			}
		},
		loop: function ( $section ) {
			if ( $section.scrollBuffer === Math.round( window.pageYOffset ) ) {
				requestAnimationFrame(
					function () {
						qodefParallaxBackground.loop( $section );
					}
				); //repeat loop

				return false; //same scroll value, do nothing
			} else {
				$section.scrollBuffer = Math.round( window.pageYOffset );
			}

			var wH   = window.outerHeight,
				sTop = $section.offset().top,
				sH   = $section.height();

			if ( $section.scrollBuffer + wH * 1.2 > sTop && $section.scrollBuffer < sTop + sH ) {
				var delta = (Math.abs( $section.scrollBuffer + wH - sTop ) / (wH + sH)).toFixed( 4 ), //coeff between 0 and 1 based on scroll amount
					yVal  = (delta * $section.movement).toFixed( 4 );

				if ( $section.buffer !== delta ) {
					$section.$imgWrapper.css( 'transform', 'translate3d(0,' + yVal + '%, 0)' );
				}

				$section.buffer = delta;
			}

			requestAnimationFrame(
				function () {
					qodefParallaxBackground.loop( $section );
				}
			); //repeat loop
		}
	};

	qodefCore.qodefParallaxBackground = qodefParallaxBackground;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( window ).on(
		'load',
		function () {
			qodefParticles.init();
		}
	);

	/**
	 * Init global parallax background functionality
	 */
	var qodefParticles = {
		init: function () {
			var particlesHolder = $('.qodef-particles-background');

			if ( particlesHolder.length ) {
				particlesHolder.each(function () {
					var thisParticles = $(this);
					
					qodefParticles.init_particles( thisParticles );
				});
			}
		},
		random_id: function() {
			var string_length = 10;
			var random_string = '';
			var random_ascii;
			for(var i = 0; i < string_length; i++) {
				random_ascii = Math.floor((Math.random() * 25) + 97);
				random_string += String.fromCharCode(random_ascii)
			}

			return random_string
		},
		init_particles: function ($holder) {
			var particlesInner = $holder.find('.qodef-p-particles-container');

			particlesInner.attr('id', 'qodef-' + qodefParticles.random_id());

			var particlesOptions = {
				particles_color: typeof particlesInner.attr('data-particles-color') !== 'undefined' && particlesInner.attr('data-particles-color') ? particlesInner.attr('data-particles-color') : '#d48063',
			};

			/* particles init */
			particlesJS(
				particlesInner.attr('id'),
				{
					"particles": {
						"number": {
							"value": 80,
							"density": {
								"enable": false,
								"value_area": 800
							}
						},
						"color": {
							"value": particlesOptions.particles_color
						},
						"shape": {
							"type": "circle",
							"stroke": {
								"width": 0,
								"color": "#ffffff"
							},
							"polygon": {
								"nb_sides": 5
							},
							"image": {
								"src": "img/github.svg",
								"width": 100,
								"height": 100
							}
						},
						"opacity": {
							"value": 1,
							"random": false,
							"anim": {
								"enable": false,
								"speed": 1,
								"opacity_min": 0.1,
								"sync": false
							}
						},
						"size": {
							"value": 3,
							"random": true,
							"anim": {
								"enable": false,
								"speed": 120,
								"size_min": 2,
								"sync": false
							}
						},
						"line_linked": {
							"enable": true,
							"distance": 100,
							"color": particlesOptions.particles_color,
							"opacity": 0.6,
							"width": 2
						},
						"move": {
							"enable": true,
							"speed": 2,
							"direction": "none",
							"random": false,
							"straight": false,
							"out_mode": "out",
							"bounce": false,
							"attract": {
								"enable": false,
								"rotateX": 600,
								"rotateY": 1200
							}
						}
					},
					"interactivity": {
						"detect_on": "canvas",
						"events": {
							"onhover": {
								"enable": false,
								"mode": "grab"
							},
							"onclick": {
								"enable": false,
								"mode": "push"
							},
							"resize": true
						},
						"modes": {
							"grab": {
								"distance": 100 * 2,
								"line_linked": {
									"opacity": 0.7
								}
							},
							"bubble": {
								"distance": 800,
								"size": 80,
								"duration": 2,
								"opacity": 0.8,
								"speed": 3
							},
							"repulse": {
								"distance": 400,
								"duration": 0.4
							},
							"push": {
								"particles_nb": 4
							},
							"remove": {
								"particles_nb": 2
							}
						}
					},
					"retina_detect": true
				}
			);
		}
	};

	qodefCore.qodefParticles = qodefParticles;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefSideArea.init();
		}
	);

	var qodefSideArea = {
		init: function () {
			var $sideAreaOpener = $( 'a.qodef-side-area-opener' ),
				$sideAreaClose  = $( '.qodef-side-area-close' ),
				$sideArea       = $( '#qodef-side-area' );

			qodefSideArea.openerHoverColor( $sideAreaOpener );
			
			if ( $('.qodef-side-area-cover').length === 0 ){
				$( '#qodef-page-wrapper' ).prepend( '<div class="qodef-side-area-cover"/>' );
				$('.qodef-side-area-cover').prepend($sideAreaClose);
			}

			// Open Side Area
			$sideAreaOpener.on(
				'click',
				function ( e ) {
					e.preventDefault();

					if ( ! qodefCore.body.hasClass( 'qodef-side-area--opened' ) ) {
						qodefSideArea.openSideArea();

						$( document ).keyup(
							function ( e ) {
								if ( e.keyCode === 27 ) {
									qodefSideArea.closeSideArea();
								}
							}
						);
					} else {
						qodefSideArea.closeSideArea();
					}
				}
			);

			$sideAreaClose.on(
				'click',
				function ( e ) {
					e.preventDefault();
					qodefSideArea.closeSideArea();
				}
			);

			if ( $sideArea.length && typeof qodefCore.qodefPerfectScrollbar === 'object' ) {
				qodefCore.qodefPerfectScrollbar.init( $sideArea );
			}
		},
		openSideArea: function () {
			var currentScroll 	  = $( window ).scrollTop();
			
			qodefCore.body.removeClass( 'qodef-side-area-animate--out' ).addClass( 'qodef-side-area--opened qodef-side-area-animate--in' );
			
			$( '.qodef-side-area-cover' ).on(
				'click',
				function ( e ) {
					e.preventDefault();
					qodefSideArea.closeSideArea();
				}
			);

			// mouse move
			$( window ).mousemove(
				function ( e ) {
					$( '.qodef-side-area-cover .qodef-side-area-close' ).css( { left: e.clientX, top: e.clientY } );
				}
			);

			$(' #qodef-page-wrapper ').find( '.qodef-side-area-cover' ).mouseenter(
				function ( e ) {
					$( '.qodef-side-area-cover .qodef-side-area-close' ).css(
						'opacity',
						'1'
					);
				}
			)
			.mouseleave(
				function ( e ) {
					$( '.qodef-side-area-cover .qodef-side-area-close' ).css(
						'opacity',
						'0'
					);
				}
			);

			$( window ).scroll(
				function () {
					if ( Math.abs( qodefCore.scroll - currentScroll ) > 400 ) {
						qodefSideArea.closeSideArea();
					}
				}
			);
		},
		closeSideArea: function () {
			qodefCore.body.removeClass( 'qodef-side-area--opened qodef-side-area-animate--in' ).addClass( 'qodef-side-area-animate--out' );
		},
		openerHoverColor: function ( $opener ) {
			if ( typeof $opener.data( 'hover-color' ) !== 'undefined' ) {
				var hoverColor    = $opener.data( 'hover-color' );
				var originalColor = $opener.css( 'color' );

				$opener.on(
					'mouseenter',
					function () {
						$opener.css( 'color', hoverColor );
					}
				).on(
					'mouseleave',
					function () {
						$opener.css( 'color', originalColor );
					}
				);
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';
	
	$( document ).ready(
		function () {
			qodefSpinner.init();
		}
	);
	
	$( window ).on(
		'load',
		function () {
			qodefSpinner.windowLoaded = true;
			
			if (document.visibilityState === 'visible') {
				qodefSpinner.fadeOutLoader();
			} else {
				if ( $('#qodef-page-spinner.qodef-layout--textual').length ) {
					$('#qodef-page-spinner.qodef-layout--textual').addClass('qodef--animation-paused');
				}
				
				document.addEventListener("visibilitychange", function() {
					if (document.visibilityState === 'visible') {
						if ( $('#qodef-page-spinner.qodef-layout--textual').length ){
							$('#qodef-page-spinner.qodef-layout--textual').removeClass('qodef--animation-paused');
							qodefSpinner.animateSpinner();
						} else {
							qodefSpinner.fadeOutLoader();
						}
					}
				});
			}
		}
	);
	
	$( window ).on(
		'elementor/frontend/init',
		function () {
			var isEditMode = Boolean( elementorFrontend.isEditMode() );
			
			if ( isEditMode ) {
				qodefSpinner.init( isEditMode );
			}
		}
	);
	
	var qodefSpinner = {
		holder: '',
		windowLoaded: false,
		init: function ( isEditMode ) {
			this.holder = $( '#qodef-page-spinner:not(.qodef--custom-spinner)' );
			
			if ( this.holder.length ) {
				qodefSpinner.animateSpinner( isEditMode );
			}
		},
		animateSpinner: function ( isEditMode ) {
			if ( isEditMode ) {
				qodefSpinner.fadeOutLoader();
			} else if ( this.holder.hasClass('qodef-layout--textual') ){
				var line = this.holder.find('.qodef-e-line'),
					text1 = this.holder.find('.qodef-e-text-1'),
					text2 = this.holder.find('.qodef-e-text-2'),
					text3 = this.holder.find('.qodef-e-text-3'),
					textHolder = this.holder.find('.qodef-m-textual'),
					
				    docStyle = getComputedStyle(document.documentElement),
					spinnerElement = document.querySelector('#qodef-page-spinner .qodef-m-inner'),
					spinnerStyle = getComputedStyle(spinnerElement),
					spinnerColor = spinnerStyle.color,
					
					textColorInitial = spinnerColor,
					textColorAnimated = docStyle.getPropertyValue("--qode-secondary-color");
				
				var tl = gsap.timeline({
					paused: true,
					onUpdate: ()=> {
						if (this.holder.hasClass('qodef--animation-paused')){
							tl.pause();
						}
					}
				})
				
				tl
					.addLabel("lineAppeared", ">")
					.fromTo(line ,{
						xPercent: -101,
						opacity: 1,
					},{
						duration: .7,
						delay: .3,
						xPercent: 0,
						ease: 'power3.out',
						onComplete: () => {
							gsap.to( text1 , {
								opacity: 0,
								clearProps: "color",
								duration: 0
							});
							gsap.set( text2 , {
								opacity: 1,
								color: textColorAnimated,
							});
						}
					})
					.to(text1, {
						color: textColorAnimated,
						duration: .4,
					},'<')
					.to(line , {
						duration: .7,
						xPercent: 101,
						ease: 'power3.inOut',
					})
					.to(text2, {
						color: textColorInitial,
						duration: .4,
					},'>-0.2')
					.fromTo(line ,{
						xPercent: -101,
					},{
						duration: .7,
						xPercent: 0,
						delay: .2,
						ease: 'power3.out',
						onComplete: () => {
							gsap.to( text2 , {
								opacity: 0,
								clearProps: "color",
								duration: 0
							});
							gsap.set( text3 , {
								opacity: 1,
								color: textColorAnimated,
							});
						}
					})
					.to(line , {
						duration: .9,
						xPercent: 101,
						ease: 'power3.inOut',
					})
					.to(text3, {
						color: textColorInitial,
						duration: .4,
						onComplete: () => {
							if (qodefSpinner.windowLoaded) {
								this.holder.removeClass('qodef--textual-spinner-animating');
								qodefSpinner.fadeOutLoader();
								tl.pause();
							}
						},
					},'>-0.2')
					.fromTo(line ,{
						xPercent: -101,
					},{
						duration: .7,
						delay: .2,
						xPercent: 0,
						ease: 'power3.out',
						onComplete: () => {
							gsap.to( text3 , {
								opacity: 0,
								clearProps: "color",
								duration: 0
							});
							gsap.set( text1 , {
								opacity: 1,
								color: textColorAnimated,
							});
						}
					})
					.to(line , {
						duration: .9,
						xPercent: 101,
						ease: 'power3.inOut',
					})
					.to(text1, {
						color: textColorInitial,
						duration: .4,
						onComplete: () => {
							tl.play("lineAppeared");
						},
					},'>-0.2')
				
				
				gsap.to(textHolder,{
					opacity: 1,
					duration: .7,
					onStart: () =>{
						this.holder.addClass('qodef--textual-spinner-animating');
					},
					onComplete: () => {
						tl.play();
					},
				})
			}
		},
		fadeOutLoader: function ( speed, delay, easing ) {
			speed  = speed ? speed : 1000;
			delay  = delay? delay : 100;
			easing = easing ? easing : 'swing';
			
			var $holder = qodefSpinner.holder.length ? qodefSpinner.holder : $( '#qodef-page-spinner:not(.qodef--custom-spinner)' ),
				mainRevHolder = $('#qodef-main-rev-holder');
			
			
			if (!$holder.hasClass('qodef--textual-spinner-animating')){
				$holder.delay( delay ).fadeOut( speed, easing );
				
				if(mainRevHolder.length){
					setTimeout(function(){
						mainRevHolder.find('rs-module').revstart();
					}, delay + 300);
				}
				
				$( window ).on(
					'bind',
					'pageshow',
					function ( event ) {
						if ( event.originalEvent.persisted ) {
							$holder.fadeOut( speed, easing );
						}
					}
				);
			}
		}
	};
	
})( jQuery );
(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_accordion = {};

	$( document ).ready(
		function () {
			qodefAccordion.init();
		}
	);

	var qodefAccordion = {
		init: function () {
			var $holder = $( '.qodef-accordion' );

			if ( $holder.length ) {
				$holder.each(
					function () {
						qodefAccordion.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			if ( $currentItem.hasClass( 'qodef-behavior--accordion' ) ) {
				qodefAccordion.initAccordion( $currentItem );
			}

			if ( $currentItem.hasClass( 'qodef-behavior--toggle' ) ) {
				qodefAccordion.initToggle( $currentItem );
			}

			$currentItem.addClass( 'qodef--init' );
		},
		initAccordion: function ( $accordion ) {
			$accordion.accordion(
				{
					animate: 'swing',
					collapsible: true,
					active: 0,
					icons: '',
					heightStyle: 'content',
				}
			);
		},
		initToggle: function ( $toggle ) {
			var $toggleAccordionTitle = $toggle.find( '.qodef-accordion-title' );

			$toggleAccordionTitle.off().on(
				'mouseenter',
				function () {
					$( this ).addClass( 'ui-state-hover' );
				}
			).on(
				'mouseleave',
				function () {
					$( this ).removeClass( 'ui-state-hover' );
				}
			).on(
				'click',
				function () {
					var $thisTitle = $( this );

					if ( $thisTitle.hasClass( 'ui-state-active' ) ) {
						$thisTitle.removeClass( 'ui-state-active' );
						$thisTitle.next().removeClass( 'ui-accordion-content-active' ).slideUp( 300 );
					} else {
						$thisTitle.addClass( 'ui-state-active' );
						$thisTitle.next().addClass( 'ui-accordion-content-active' ).slideDown( 400 );
					}
				}
			);
		}
	};

	qodefCore.shortcodes.micdrop_core_accordion.qodefAccordion = qodefAccordion;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefAuthorListPagination.init();
		}
	);

	$( window ).scroll(
		function () {
			qodefAuthorListPagination.scroll();
		}
	);

	$( document ).on(
		'micdrop_core_trigger_author_load_more',
		function ( e, $holder, nextPage ) {
			qodefAuthorListPagination.triggerLoadMore( $holder, nextPage );
		}
	);

	/*
	 **	Init pagination functionality
	 */
	var qodefAuthorListPagination = {
		init: function ( settings ) {
			this.holder = $( '.qodef-author-pagination--on' );

			// Allow overriding the default config
			$.extend( this.holder, settings );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $holder = $( this );

						qodefAuthorListPagination.initPaginationType( $holder );
					}
				);
			}
		},
		scroll: function ( settings ) {
			this.holder = $( '.qodef-author-pagination--on' );

			// Allow overriding the default config
			$.extend( this.holder, settings );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $holder = $( this );

						if ( $holder.hasClass( 'qodef-pagination-type--infinite-scroll' ) ) {
							qodefAuthorListPagination.initInfiniteScroll( $holder );
						}
					}
				);
			}
		},
		initPaginationType: function ( $holder ) {
			if ( $holder.hasClass( 'qodef-pagination-type--standard' ) ) {
				qodefAuthorListPagination.initStandard( $holder );
			} else if ( $holder.hasClass( 'qodef-pagination-type--load-more' ) ) {
				qodefAuthorListPagination.initLoadMore( $holder );
			} else if ( $holder.hasClass( 'qodef-pagination-type--infinite-scroll' ) ) {
				qodefAuthorListPagination.initInfiniteScroll( $holder );
			}
		},
		initStandard: function ( $holder ) {
			var $paginationItems = $holder.find( '.qodef-m-pagination-items' );

			if ( $paginationItems.length ) {
				var options = $holder.data( 'options' );

				$paginationItems.children().each( function () {
					var $thisItem = $( this ),
						$itemLink = $thisItem.children( 'a' );

					qodefAuthorListPagination.changeStandardState( $holder, options.max_num_pages, 1 );

					$itemLink.on(
						'click',
						function ( e ) {
							e.preventDefault();

							if ( ! $thisItem.hasClass( 'qodef--active' ) ) {
								qodefAuthorListPagination.getNewPosts( $holder, $itemLink.data( 'paged' ) );
							}
						}
					);
				} );
			}
		},
		changeStandardState: function ( $holder, max_num_pages, nextPage ) {
			if ( $holder.hasClass( 'qodef-pagination-type--standard' ) ) {
				var $paginationNav = $holder.find( '.qodef-m-pagination-items' ),
					$numericItem   = $paginationNav.children( '.qodef--number' ),
					$prevItem      = $paginationNav.children( '.qodef--prev' ),
					$nextItem      = $paginationNav.children( '.qodef--next' );

				$numericItem.removeClass( 'qodef--active' ).eq( nextPage - 1 ).addClass( 'qodef--active' );

				$prevItem.children().data( 'paged', nextPage - 1 );

				if ( nextPage > 1 ) {
					$prevItem.show();
				} else {
					$prevItem.hide();
				}

				$nextItem.children().data( 'paged', nextPage + 1 );

				if ( nextPage === max_num_pages ) {
					$nextItem.hide();
				} else {
					$nextItem.show();
				}
			}
		},
		initLoadMore: function ( $holder ) {
			var $loadMoreButton = $holder.find( '.qodef-load-more-button' );

			$loadMoreButton.on(
				'click',
				function ( e ) {
					e.preventDefault();

					qodefAuthorListPagination.getNewPosts( $holder );
				}
			);
		},
		triggerLoadMore: function ( $holder, nextPage ) {
			qodefAuthorListPagination.getNewPosts( $holder, nextPage );
		},
		hideLoadMoreButton: function ( $holder, options ) {
			if ( $holder.hasClass( 'qodef-pagination-type--load-more' ) && options.next_page > options.max_num_pages ) {
				$holder.find( '.qodef-load-more-button' ).hide();
			}
		},
		initInfiniteScroll: function ( $holder ) {
			var holderEndPosition = $holder.outerHeight() + $holder.offset().top,
				scrollPosition    = qodefCore.scroll + qodefCore.windowHeight,
				options           = $holder.data( 'options' );

			if ( ! $holder.hasClass( 'qodef--loading' ) && scrollPosition > holderEndPosition && options.max_num_pages >= options.next_page ) {
				qodefAuthorListPagination.getNewPosts( $holder );
			}
		},
		getNewPosts: function ( $holder, nextPage ) {
			$holder.addClass( 'qodef--loading' );

			var $itemsHolder = $holder.children( '.qodef-grid-inner' );
			var options      = $holder.data( 'options' );

			qodefAuthorListPagination.setNextPageValue( options, nextPage, false );

			$.ajax(
				{
					type: 'GET',
					url: qodefGlobal.vars.restUrl + qodefGlobal.vars.authorPaginationRestRoute,
					data: {
						options: options,
					},
					beforeSend: function ( request ) {
						request.setRequestHeader( 'X-WP-Nonce', qodefGlobal.vars.restNonce );
					},
					success: function ( response ) {

						if ( response.status === 'success' ) {
							qodefAuthorListPagination.setNextPageValue( options, nextPage, true );
							qodefAuthorListPagination.changeStandardState( $holder, options.max_num_pages, nextPage );

							$itemsHolder.waitForImages(
								function () {
									qodefAuthorListPagination.addPosts( $itemsHolder, response.data, nextPage );

									qodefCore.body.trigger(
										'micdrop_core_trigger_get_new_authors',
										[$holder]
									);
								}
							);

							qodefAuthorListPagination.hideLoadMoreButton( $holder, options );
						} else {
							console.log( response.message );
						}
					},
					complete: function () {
						$holder.removeClass( 'qodef--loading' );
					}
				}
			);
		},
		setNextPageValue: function ( options, nextPage, ajaxTrigger ) {
			if ( typeof nextPage !== 'undefined' && nextPage !== '' && ! ajaxTrigger ) {
				options.next_page = nextPage;
			} else if ( ajaxTrigger ) {
				options.next_page = parseInt( options.next_page, 10 ) + 1;
			}
		},
		addPosts: function ( $itemsHolder, newItems, nextPage ) {
			if ( typeof nextPage !== 'undefined' && nextPage !== '' ) {
				$itemsHolder.html( newItems );
			} else {
				$itemsHolder.append( newItems );
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_button 			  = {};
	qodefCore.shortcodes.micdrop_core_button.qodefButton = qodef.qodefButton;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_countdown = {};

	$( document ).ready(
		function () {
			qodefCountdown.init();
		}
	);

	var qodefCountdown = {
		init: function () {
			this.countdowns = $( '.qodef-countdown' );

			if ( this.countdowns.length ) {
				this.countdowns.each(
					function () {
						qodefCountdown.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			var $countdownElement = $currentItem.find( '.qodef-m-date' ),
				options           = qodefCountdown.generateOptions( $currentItem );

			qodefCountdown.initCountdown( $countdownElement, options );
		},
		generateOptions: function ( $countdown ) {
			var options  = {};
			options.date = typeof $countdown.data( 'date' ) !== 'undefined' ? $countdown.data( 'date' ) : null;

			options.monthLabel       = typeof $countdown.data( 'month-label' ) !== 'undefined' ? $countdown.data( 'month-label' ) : '';
			options.monthLabelPlural = typeof $countdown.data( 'month-label-plural' ) !== 'undefined' ? $countdown.data( 'month-label-plural' ) : '';

			options.weekLabel       = typeof $countdown.data( 'week-label' ) !== 'undefined' ? $countdown.data( 'week-label' ) : '';
			options.weekLabelPlural = typeof $countdown.data( 'week-label-plural' ) !== 'undefined' ? $countdown.data( 'week-label-plural' ) : '';

			options.dayLabel       = typeof $countdown.data( 'day-label' ) !== 'undefined' ? $countdown.data( 'day-label' ) : '';
			options.dayLabelPlural = typeof $countdown.data( 'day-label-plural' ) !== 'undefined' ? $countdown.data( 'day-label-plural' ) : '';

			options.hourLabel       = typeof $countdown.data( 'hour-label' ) !== 'undefined' ? $countdown.data( 'hour-label' ) : '';
			options.hourLabelPlural = typeof $countdown.data( 'hour-label-plural' ) !== 'undefined' ? $countdown.data( 'hour-label-plural' ) : '';

			options.minuteLabel       = typeof $countdown.data( 'minute-label' ) !== 'undefined' ? $countdown.data( 'minute-label' ) : '';
			options.minuteLabelPlural = typeof $countdown.data( 'minute-label-plural' ) !== 'undefined' ? $countdown.data( 'minute-label-plural' ) : '';

			options.secondLabel       = typeof $countdown.data( 'second-label' ) !== 'undefined' ? $countdown.data( 'second-label' ) : '';
			options.secondLabelPlural = typeof $countdown.data( 'second-label-plural' ) !== 'undefined' ? $countdown.data( 'second-label-plural' ) : '';

			return options;
		},
		initCountdown: function ( $countdownElement, options ) {
			var $weekHTML   = '<span class="qodef-digit-wrapper"><span class="qodef-digit">%w</span><span class="qodef-label">' + '%!w:' + options.weekLabel + ',' + options.weekLabelPlural + ';</span></span>';
			var $monthHTML  = '<span class="qodef-digit-wrapper"><span class="qodef-digit">%m</span><span class="qodef-label">' + '%!m:' + options.monthLabel + ',' + options.monthLabelPlural + ';</span></span>';
			var $dayHTML    = '<span class="qodef-digit-wrapper"><span class="qodef-digit">%d</span><span class="qodef-label">' + '%!d:' + options.dayLabel + ',' + options.dayLabelPlural + ';</span></span>';
			var $hourHTML   = '<span class="qodef-digit-wrapper"><span class="qodef-digit">%H</span><span class="qodef-label">' + '%!H:' + options.hourLabel + ',' + options.hourLabelPlural + ';</span></span>';
			var $minuteHTML = '<span class="qodef-digit-wrapper"><span class="qodef-digit">%M</span><span class="qodef-label">' + '%!M:' + options.minuteLabel + ',' + options.minuteLabelPlural + ';</span></span>';
			var $secondHTML = '<span class="qodef-digit-wrapper"><span class="qodef-digit">%S</span><span class="qodef-label">' + '%!S:' + options.secondLabel + ',' + options.secondLabelPlural + ';</span></span>';

			$countdownElement.countdown(
				options.date,
				function ( event ) {
					$( this ).html( event.strftime( $monthHTML + $dayHTML + $hourHTML + $minuteHTML + $secondHTML ) );
				}
			);
		}
	};

	qodefCore.shortcodes.micdrop_core_countdown.qodefCountdown = qodefCountdown;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_counter = {};

	$( document ).ready(
		function () {
			qodefCounter.init();
		}
	);

	var qodefCounter = {
		init: function () {
			this.counters = $( '.qodef-counter' );

			if ( this.counters.length ) {
				this.counters.each(
					function () {
						qodefCounter.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			var $counterElement = $currentItem.find( '.qodef-m-digit' ),
				options         = qodefCounter.generateOptions( $currentItem );

			qodefCounter.counterScript( $counterElement, options );
		},
		generateOptions: function ( $counter ) {
			var options   = {};
			options.start = typeof $counter.data( 'start-digit' ) !== 'undefined' && $counter.data( 'start-digit' ) !== '' ? $counter.data( 'start-digit' ) : 0;
			options.end   = typeof $counter.data( 'end-digit' ) !== 'undefined' && $counter.data( 'end-digit' ) !== '' ? $counter.data( 'end-digit' ) : null;
			options.step  = typeof $counter.data( 'step-digit' ) !== 'undefined' && $counter.data( 'step-digit' ) !== '' ? $counter.data( 'step-digit' ) : 1;
			options.delay = typeof $counter.data( 'step-delay' ) !== 'undefined' && $counter.data( 'step-delay' ) !== '' ? parseInt( $counter.data( 'step-delay' ), 10 ) : 100;
			options.txt   = typeof $counter.data( 'digit-label' ) !== 'undefined' && $counter.data( 'digit-label' ) !== '' ? $counter.data( 'digit-label' ) : '';

			return options;
		},
		counterScript: function ( $counterElement, options ) {
			var defaults = {
				start: 0,
				end: null,
				step: 1,
				delay: 50,
				txt: '',
			};

			var settings = $.extend( defaults, options || {} );
			var nb_start = settings.start;
			var nb_end   = settings.end;

			$counterElement.text( nb_start + settings.txt );

			var counter = function () {
				// Definition of conditions of arrest
				if ( nb_end !== null && nb_start >= nb_end ) {
					return;
				}
				// incrementation
				nb_start = nb_start + settings.step;

				if ( nb_start >= nb_end ) {
					nb_start = nb_end;
				}
				// display
				$counterElement.text( nb_start + settings.txt );
			};

			// Timer
			// Launches every "settings.delay"
			$counterElement.appear(
				function () {
					setInterval( counter, settings.delay );
				},
				{ accX: 0, accY: 0 }
			);
		}
	};

	qodefCore.shortcodes.micdrop_core_counter.qodefCounter = qodefCounter;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_google_map = {};

	$( document ).ready(
		function () {
			qodefGoogleMap.init();
		}
	);

	var qodefGoogleMap = {
		init: function () {
			this.holder = $( '.qodef-google-map' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefGoogleMap.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			if ( typeof window.qodefGoogleMap !== 'undefined' ) {
				window.qodefGoogleMap.init( $currentItem.find( '.qodef-m-map' ) );
			}
		},
	};

	qodefCore.shortcodes.micdrop_core_google_map.qodefGoogleMap = qodefGoogleMap;

})( jQuery );

(function ( $ ) {
	'use strict';

	var horizontalLayout                              = {};
	qodefCore.shortcodes.horizontalLayout             = horizontalLayout;
	qodefCore.shortcodes.wonderment_core_scroll_right = {};

	horizontalLayout.qodefHorizontalLayout          = qodefHorizontalLayout;
	horizontalLayout.qodefElementorHorizontalLayout = qodefElementorHorizontalLayout;

	$( window ).on(
		'load',
		function () {
			qodefHorizontalLayout().init();
			qodefElementorHorizontalLayout();
		}
	);

	$( window ).resize(
		function () {
			qodefHorizontalLayout().init();
		}
	);

	/**
	 * Init Horizontal Layout Shortcode
	 */
	function qodefHorizontalLayout() {
		var $wrapper                          = $( '.qodef-hl-items-wrapper' ),
			$holder                           = $( '.qodef-horizontal-scroll-showcase' ),
			$items                            = $( '.qodef-hl-item' ),
			$scrollArea                       = $( '#qodef-hl-scroll-area' ),
			$tops                             = $( '.qodef-hli-top' ),
			$btms                             = $( '.qodef-hli-btm' ),
			$intro                            = $( '.qodef-hl-intro' ),
			$cta                              = $( '.qodef-hl-cta' ),
			$hiddenItems                      = $( '.qodef--has-horizontal-appear' ),
			$parallaxImage                    = $( '.qodef-hli-btm-bg-image-inner img' ),
			numOfItems                        = $items.length,
			btmOffset                         = 0,
			reverted                          = false,
			ctaW,
			introW,
			speed                             = 200, //vh per item
			first_item_addition_width         = 12,
			intro_section_subtractional_width = 86;

		var c, w, offset, wrapperW,
			sX = 0,
			dX = 0;

		//trigger calculations
		var calc = function () {
			setVars();
			reset();
			setX();
			setPositions();
		};

		//variables for calculation
		var setVars = function () {

			/* vertical header check */
			if ( $( '.qodef-header--vertical-sliding #qodef-page-header' ).length && window.innerWidth > 1024 ) {
				c = $( '.qodef-header--vertical-sliding #qodef-page-header' ).width();
			} else if ( $( '.qodef-header--vertical #qodef-page-header' ).length && window.innerWidth > 1024 ) {
				c = $( '.qodef-header--vertical #qodef-page-header' ).width();
			} else {
				c = 0;
			}
			w        = window.innerWidth > 1024 ? window.innerWidth / 2.84866468 : window.innerWidth;
			offset   = window.innerWidth > 1024 ? window.innerWidth / 2.84866468 : window.innerWidth;
			//intro offset offset = window.innerWidth > 1024 ? window.innerWidth / 2.59459459 : window.innerWidth;
			ctaW     = $cta.innerWidth();
			$intro.css( 'width', '100%' ); // reset width because of resize
			introW   = $intro.innerWidth() - intro_section_subtractional_width;
			wrapperW = (numOfItems - 1) * w + offset + ctaW + introW + first_item_addition_width - intro_section_subtractional_width;
		};

		//calc next x value based on scroll position
		var setX = function () {
			sX = 1 - (qodef.scroll) / (parseFloat( $scrollArea.height() ) - screen.height);
		};

		//position items incrementally to the right
		var setPositions = function () {
			$items.each( function ( i ) {
				if ( window.innerWidth > 1024 ) {
					$( this ).css(
						'right',
						(numOfItems - i - 1) * w + ctaW
					);
				} else {
					$items.removeAttr( 'style' );
				}
			} );
		};

		var val;

		//animate rAF
		var animate = function ( $active ) {
			reverted = false;
			val = Math.min(
				parseFloat( (1 - ($active.offset().left - c) / (offset - c)).toFixed( 4 ) ),
				1
			); //0-1

			//prev
			$active.prevAll( '.qodef-hl-item' ).css( {
				'width': offset + 'px'
			} );
			$active.prevAll().find( '.qodef-hli-btm-inner' ).height( '100%' );
			//active
			$active.css( {
				'width': w + (offset - w) * val + 'px'
			} );
			//next
			$active.next( '.qodef-hl-item' ).css( {
				'width': w + 'px'
			} );
		};

		//reset values
		var reset = function () {
			reverted = true;

			if ( window.innerWidth > 1024 ) {
				$items.width( w );
				$items.first().width( w + first_item_addition_width );
				$cta.css(
					'transform',
					'translate3d(100%, 0px, 0px)'
				);

				$intro.width( introW );
			}
		};

		//set active item if in between 0 and offset values
		var setActive = function () {
			var $active = $items.filter( function () {
				var $item = $( this );

				return $item.offset().left <= offset && $item.offset().left > 0;
			} );

			$active.length && animate( $active.first() );
		};

		var setVisibleClass = function () {

			$hiddenItems.each( function () {
				var item = $( this );

				if ( qodef.windowWidth - c + 100 > item.offset().left || item.offset().left <= 0 ) {
					item.not( '.qodef-appeared' ).addClass( 'qodef--appeared' );
				}
			} );
		};

		var setVisibleClassPhone = function () {

			$hiddenItems.each( function () {
				var item = $( this );

				item.appear(
					function () {
						item.addClass( 'qodef--appeared ' );
					},
					{ accX: 0, accY: -50 }
				);
			} );
		};

		//60fps render
		var render = function () {
			/*dX = lerp(dX, sX, 0.1);*/
			dX = lerp(
				sX,
				dX,
				.1
			);
			dX = Math.max(
				dX,
				0
			);
			if ( window.innerWidth > 1024 ) dX = parseFloat( dX.toFixed( 4 ) );

			if ( window.innerWidth > 1024 ) {
				$wrapper.css(
					'transform',
					'translate3d(' + dX * (wrapperW - window.innerWidth + c) + 'px, 0, 0)'
				);
				$cta.css(
					'transform',
					'translate3d(' + dX * ctaW + 'px, 0, 0)'
				);

				/* active class for z-index change */
				if ( dX === 0 ) {
					$cta.addClass( 'qodef-active-cta' );
				} else {
					$cta.removeClass( 'qodef-active-cta' );
				}

				setActive();
				! reverted && qodef.scroll == 0 && reset();

				requestAnimationFrame( render );
			} else {
				$wrapper.removeAttr( 'style' );
				$cta.removeAttr( 'style' );
				$items.removeAttr( 'style' );
			}
		};

		var parallaxBackground = function () {
			$parallaxImage.each( function () {
				var $thisItem     = $( this ),
					thisItemLeft  = $thisItem.offset().left,
					thisItemWidth = $thisItem.outerWidth(),
					thisItemRight = thisItemLeft + thisItemWidth,
					progressVal   = 0,
					modifier      = 'translateX',
					modifierUnit  = 'px',
					startValue    = 150,
					endValue      = 0;

				// Set init value
				$thisItem.waitForImages( function () {
					$thisItem.css(
						'transform',
						modifier + '(' + startValue + modifierUnit + ')'
					);
				} );

				var renderParallax = function ( $item ) {
					if ( $item.length ) {
						$item.css(
							'transform',
							modifier + '(' + (endValue + (1 - (progressVal * 1) * 1) * Math.abs( 1 - startValue )) + modifierUnit + ')'
						);
					}
					requestAnimationFrame( renderParallax );
				};

				$( window ).on(
					'scroll',
					function () {
						if ( qodef.scroll + window.innerWidth > thisItemLeft ) {
							progressVal = Math.abs( qodef.scroll + window.innerWidth - thisItemRight ) / window.innerWidth;
							if ( progressVal < 1 ) {
								$thisItem.css(
									'transform',
									modifier + '(' + (endValue + (1 - (progressVal * 1) * 1) * Math.abs( 1 - startValue )) + modifierUnit + ')'
								);
							}
						}
					}
				);
			} );
		};

		//linear interpolation
		var lerp = function ( a, b, n ) {
			return (1 - n) * a + n * b;
		};

		var init = function () {
			qodef.body.addClass( 'qodef-with-horizontal-scroll-showcase' );

			if ( window.innerWidth > 1024 ) {
				calc();
				$scrollArea.height( numOfItems * speed + 'vh' );

				if ( qodefCore.html.hasClass( 'touchevents' ) ) {
					window.addEventListener(
						'touchmove',
						setX
					);
				} else {
					window.addEventListener(
						'scroll',
						setX
					);
				}

				//resize debounce
				var resizeTimer;
				window.addEventListener(
					'resize',
					function () {
						clearTimeout( resizeTimer );
						resizeTimer = setTimeout(
							function () {
								calc();
							},
							250
						);

					}
				);

				requestAnimationFrame( render );

				setTimeout(
					function () {
						setVisibleClass();
					},
					100
				);

				setTimeout(
					function () {
						//parallaxBackground();
					},
					200
				);

				$( window ).scroll( function () {
					setVisibleClass();
				} );
			} else {
				setVisibleClassPhone();
			}
		};

		return {
			init: function () {
				$wrapper.length && init();

				setTimeout(
					function () {
						$holder.addClass( 'qodef-appear' );

						var htmlTag = $holder.closest( 'body' ).parent( 'html' );

						if ( ! htmlTag.hasClass( 'qodef-horizontal-scroll-showcase-initialized' ) ) {
							htmlTag.addClass( 'qodef-horizontal-scroll-showcase-initialized' );
						}
					},
					100
				);
			},
		};
	}

	/**
	 * Elementor
	 */
	function qodefElementorHorizontalLayout() {
		$( window ).on(
			'elementor/frontend/init',
			function () {
				elementorFrontend.hooks.addAction(
					'frontend/element_ready/qodef_horizontal_layout.default',
					function () {
						qodefHorizontalLayout().init();
					}
				);
			}
		);
	}

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_icon = {};

	$( document ).ready(
		function () {
			qodefIcon.init();
		}
	);

	var qodefIcon = {
		init: function () {
			this.icons = $( '.qodef-icon-holder' );

			if ( this.icons.length ) {
				this.icons.each(
					function () {
						qodefIcon.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			qodefIcon.iconHoverColor( $currentItem );
			qodefIcon.iconHoverBgColor( $currentItem );
			qodefIcon.iconHoverBorderColor( $currentItem );
		},
		iconHoverColor: function ( $iconHolder ) {
			if ( typeof $iconHolder.data( 'hover-color' ) !== 'undefined' ) {
				var spanHolder    = $iconHolder.find( 'span' ).length ? $iconHolder.find( 'span' ) : $iconHolder;
				var originalColor = spanHolder.css( 'color' );
				var hoverColor    = $iconHolder.data( 'hover-color' );

				$iconHolder.on(
					'mouseenter',
					function () {
						qodefIcon.changeColor(
							spanHolder,
							'color',
							hoverColor
						);
					}
				);
				$iconHolder.on(
					'mouseleave',
					function () {
						qodefIcon.changeColor(
							spanHolder,
							'color',
							originalColor
						);
					}
				);
			}
		},
		iconHoverBgColor: function ( $iconHolder ) {
			if ( typeof $iconHolder.data( 'hover-background-color' ) !== 'undefined' ) {
				var hoverBackgroundColor    = $iconHolder.data( 'hover-background-color' );
				var originalBackgroundColor = $iconHolder.css( 'background-color' );

				$iconHolder.on(
					'mouseenter',
					function () {
						qodefIcon.changeColor(
							$iconHolder,
							'background-color',
							hoverBackgroundColor
						);
					}
				);
				$iconHolder.on(
					'mouseleave',
					function () {
						qodefIcon.changeColor(
							$iconHolder,
							'background-color',
							originalBackgroundColor
						);
					}
				);
			}
		},
		iconHoverBorderColor: function ( $iconHolder ) {
			if ( typeof $iconHolder.data( 'hover-border-color' ) !== 'undefined' ) {
				var hoverBorderColor    = $iconHolder.data( 'hover-border-color' );
				var originalBorderColor = $iconHolder.css( 'borderTopColor' );

				$iconHolder.on(
					'mouseenter',
					function () {
						qodefIcon.changeColor(
							$iconHolder,
							'border-color',
							hoverBorderColor
						);
					}
				);
				$iconHolder.on(
					'mouseleave',
					function () {
						qodefIcon.changeColor(
							$iconHolder,
							'border-color',
							originalBorderColor
						);
					}
				);
			}
		},
		changeColor: function ( iconElement, cssProperty, color ) {
			iconElement.css(
				cssProperty,
				color
			);
		}
	};

	qodefCore.shortcodes.micdrop_core_icon.qodefIcon = qodefIcon;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_image_gallery                    = {};
	qodefCore.shortcodes.micdrop_core_image_gallery.qodefSwiper        = qodef.qodefSwiper;
	qodefCore.shortcodes.micdrop_core_image_gallery.qodefMasonryLayout = qodef.qodefMasonryLayout;
	qodefCore.shortcodes.micdrop_core_image_gallery.qodefMagnificPopup = qodef.qodefMagnificPopup;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_image_with_text                    = {};
	qodefCore.shortcodes.micdrop_core_image_with_text.qodefMagnificPopup = qodef.qodefMagnificPopup;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_progress_bar = {};

	$( document ).ready(
		function () {
			qodefProgressBar.init();
		}
	);

	/**
	 * Init progress bar shortcode functionality
	 */
	var qodefProgressBar = {
		init: function () {
			this.holder = $( '.qodef-progress-bar' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefProgressBar.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			var layout = $currentItem.data( 'layout' );

			$currentItem.appear(
				function () {
					$currentItem.addClass( 'qodef--init' );

					var $container = $currentItem.find( '.qodef-m-canvas' ),
						data       = qodefProgressBar.generateBarData( $currentItem, layout ),
						number     = $currentItem.data( 'number' ) / 100;

					switch (layout) {
						case 'circle':
							qodefProgressBar.initCircleBar( $container, data, number );
							break;
						case 'semi-circle':
							qodefProgressBar.initSemiCircleBar( $container, data, number );
							break;
						case 'line':
							data = qodefProgressBar.generateLineData( $currentItem, number );
							qodefProgressBar.initLineBar( $container, data );
							break;
						case 'custom':
							qodefProgressBar.initCustomBar( $container, data, number );
							break;
					}
				}
			);
		},
		generateBarData: function ( thisBar, layout ) {
			var activeWidth   = thisBar.data( 'active-line-width' );
			var activeColor   = thisBar.data( 'active-line-color' );
			var inactiveWidth = thisBar.data( 'inactive-line-width' );
			var inactiveColor = thisBar.data( 'inactive-line-color' );
			var easing        = 'linear';
			var duration      = typeof thisBar.data( 'duration' ) !== 'undefined' && thisBar.data( 'duration' ) !== '' ? parseInt( thisBar.data( 'duration' ), 10 ) : 1600;
			var textColor     = thisBar.data( 'text-color' );

			return {
				strokeWidth: activeWidth,
				color: activeColor,
				trailWidth: inactiveWidth,
				trailColor: inactiveColor,
				easing: easing,
				duration: duration,
				svgStyle: {
					width: '100%',
					height: '100%'
				},
				text: {
					style: {
						color: textColor
					},
					autoStyleContainer: false
				},
				from: {
					color: inactiveColor
				},
				to: {
					color: activeColor
				},
				step: function ( state, bar ) {
					if ( layout !== 'custom' ) {
						bar.setText( Math.round( bar.value() * 100 ) + '%' );
					}
				},
			};
		},
		generateLineData: function ( thisBar, number ) {
			var height         = thisBar.data( 'active-line-width' );
			var activeColor    = thisBar.data( 'active-line-color' );
			var inactiveHeight = thisBar.data( 'inactive-line-width' );
			var inactiveColor  = thisBar.data( 'inactive-line-color' );
			var duration       = typeof thisBar.data( 'duration' ) !== 'undefined' && thisBar.data( 'duration' ) !== '' ? parseInt( thisBar.data( 'duration' ), 10 ) : 1600;
			var textColor      = thisBar.data( 'text-color' );

			return {
				percentage: number * 100,
				duration: duration,
				fillBackgroundColor: activeColor,
				backgroundColor: inactiveColor,
				height: height,
				inactiveHeight: inactiveHeight,
				followText: thisBar.hasClass( 'qodef-percentage--floating' ),
				textColor: textColor,
			};
		},
		initCircleBar: function ( $container, data, number ) {
			if ( qodefProgressBar.checkBar( $container ) ) {
				var $bar = new ProgressBar.Circle( $container[0], data );

				$bar.animate( number );
			}
		},
		initSemiCircleBar: function ( $container, data, number ) {
			if ( qodefProgressBar.checkBar( $container ) ) {
				var $bar = new ProgressBar.SemiCircle( $container[0], data );

				$bar.animate( number );
			}
		},
		initCustomBar: function ( $container, data, number ) {
			if ( qodefProgressBar.checkBar( $container ) ) {
				var $bar = new ProgressBar.Path( $container[0], data );

				$bar.set( 0 );
				$bar.animate( number );
			}
		},
		initLineBar: function ( $container, data ) {
			$container.LineProgressbar( data );
		},
		checkBar: function ( $container ) {
			// check if svg is already in container, elementor fix
			if ( $container.find( 'svg' ).length ) {
				return false;
			}

			return true;
		}
	};

	qodefCore.shortcodes.micdrop_core_progress_bar.qodefProgressBar = qodefProgressBar;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_single_image                    = {};
	qodefCore.shortcodes.micdrop_core_single_image.qodefMagnificPopup = qodef.qodefMagnificPopup;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_tabs = {};

	$( document ).ready(
		function () {
			qodefTabs.init();
		}
	);

	var qodefTabs = {
		init: function () {
			this.holder = $( '.qodef-tabs' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefTabs.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			$currentItem.children( '.qodef-tabs-content' ).each(
				function ( index ) {
					index = index + 1;

					var $that    = $( this ),
						link     = $that.attr( 'id' ),
						$navItem = $that.parent().find( '.qodef-tabs-navigation li:nth-child(' + index + ') a' ),
						navLink  = $navItem.attr( 'href' );

					link = '#' + link;

					if ( link.indexOf( navLink ) > -1 ) {
						$navItem.attr(
							'href',
							link
						);
					}
				}
			);

			$currentItem.addClass( 'qodef--init' ).tabs();
		}
	};

	qodefCore.shortcodes.micdrop_core_tabs.qodefTabs = qodefTabs;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_text_marquee = {};

	$( document ).ready(
		function () {
			qodefTextMarquee.init();
		}
	);

	var qodefTextMarquee = {
		init: function () {
			this.holder = $( '.qodef-text-marquee' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefTextMarquee.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			qodefTextMarquee.initMarquee( $currentItem );
			qodefTextMarquee.initResponsive( $currentItem.find( '.qodef-m-content' ) );
		},
		initResponsive: function ( thisMarquee ) {
			var fontSize,
				lineHeight,
				coef1 = 1,
				coef2 = 1;

			if ( qodefCore.windowWidth < 1480 ) {
				coef1 = 0.8;
			}

			if ( qodefCore.windowWidth < 1200 ) {
				coef1 = 0.7;
			}

			if ( qodefCore.windowWidth < 768 ) {
				coef1 = 0.55;
				coef2 = 0.65;
			}

			if ( qodefCore.windowWidth < 600 ) {
				coef1 = 0.45;
				coef2 = 0.55;
			}

			if ( qodefCore.windowWidth < 480 ) {
				coef1 = 0.4;
				coef2 = 0.5;
			}

			fontSize = parseInt( thisMarquee.css( 'font-size' ) );

			if ( fontSize > 200 ) {
				fontSize = Math.round( fontSize * coef1 );
			} else if ( fontSize > 60 ) {
				fontSize = Math.round( fontSize * coef2 );
			}

			thisMarquee.css( 'font-size', fontSize + 'px' );

			lineHeight = parseInt( thisMarquee.css( 'line-height' ) );

			if ( lineHeight > 70 && qodefCore.windowWidth < 1440 ) {
				lineHeight = '1.2em';
			} else if ( lineHeight > 35 && qodefCore.windowWidth < 768 ) {
				lineHeight = '1.2em';
			} else {
				lineHeight += 'px';
			}

			thisMarquee.css( 'line-height', lineHeight );
		},
		initMarquee: function ( thisMarquee ) {
			var elements = thisMarquee.find( '.qodef-m-text' ),
				delta    = 0.1;

			elements.each(
				function ( i ) {
					$( this ).data( 'x', 0 );
				}
			);

			requestAnimationFrame(
				function () {
					qodefTextMarquee.loop( thisMarquee, elements, delta );
				}
			);
		},
		inRange: function ( thisMarquee ) {
			if ( qodefCore.scroll + qodefCore.windowHeight >= thisMarquee.offset().top && qodefCore.scroll < thisMarquee.offset().top + thisMarquee.height() ) {
				return true;
			}

			return false;
		},
		loop: function ( thisMarquee, elements, delta ) {
			if ( ! qodefTextMarquee.inRange( thisMarquee ) ) {
				requestAnimationFrame(
					function () {
						qodefTextMarquee.loop( thisMarquee, elements, delta );
					}
				);
				return false;
			} else {
				elements.each(
					function ( i ) {
						var el = $( this );
						el.css( 'transform', 'translate3d(' + el.data( 'x' ) + '%, 0, 0)' );
						el.data( 'x', (el.data( 'x' ) - delta).toFixed( 2 ) );
						el.offset().left < -el.width() - 25 && el.data( 'x', 100 * Math.abs( i - 1 ) );
					}
				);
				requestAnimationFrame(
					function () {
						qodefTextMarquee.loop( thisMarquee, elements, delta );
					}
				);
			}
		}
	};

	qodefCore.shortcodes.micdrop_core_text_marquee.qodefTextMarquee = qodefTextMarquee;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_video_button                    = {};
	qodefCore.shortcodes.micdrop_core_video_button.qodefMagnificPopup = qodef.qodefMagnificPopup;

})( jQuery );

(function ($) {
    "use strict";

	qodefCore.shortcodes.micdrop_core_video_holder = {};
	qodefCore.shortcodes.micdrop_core_video_holder.qodefAppear = qodef.qodefAppear ;

})(jQuery);
(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_cards_gallery = {};

	$( document ).ready(
		function () {
			qodefVideoWithInteractiveBanners.init();
		}
	);

	$( window ).on(
		'resize',
		function () {
			qodefVideoWithInteractiveBanners.init();
		}
	);

	var qodefVideoWithInteractiveBanners = {
		init: function () {
			this.holder = $( '.qodef-video-with-interactive-banners' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefVideoWithInteractiveBanners.maintainFullHeight( $( this ) );
						qodefVideoWithInteractiveBanners.initBanners( $( this ) );
					}
				);
			}
		},
		maintainFullHeight: function ( $holder ) {
			var $headerHeight = 0;
			var $mobileHeaderHeight = 0;
			var $videoSectionHeight = 0;
			var $videoSection = $holder.find('.qodef-e-inner .qodef-e-item.qodef-e-left');

			if ( $holder.hasClass('qodef-maintain-full-height--yes') ) {

				$holder.css("height", ""); // reset height value if exist
				$videoSection.height('100%');

				var $holderHeight = $holder.height();

				if ( qodef.windowWidth > 1024 && ! qodef.body.hasClass('qodef-header--transparent') && qodefGlobal.vars.headerHeight !== null && qodefGlobal.vars.headerHeight !== '' ) {
					$headerHeight = parseInt( qodefGlobal.vars.headerHeight, 10 );
					$holderHeight = $holderHeight - $headerHeight;
				} else if ( qodef.windowWidth > 768 && qodef.windowWidth <= 1024 && ! qodef.body.hasClass('qodef-header--transparent') && qodefGlobal.vars.headerHeight !== null && qodefGlobal.vars.headerHeight !== '' ) {
					$mobileHeaderHeight = parseInt( qodefGlobal.vars.mobileHeaderHeight, 10 );
					$holderHeight = $holderHeight - $mobileHeaderHeight;
				} else {
					$mobileHeaderHeight = parseInt( qodefGlobal.vars.mobileHeaderHeight, 10 );
					$holderHeight = $holderHeight - $mobileHeaderHeight;
					$videoSection.height('100%');
					$holderHeight = '100%';
				}

				$holder.height($holderHeight); // sets holder height
			}
		},
		initBanners: function ( $holder ) {
			var $items = $holder.find( '.qodef-m-banner-items' );

			if ( qodef.windowWidth > 768 ) {
				if ( $items.length && typeof qodefCore.qodefPerfectScrollbar === 'object' ) {
					qodefCore.qodefPerfectScrollbar.init( $items );
				}
			}
		}
	};

	qodefCore.shortcodes.micdrop_core_cards_gallery.qodefVideoWithInteractiveBanners = qodefVideoWithInteractiveBanners;

})( jQuery );

(function ( $ ) {
	'use strict';

	var shortcode = 'micdrop_core_blog_list';

	$( document ).ready(
		function () {
			//qodefSoundCloudonBlogList.init();
		}
	);

	$( document ).on(
		'micdrop_trigger_get_new_posts',
		function () {
			//qodefSoundCloudonBlogList.init();
		}
	);

	var qodefSoundCloudonBlogList = {
		players: [],
		init: function () {
			this.holder = $( '.qodef-blog.qodef-blog-audio-featured-image' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $holder = $( this );

						qodefSoundCloudonBlogList.initItem( $holder );
					}
				);
			}
		},
		initItem: function ( $holder ) {
			var $item	 = $holder.find( '.format-audio iframe' );
			var $itemSRC = $item.attr( 'src' );

			if ( $itemSRC.length && $itemSRC.includes( 'soundcloud.com' ) ) {
				var $newSRC = $itemSRC.replace( 'visual=true&','' );
			}

			$item.attr( 'src', $newSRC );
		}
	};

	qodefCore.shortcodes[shortcode] = {};

	if ( typeof qodefCore.listShortcodesScripts === 'object' ) {
		$.each(
			qodefCore.listShortcodesScripts,
			function ( key, value ) {
				qodefCore.shortcodes[shortcode][key] = value;
			}
		);
	}

	qodefCore.shortcodes[shortcode].qodefResizeIframes = qodef.qodefResizeIframes;
	//qodefCore.shortcodes.micdrop_core_blog_list.qodefSoundCloudonBlogList = qodefSoundCloudonBlogList;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefFullscreenMenu.init();
			qodefHideWidgetFullscreenMenu.init();
		}
	);

	/**
	 * Init Fullscreen Menu
	 */
	var qodefFullscreenMenu = {
		// Add overlay for closing the menu
		init: function () {

			if ( $( 'body' ).hasClass( 'qodef-header--minimal' ) ) {

				$( '#qodef-page-wrapper #qodef-fullscreen-area-inner' ).prepend( '<div class="qodef-fullscreen-cover"/>' );

				$( '#qodef-page-wrapper .qodef-fullscreen-cover' ).on(
					'click',
					function () {
						$( 'body' ).removeClass( 'qodef-fullscreen-menu--opened qodef-fullscreen-menu-animate--in' ).addClass('qodef-fullscreen-menu-animate--out');
						qodefCore.qodefScroll.enable();
					}
				);

				$( window ).mousemove(
					function ( e ) {
						$( '.qodef-fullscreen-menu-opener .qodef-m-icon.qodef--close' ).css( { left: e.clientX, top: e.clientY } );
					}
				);

				$( '.qodef-fullscreen-menu, #qodef-fullscreen-area .qodef-widget-holder' ).mouseenter(
					function ( e ) {
						$( '.qodef-m-icon.qodef--close' ).css(
							'opacity',
							'0'
						);
					}
				)
				.mouseleave(
					function ( e ) {
						$( '.qodef-m-icon.qodef--close' ).css(
							'opacity',
							'1'
						);
					}
				);
			}
		}
	}

	var qodefHideWidgetFullscreenMenu = {
		init: function () {
			this.holder = $( '.qodef-header--minimal .qodef-minimal-header-hide-widget-open-menu' );

			if ( this.holder.length ) {
				$( 'body' ).addClass( 'qodef-hide-widget-on-fullscren-open-menu' );
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefVerticalNavMenu.init();
		}
	);

	/**
	 * Function object that represents vertical menu area.
	 * @returns {{init: Function}}
	 */
	var qodefVerticalNavMenu = {
		initNavigation: function ( $verticalMenuObject ) {
			var $verticalNavObject = $verticalMenuObject.find( '.qodef-header-vertical-navigation' );

			if ( $verticalNavObject.hasClass( 'qodef-vertical-drop-down--below' ) ) {
				qodefVerticalNavMenu.dropdownClickToggle( $verticalNavObject );
			} else if ( $verticalNavObject.hasClass( 'qodef-vertical-drop-down--side' ) ) {
				qodefVerticalNavMenu.dropdownFloat( $verticalNavObject );
			}
		},
		dropdownClickToggle: function ( $verticalNavObject ) {
			var $menuItems = $verticalNavObject.find( 'ul li.menu-item-has-children' );

			$menuItems.each(
				function () {
					var $elementToExpand = $( this ).find( ' > .qodef-drop-down-second, > ul' );
					var menuItem         = this;
					var $dropdownOpener  = $( this ).find( '> a' );
					var slideUpSpeed     = 'fast';
					var slideDownSpeed   = 'slow';

					$dropdownOpener.on(
						'click tap',
						function ( e ) {
							e.preventDefault();
							e.stopPropagation();

							if ( $elementToExpand.is( ':visible' ) ) {
								$( menuItem ).removeClass( 'qodef-menu-item--open' );
								$elementToExpand.slideUp( slideUpSpeed );
							} else if ( $dropdownOpener.parent().parent().children().hasClass( 'qodef-menu-item--open' ) && $dropdownOpener.parent().parent().parent().hasClass( 'qodef-vertical-menu' ) ) {
								$( this ).parent().parent().children().removeClass( 'qodef-menu-item--open' );
								$( this ).parent().parent().children().find( ' > .qodef-drop-down-second' ).slideUp( slideUpSpeed );

								$( menuItem ).addClass( 'qodef-menu-item--open' );
								$elementToExpand.slideDown( slideDownSpeed );
							} else {

								if ( ! $( this ).parents( 'li' ).hasClass( 'qodef-menu-item--open' ) ) {
									$menuItems.removeClass( 'qodef-menu-item--open' );
									$menuItems.find( ' > .qodef-drop-down-second, > ul' ).slideUp( slideUpSpeed );
								}

								if ( $( this ).parent().parent().children().hasClass( 'qodef-menu-item--open' ) ) {
									$( this ).parent().parent().children().removeClass( 'qodef-menu-item--open' );
									$( this ).parent().parent().children().find( ' > .qodef-drop-down-second, > ul' ).slideUp( slideUpSpeed );
								}

								$( menuItem ).addClass( 'qodef-menu-item--open' );
								$elementToExpand.slideDown( slideDownSpeed );
							}
						}
					);
				}
			);
		},
		dropdownFloat: function ( $verticalNavObject ) {
			var $menuItems = $verticalNavObject.find( 'ul li.menu-item-has-children' );
			var $allDropdowns = $menuItems.find( ' > .qodef-drop-down-second > .qodef-drop-down-second-inner > ul, > ul' );

			$menuItems.each(
				function () {
					var $elementToExpand = $( this ).find( ' > .qodef-drop-down-second > .qodef-drop-down-second-inner > ul, > ul' );
					var menuItem         = this;

					if ( Modernizr.touch ) {
						var $dropdownOpener = $( this ).find( '> a' );

						$dropdownOpener.on(
							'click tap',
							function ( e ) {
								e.preventDefault();
								e.stopPropagation();

								if ( $elementToExpand.hasClass( 'qodef-float--open' ) ) {
									$elementToExpand.removeClass( 'qodef-float--open' );
									$( menuItem ).removeClass( 'qodef-menu-item--open' );
								} else {
									if ( ! $( this ).parents( 'li' ).hasClass( 'qodef-menu-item--open' ) ) {
										$menuItems.removeClass( 'qodef-menu-item--open' );
										$allDropdowns.removeClass( 'qodef-float--open' );
									}

									$elementToExpand.addClass( 'qodef-float--open' );
									$( menuItem ).addClass( 'qodef-menu-item--open' );
								}
							}
						);
					} else {
						//must use hoverIntent because basic hover effect doesn't catch dropdown
						//it doesn't start from menu item's edge
						$( this ).hoverIntent(
							{
								over: function () {
									$elementToExpand.addClass( 'qodef-float--open' );
									$( menuItem ).addClass( 'qodef-menu-item--open' );
								},
								out: function () {
									$elementToExpand.removeClass( 'qodef-float--open' );
									$( menuItem ).removeClass( 'qodef-menu-item--open' );
								},
								timeout: 300
							}
						);
					}
				}
			);
		},
		verticalAreaScrollable: function ( $verticalMenuObject ) {
			return $verticalMenuObject.hasClass( 'qodef-with-scroll' );
		},
		initVerticalAreaScroll: function ( $verticalMenuObject ) {
			if ( qodefVerticalNavMenu.verticalAreaScrollable( $verticalMenuObject ) && typeof qodefCore.qodefPerfectScrollbar === 'object' ) {
				qodefCore.qodefPerfectScrollbar.init( $verticalMenuObject );
			}
		},
		init: function () {
			var $verticalMenuObject = $( '.qodef-header--vertical #qodef-page-header' );

			if ( $verticalMenuObject.length ) {
				qodefVerticalNavMenu.initNavigation( $verticalMenuObject );
				qodefVerticalNavMenu.initVerticalAreaScroll( $verticalMenuObject );
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
	    function () {
            qodefVerticalSlidingNavMenu.init();
        }
	);

	/**
	 * Function object that represents vertical menu area.
	 * @returns {{init: Function}}
	 */
	var qodefVerticalSlidingNavMenu = {
		openedScroll: 0,

		initNavigation: function ( $verticalSlidingMenuObject ) {
			var $verticalSlidingNavObject = $verticalSlidingMenuObject.find( '.qodef-header-vertical-sliding-navigation' );

			if ( $verticalSlidingNavObject.hasClass( 'qodef-vertical-sliding-drop-down--below' ) ) {
				qodefVerticalSlidingNavMenu.dropdownClickToggle( $verticalSlidingNavObject );
			} else if ( $verticalSlidingNavObject.hasClass( 'qodef-vertical-sliding-drop-down--side' ) ) {
				qodefVerticalSlidingNavMenu.dropdownFloat( $verticalSlidingNavObject );
			}
		},
		dropdownClickToggle: function ( $verticalSlidingNavObject ) {
			var $menuItems = $verticalSlidingNavObject.find( 'ul li.menu-item-has-children' );

			$menuItems.each(
				function () {
					var $elementToExpand = $( this ).find( ' > .qodef-drop-down-second, > ul' );
					var menuItem         = this;
					var $dropdownOpener  = $( this ).find( '> a' );
					var slideUpSpeed     = 'fast';
					var slideDownSpeed   = 'slow';

					$dropdownOpener.on(
						'click tap',
						function ( e ) {
							e.preventDefault();
							e.stopPropagation();

							if ( $elementToExpand.is( ':visible' ) ) {
								$( menuItem ).removeClass( 'qodef-menu-item--open' );
								$elementToExpand.slideUp( slideUpSpeed );
							} else if ( $dropdownOpener.parent().parent().children().hasClass( 'qodef-menu-item--open' ) && $dropdownOpener.parent().parent().parent().hasClass( 'qodef-vertical-menu' ) ) {
								$( this ).parent().parent().children().removeClass( 'qodef-menu-item--open' );
								$( this ).parent().parent().children().find( ' > .qodef-drop-down-second' ).slideUp( slideUpSpeed );

								$( menuItem ).addClass( 'qodef-menu-item--open' );
								$elementToExpand.slideDown( slideDownSpeed );
							} else {

								if ( ! $( this ).parents( 'li' ).hasClass( 'qodef-menu-item--open' ) ) {
									$menuItems.removeClass( 'qodef-menu-item--open' );
									$menuItems.find( ' > .qodef-drop-down-second, > ul' ).slideUp( slideUpSpeed );
								}

								if ( $( this ).parent().parent().children().hasClass( 'qodef-menu-item--open' ) ) {
									$( this ).parent().parent().children().removeClass( 'qodef-menu-item--open' );
									$( this ).parent().parent().children().find( ' > .qodef-drop-down-second, > ul' ).slideUp( slideUpSpeed );
								}

								$( menuItem ).addClass( 'qodef-menu-item--open' );
								$elementToExpand.slideDown( slideDownSpeed );
							}
						}
					);
				}
			);
		},
		dropdownFloat: function ( $verticalSlidingNavObject ) {
			var $menuItems = $verticalSlidingNavObject.find( 'ul li.menu-item-has-children' );
			var $allDropdowns = $menuItems.find( ' > .qodef-drop-down-second > .qodef-drop-down-second-inner > ul, > ul' );

			$menuItems.each(
				function () {
					var $elementToExpand = $( this ).find( ' > .qodef-drop-down-second > .qodef-drop-down-second-inner > ul, > ul' );
					var menuItem         = this;

					if ( Modernizr.touch ) {
						var $dropdownOpener = $( this ).find( '> a' );

						$dropdownOpener.on(
							'click tap',
							function ( e ) {
								e.preventDefault();
								e.stopPropagation();

								if ( $elementToExpand.hasClass( 'qodef-float--open' ) ) {
									$elementToExpand.removeClass( 'qodef-float--open' );
									$( menuItem ).removeClass( 'qodef-menu-item--open' );
								} else {
									if ( ! $( this ).parents( 'li' ).hasClass( 'qodef-menu-item--open' ) ) {
										$menuItems.removeClass( 'qodef-menu-item--open' );
										$allDropdowns.removeClass( 'qodef-float--open' );
									}

									$elementToExpand.addClass( 'qodef-float--open' );
									$( menuItem ).addClass( 'qodef-menu-item--open' );
								}
							}
						);
					} else {
						//must use hoverIntent because basic hover effect doesn't catch dropdown
						//it doesn't start from menu item's edge
						$( this ).hoverIntent(
							{
								over: function () {
									$elementToExpand.addClass( 'qodef-float--open' );
									$( menuItem ).addClass( 'qodef-menu-item--open' );
								},
								out: function () {
									$elementToExpand.removeClass( 'qodef-float--open' );
									$( menuItem ).removeClass( 'qodef-menu-item--open' );
								},
								timeout: 300
							}
						);
					}
				}
			);
		},
		verticalSlidingAreaScrollable: function ( $verticalSlidingMenuObject ) {
			return $verticalSlidingMenuObject.hasClass( 'qodef-with-scroll' );
		},
		initVerticalSlidingAreaScroll: function ( $verticalSlidingMenuObject ) {
			if ( qodefVerticalSlidingNavMenu.verticalSlidingAreaScrollable( $verticalSlidingMenuObject ) && typeof qodefCore.qodefPerfectScrollbar === 'object' ) {
				qodefCore.qodefPerfectScrollbar.init( $verticalSlidingMenuObject );
			}
		},
		verticalSlidingAreaShowHide: function ( $verticalSlidingMenuObject ) {
			var $verticalSlidingMenuOpener = $verticalSlidingMenuObject.find( '.qodef-vertical-sliding-menu-opener' );

			$verticalSlidingMenuOpener.on(
				'click',
				function ( e ) {
					e.preventDefault();

					if ( ! $verticalSlidingMenuObject.hasClass( 'qodef-vertical-sliding-menu--opened' ) ) {
						$verticalSlidingMenuObject.addClass( 'qodef-vertical-sliding-menu--opened' );
						qodefVerticalSlidingNavMenu.openedScroll = qodef.window.scrollTop();
					} else {
						$verticalSlidingMenuObject.removeClass( 'qodef-vertical-sliding-menu--opened' );
					}
				}
			);
		},
		verticalSlidingAreaCloseOnScroll: function ( $verticalSlidingMenuObject ) {
			qodef.window.on(
				'scroll',
				function () {
					if ( $verticalSlidingMenuObject.hasClass( 'qodef-vertical-sliding-menu--opened' ) && Math.abs( qodef.scroll - qodefVerticalSlidingNavMenu.openedScroll ) > 400 ) {
						$verticalSlidingMenuObject.removeClass( 'qodef-vertical-sliding-menu--opened' );
					}
				}
			);
		},
		init: function () {
			var $verticalSlidingMenuObject = $( '.qodef-header--vertical-sliding #qodef-page-header' );

			if ( $verticalSlidingMenuObject.length ) {
				qodefVerticalSlidingNavMenu.verticalSlidingAreaShowHide( $verticalSlidingMenuObject );
				qodefVerticalSlidingNavMenu.verticalSlidingAreaCloseOnScroll( $verticalSlidingMenuObject );
				qodefVerticalSlidingNavMenu.initNavigation( $verticalSlidingMenuObject );
				qodefVerticalSlidingNavMenu.initVerticalSlidingAreaScroll( $verticalSlidingMenuObject );
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	var fixedHeaderAppearance = {
		showHideHeader: function ( $pageOuter, $header ) {
			if ( qodefCore.windowWidth > 1024 ) {
				if ( qodefCore.scroll <= 0 ) {
					qodefCore.body.removeClass( 'qodef-header--fixed-display' );
					$header.css( 'margin-top', '0' );
				} else {
					qodefCore.body.addClass( 'qodef-header--fixed-display' );
					$header.css( 'margin-top', parseInt( qodefGlobal.vars.topAreaHeight ) + 'px' );
				}
			}
		},
		init: function () {

			if ( ! qodefCore.body.hasClass( 'qodef-header--vertical' ) ) {
				var $pageOuter = $( '#qodef-page-outer' ),
					$header    = $( '#qodef-page-header' );

				fixedHeaderAppearance.showHideHeader( $pageOuter, $header );

				$( window ).scroll(
					function () {
						fixedHeaderAppearance.showHideHeader( $pageOuter, $header );
					}
				);

				$( window ).resize(
					function () {
						fixedHeaderAppearance.showHideHeader( $pageOuter, $header );
					}
				);
			}
		}
	};

	qodefCore.fixedHeaderAppearance = fixedHeaderAppearance.init;

})( jQuery );

(function ( $ ) {
	'use strict';

	var stickyHeaderAppearance = {
		header: '',
		docYScroll: 0,
		init: function () {
			var displayAmount = stickyHeaderAppearance.displayAmount();

			// Set variables
			stickyHeaderAppearance.header 	  = $( '.qodef-header-sticky' );
			stickyHeaderAppearance.docYScroll = $( document ).scrollTop();

			// Set sticky visibility
			stickyHeaderAppearance.setVisibility( displayAmount );

			$( window ).scroll(
				function () {
					stickyHeaderAppearance.setVisibility( displayAmount );
				}
			);
		},
		displayAmount: function () {
			if ( qodefGlobal.vars.qodefStickyHeaderScrollAmount !== 0 ) {
				return parseInt( qodefGlobal.vars.qodefStickyHeaderScrollAmount, 10 );
			} else {
				return parseInt( qodefGlobal.vars.headerHeight + qodefGlobal.vars.adminBarHeight, 10 );
			}
		},
		setVisibility: function ( displayAmount ) {
			var isStickyHidden = qodefCore.scroll < displayAmount;

			if ( stickyHeaderAppearance.header.hasClass( 'qodef-appearance--up' ) ) {
				var currentDocYScroll = $( document ).scrollTop();

				isStickyHidden = (currentDocYScroll > stickyHeaderAppearance.docYScroll && currentDocYScroll > displayAmount) || (currentDocYScroll < displayAmount);

				stickyHeaderAppearance.docYScroll = $( document ).scrollTop();
			}

			stickyHeaderAppearance.showHideHeader( isStickyHidden );
		},
		showHideHeader: function ( isStickyHidden ) {
			if ( isStickyHidden ) {
				qodefCore.body.removeClass( 'qodef-header--sticky-display' );
			} else {
				qodefCore.body.addClass( 'qodef-header--sticky-display' );
			}
		},
	};

	qodefCore.stickyHeaderAppearance = stickyHeaderAppearance.init;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefSideAreaMobileHeader.init();
		}
	);

	var qodefSideAreaMobileHeader = {
		init: function () {
			var $holder = $( '#qodef-side-area-mobile-header' );

			if ( $holder.length && qodefCore.body.hasClass( 'qodef-mobile-header--side-area' ) ) {
				var $navigation = $holder.find( '.qodef-m-navigation' );

				qodefSideAreaMobileHeader.initOpenerTrigger( $holder, $navigation );
				qodefSideAreaMobileHeader.initNavigationClickToggle( $navigation );

				if ( typeof qodefCore.qodefPerfectScrollbar === 'object' ) {
					qodefCore.qodefPerfectScrollbar.init( $holder );
				}
			}
		},
		initOpenerTrigger: function ( $holder, $navigation ) {
			var $openerIcon = $( '.qodef-side-area-mobile-header-opener' ),
				$closeIcon  = $holder.children( '.qodef-m-close' );

			if ( $openerIcon.length && $navigation.length ) {
				$openerIcon.on(
					'tap click',
					function ( e ) {
						e.stopPropagation();
						e.preventDefault();

						if ( $holder.hasClass( 'qodef--opened' ) ) {
							$holder.removeClass( 'qodef--opened' );
						} else {
							$holder.addClass( 'qodef--opened' );
						}
					}
				);
			}

			$closeIcon.on(
				'tap click',
				function ( e ) {
					e.stopPropagation();
					e.preventDefault();

					if ( $holder.hasClass( 'qodef--opened' ) ) {
						$holder.removeClass( 'qodef--opened' );
					}
				}
			);
		},
		initNavigationClickToggle: function ( $navigation ) {
			var $menuItems = $navigation.find( 'ul li.menu-item-has-children' );

			$menuItems.each(
				function () {
					var $thisItem        = $( this ),
						$elementToExpand = $thisItem.find( ' > .qodef-drop-down-second, > ul' ),
						$dropdownOpener  = $thisItem.find( '> .qodef-menu-item-arrow' ),
						slideUpSpeed     = 'fast',
						slideDownSpeed   = 'slow';

					$dropdownOpener.on(
						'click tap',
						function ( e ) {
							e.preventDefault();
							e.stopPropagation();

							if ( $elementToExpand.is( ':visible' ) ) {
								$thisItem.removeClass( 'qodef-menu-item--open' );
								$elementToExpand.slideUp( slideUpSpeed );
							} else if ( $dropdownOpener.parent().parent().children().hasClass( 'qodef-menu-item--open' ) && $dropdownOpener.parent().parent().parent().hasClass( 'qodef-vertical-menu' ) ) {
								$thisItem.parent().parent().children().removeClass( 'qodef-menu-item--open' );
								$thisItem.parent().parent().children().find( ' > .qodef-drop-down-second' ).slideUp( slideUpSpeed );

								$thisItem.addClass( 'qodef-menu-item--open' );
								$elementToExpand.slideDown( slideDownSpeed );
							} else {

								if ( ! $thisItem.parents( 'li' ).hasClass( 'qodef-menu-item--open' ) ) {
									$menuItems.removeClass( 'qodef-menu-item--open' );
									$menuItems.find( ' > .qodef-drop-down-second, > ul' ).slideUp( slideUpSpeed );
								}

								if ( $thisItem.parent().parent().children().hasClass( 'qodef-menu-item--open' ) ) {
									$thisItem.parent().parent().children().removeClass( 'qodef-menu-item--open' );
									$thisItem.parent().parent().children().find( ' > .qodef-drop-down-second, > ul' ).slideUp( slideUpSpeed );
								}

								$thisItem.addClass( 'qodef-menu-item--open' );
								$elementToExpand.slideDown( slideDownSpeed );
							}
						}
					);
				}
			);
		},
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefSearchCoversHeader.init();
		}
	);

	var qodefSearchCoversHeader = {
		init: function () {
			var $searchOpener = $( 'a.qodef-search-opener' ),
				$searchForm   = $( '.qodef-search-cover-form' ),
				$searchClose  = $searchForm.find( '.qodef-m-close' );

			if ( $searchOpener.length && $searchForm.length ) {
				$searchOpener.on(
					'click',
					function ( e ) {
						e.preventDefault();
						qodefSearchCoversHeader.openCoversHeader( $searchForm );
					}
				);
				$searchClose.on(
					'click',
					function ( e ) {
						e.preventDefault();
						qodefSearchCoversHeader.closeCoversHeader( $searchForm );
					}
				);
			}
		},
		openCoversHeader: function ( $searchForm ) {
			qodefCore.body.addClass( 'qodef-covers-search--opened qodef-covers-search--fadein' );
			qodefCore.body.removeClass( 'qodef-covers-search--fadeout' );

			setTimeout(
				function () {
					$searchForm.find( '.qodef-m-form-field' ).focus();
				},
				600
			);
		},
		closeCoversHeader: function ( $searchForm ) {
			qodefCore.body.removeClass( 'qodef-covers-search--opened qodef-covers-search--fadein' );
			qodefCore.body.addClass( 'qodef-covers-search--fadeout' );

			setTimeout(
				function () {
					$searchForm.find( '.qodef-m-form-field' ).val( '' );
					$searchForm.find( '.qodef-m-form-field' ).blur();
					qodefCore.body.removeClass( 'qodef-covers-search--fadeout' );
				},
				300
			);
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefSearchFullscreen.init();
		}
	);

	var qodefSearchFullscreen = {
		init: function () {
			var $searchOpener = $( 'a.qodef-search-opener' ),
				$searchHolder = $( '.qodef-fullscreen-search-holder' ),
				$searchClose  = $searchHolder.find( '.qodef-m-close' );

			if ( $searchOpener.length && $searchHolder.length ) {

				if ( $( 'body' ).hasClass( 'qodef-search--fullscreen' ) ) {

					$searchHolder.prepend( '<div class="qodef-fullscreen-search-cover"/>' );

					$( '.qodef-fullscreen-search-holder .qodef-fullscreen-search-cover' ).on(
						'click',
						function () {
							qodefSearchFullscreen.closeFullscreen( $searchHolder );
						}
					);

					$( window ).mousemove(
						function ( e ) {
							$( '.qodef-fullscreen-search-holder .qodef-opener-icon.qodef-m-close' ).css( { left: e.clientX, top: e.clientY } );
						}
					);

					$( '.qodef-fullscreen-search-holder .qodef-m-form' ).mouseenter(
						function ( e ) {
							$( '.qodef-opener-icon.qodef-m-close' ).css(
								'opacity',
								'0'
							);
						}
					)
					.mouseleave(
						function ( e ) {
							$( '.qodef-opener-icon.qodef-m-close' ).css(
								'opacity',
								'1'
							);
						}
					);
				}

				$searchOpener.on(
					'click',
					function ( e ) {
						e.preventDefault();
						if ( qodefCore.body.hasClass( 'qodef-fullscreen-search--opened' ) ) {
							qodefSearchFullscreen.closeFullscreen( $searchHolder );
						} else {
							qodefSearchFullscreen.openFullscreen( $searchHolder );
						}
					}
				);
				$searchClose.on(
					'click',
					function ( e ) {
						e.preventDefault();
						qodefSearchFullscreen.closeFullscreen( $searchHolder );
					}
				);

				//Close on escape
				$( document ).keyup(
					function ( e ) {
						if ( e.keyCode === 27 && qodefCore.body.hasClass( 'qodef-fullscreen-search--opened' ) ) { //KeyCode for ESC button is 27
							qodefSearchFullscreen.closeFullscreen( $searchHolder );
						}
					}
				);
			}
		},
		openFullscreen: function ( $searchHolder ) {
			qodefCore.body.removeClass( 'qodef-fullscreen-search--fadeout' );
			qodefCore.body.addClass( 'qodef-fullscreen-search--opened qodef-fullscreen-search--fadein' );

			setTimeout(
				function () {
					$searchHolder.find( '.qodef-m-form-field' ).focus();
				},
				900
			);

			qodefCore.qodefScroll.disable();
		},
		closeFullscreen: function ( $searchHolder ) {
			qodefCore.body.removeClass( 'qodef-fullscreen-search--opened qodef-fullscreen-search--fadein' );
			qodefCore.body.addClass( 'qodef-fullscreen-search--fadeout' );

			setTimeout(
				function () {
					$searchHolder.find( '.qodef-m-form-field' ).val( '' );
					$searchHolder.find( '.qodef-m-form-field' ).blur();
					qodefCore.body.removeClass( 'qodef-fullscreen-search--fadeout' );
				},
				300
			);

			qodefCore.qodefScroll.enable();
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefSearch.init();
		}
	);

	var qodefSearch = {
		init: function () {
			this.search = $( 'a.qodef-search-opener' );

			if ( this.search.length ) {
				this.search.each(
					function () {
						var $thisSearch = $( this );

						qodefSearch.searchHoverColor( $thisSearch );
					}
				);
			}
		},
		searchHoverColor: function ( $searchHolder ) {
			if ( typeof $searchHolder.data( 'hover-color' ) !== 'undefined' ) {
				var hoverColor    = $searchHolder.data( 'hover-color' ),
					originalColor = $searchHolder.css( 'color' );

				$searchHolder.on(
					'mouseenter',
					function () {
						$searchHolder.css( 'color', hoverColor );
					}
				).on(
					'mouseleave',
					function () {
						$searchHolder.css( 'color', originalColor );
					}
				);
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefProgressBarSpinner.init();
		}
	);

	$( window ).on(
		'load',
		function () {
			qodefProgressBarSpinner.windowLoaded = true;
			qodefProgressBarSpinner.completeAnimation();
		}
	);

	$( window ).on(
		'elementor/frontend/init',
		function () {
			var isEditMode = Boolean( elementorFrontend.isEditMode() );

			if ( isEditMode ) {
				qodefProgressBarSpinner.init( isEditMode );
			}
		}
	);

	var qodefProgressBarSpinner = {
		holder: '',
		windowLoaded: false,
		percentNumber: 0,
		init: function ( isEditMode ) {
			this.holder = $( '#qodef-page-spinner.qodef-layout--progress-bar' );

			if ( this.holder.length ) {
				qodefProgressBarSpinner.animateSpinner( this.holder, isEditMode );
			}
		},
		animateSpinner: function ( $holder, isEditMode ) {
			var $numberHolder = $holder.find( '.qodef-m-spinner-number-label' ),
				$spinnerLine  = $holder.find( '.qodef-m-spinner-line-front' );

			$spinnerLine.animate(
				{ 'width': '100%' },
				10000,
				'linear'
			);

			var numberInterval = setInterval(
				function () {
					qodefProgressBarSpinner.animatePercent( $numberHolder, qodefProgressBarSpinner.percentNumber );

					if ( qodefProgressBarSpinner.windowLoaded ) {
						clearInterval( numberInterval );
					}
				},
				100
			);

			if ( isEditMode ) {
				qodefProgressBarSpinner.fadeOutLoader( $holder );
			}
		},
		completeAnimation: function () {
			var $holder = qodefProgressBarSpinner.holder.length ? qodefProgressBarSpinner.holder : $( '#qodef-page-spinner.qodef-layout--progress-bar' );

			var numberIntervalFastest = setInterval(
				function () {

					if ( qodefProgressBarSpinner.percentNumber >= 100 ) {
						clearInterval( numberIntervalFastest );

						$holder.find( '.qodef-m-spinner-line-front' ).stop().animate(
							{ 'width': '100%' },
							500
						);

						$holder.addClass( 'qodef--finished' );

						setTimeout(
							function () {
								qodefProgressBarSpinner.fadeOutLoader( $holder );
							},
							600
						);
					} else {
						qodefProgressBarSpinner.animatePercent(
							$holder.find( '.qodef-m-spinner-number-label' ),
							qodefProgressBarSpinner.percentNumber
						);
					}
				},
				6
			);
		},
		animatePercent: function ( $numberHolder, percentNumber ) {
			if ( percentNumber < 100 ) {
				percentNumber += 5;
				$numberHolder.text( percentNumber );

				qodefProgressBarSpinner.percentNumber = percentNumber;
			}
		},
		fadeOutLoader: function ( $holder, speed, delay, easing ) {
			speed  = speed ? speed : 600;
			delay  = delay ? delay : 0;
			easing = easing ? easing : 'swing';

			$holder.delay( delay ).fadeOut( speed, easing );

			$( window ).on(
				'bind',
				'pageshow',
				function ( event ) {
					if ( event.originalEvent.persisted ) {
						$holder.fadeOut( speed, easing );
					}
				}
			);
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_instagram_list = {};

	$( document ).ready(
		function () {
			qodefInstagram.init();
		}
	);

	var qodefInstagram = {
		init: function () {
			this.holder = $( '.sbi.qodef-instagram-swiper-container' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefInstagram.initSlider( $( this ) );
					}
				);
			}
		},
		initSlider: function ( $currentItem, $initAllItems ) {
			var sliderOptions   = $currentItem.parent().attr( 'data-options' ),
				$instagramImage = $currentItem.find( '.sbi_item.sbi_type_image' ),
				$imageHolder    = $currentItem.find( '#sbi_images' );

			$currentItem.attr( 'data-options', sliderOptions );

			$imageHolder.addClass( 'swiper-wrapper' );

			if ( $instagramImage.length ) {
				$instagramImage.each(
					function () {
						$( this ).addClass( 'qodef-e qodef-image-wrapper swiper-slide' );
					}
				);
			}

			if ( typeof qodef.qodefSwiper === 'object' ) {

				if ( false === $initAllItems ) {
					qodef.qodefSwiper.initSlider( $currentItem );
				} else {
					qodef.qodefSwiper.init( $currentItem );
				}
			}
		},
	};

	qodefCore.shortcodes.micdrop_core_instagram_list.qodefInstagram = qodefInstagram;
	qodefCore.shortcodes.micdrop_core_instagram_list.qodefSwiper    = qodef.qodefSwiper;

})( jQuery );

(function ( $ ) {
	'use strict';

	/*
	 **	Re-init scripts on gallery loaded
	 */
	$( document ).on(
		'yith_wccl_product_gallery_loaded',
		function () {

			if ( typeof qodefCore.qodefWooMagnificPopup === 'function' ) {
				qodefCore.qodefWooMagnificPopup.init();
			}
		}
	);

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_product_category_list                    = {};
	qodefCore.shortcodes.micdrop_core_product_category_list.qodefMasonryLayout = qodef.qodefMasonryLayout;
	qodefCore.shortcodes.micdrop_core_product_category_list.qodefSwiper        = qodef.qodefSwiper;

})( jQuery );

(function ( $ ) {
	'use strict';

	var shortcode = 'micdrop_core_product_list';

	qodefCore.shortcodes[shortcode] = {};

	if ( typeof qodefCore.listShortcodesScripts === 'object' ) {
		$.each(
			qodefCore.listShortcodesScripts,
			function ( key, value ) {
				qodefCore.shortcodes[shortcode][key] = value;
			}
		);
	}

	/* for elementor editor */
	qodefCore.shortcodes.micdrop_core_product_list.qodefWooListButtonIcon 		   = qodef.qodefWooListButtonIcon;
	qodefCore.shortcodes.micdrop_core_product_list.qodefWooListButtonIconGrouped  = qodef.qodefWooListButtonIconGrouped;
	qodefCore.shortcodes.micdrop_core_product_list.qodefWooListButtonIconExternal = qodef.qodefWooListButtonIconExternal;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefDropDownCart.init();
		}
	);

	var qodefDropDownCart = {
		init: function () {
			var $holder = $( '.qodef-widget-dropdown-cart-content' );

			if ( $holder.length ) {
				$holder.off().each(
					function () {
						var $thisHolder = $( this );

						qodefDropDownCart.trigger( $thisHolder );

						qodefCore.body.on(
							'added_to_cart removed_from_cart',
							function () {
								qodefDropDownCart.init();
							}
						);
					}
				);
			}
		},
		trigger: function ( $holder ) {
			var $items = $holder.find( '.qodef-woo-mini-cart' );
			if ( $items.length && typeof qodefCore.qodefPerfectScrollbar === 'object' ) {
				qodefCore.qodefPerfectScrollbar.init( $items );
			}
		},
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	var shortcode = 'micdrop_core_album_list';

	qodefCore.shortcodes[shortcode] = {};

	if ( typeof qodefCore.listShortcodesScripts === 'object' ) {
		$.each(
			qodefCore.listShortcodesScripts,
			function ( key, value ) {
				qodefCore.shortcodes[shortcode][key] = value;
			}
		);
	}

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_album_player = {};

	$( document ).ready(
		function () {
		}
	);

	$( window ).on(
		'load',
		function () {
			// on load because of init in album slider SC
			qodefAlbumPlayer.init();
		}
	);

	$( document ).on(
		'micdrop_core_trigger_tracks_list_event',
		function ( e, albumID, trackID, event ) {
			qodefAlbumPlayer.triggerPlayerEvent( albumID, trackID, event );
		}
	);

	var qodefAlbumPlayer = {
		players: [],
		init: function () {
			this.holder = $( '.qodef-album-player' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefAlbumPlayer.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			qodefAlbumPlayer.triggerPlayer( $currentItem );
		},
		triggerPlayer: function ( $holder ) {
			$holder.addClass( 'qodef--loading' );

			$.ajax(
				{
					type: 'GET',
					url: qodefGlobal.vars.restUrl + qodefGlobal.vars.getAlbumSongRestRoute,
					data: {
						album_id: $holder.children( '.qodef-m-album' ).data( 'album-id' ),
					},
					success: function ( response ) {
						if ( response.status === 'success' ) {
							qodefAlbumPlayer.initPlayer( $holder, response.data );
						} else {
							console.log( response.message );
						}
					},
					complete: function () {
						$holder.removeClass( 'qodef--loading' );
					}
				}
			);
		},
		initPlayer: function ( $holder, data ) {
			$holder.addClass( 'qodef--init' );

			var $playerPlayList = new jPlayerPlaylist(
				{
					jPlayer: '#' + $holder.children( '.qodef-m-album' ).attr( 'id' ),
					cssSelectorAncestor: '#' + $holder.children( '.qodef-m-player' ).attr( 'id' ),
				},
				data,
				{
					supplied: 'mp3',
					wmode: 'window',
					useStateClassSkin: true,
					autoBlur: false,
					smoothPlayBar: true,
					keyEnabled: true,
					ready: function () {
						qodefAlbumPlayer.setTrackDetails( $playerPlayList, $holder );

						qodefCore.body.trigger(
							'micdrop_core_trigger_album_player_event',
							[$playerPlayList, 'ready']
						);
					},
					pause: function () {
						qodefCore.body.trigger(
							'micdrop_core_trigger_album_player_event',
							[$playerPlayList, 'pause']
						);
					},
					play: function () {
						qodefAlbumPlayer.setTrackDetails( $playerPlayList, $holder );

						qodefCore.body.trigger(
							'micdrop_core_trigger_album_player_event',
							[$playerPlayList, 'play']
						);
					}
				}
			);

			qodefAlbumPlayer.players.push( $playerPlayList );
		},
		setTrackDetails: function ( $playerPlayList, $holder ) {
			var $title = $holder.find( '.qodef-m-player-track-title' );

			if ( $title.length ) {
				$title.html( $playerPlayList.original[$playerPlayList.current].title );
			}
		},
		triggerPlayerEvent: function ( albumID, trackID, event ) {
			if ( typeof qodefAlbumPlayer.players === 'object' && typeof albumID !== 'undefined' && typeof event !== 'undefined' ) {
				$.each(
					qodefAlbumPlayer.players,
					function ( key, value ) {
						if ( value.cssSelector.jPlayer === ('#' + 'qodef-m-album-' + albumID) ) {
							switch (event) {
								case 'pause':
									value.pause( trackID );
									break;
								case 'play':
									value.play( trackID );
									break;
							}
						}
					}
				);
			}
		}
	};

	qodefCore.shortcodes.micdrop_core_album_player.qodefAlbumPlayer = qodefAlbumPlayer;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_album_player_slider = {};

	$( document ).ready(
		function () {
			qodefAlbumPlayerSlider.init();
		}
	);

	var qodefAlbumPlayerSlider = {
		init: function () {
			this.holder = $( '.qodef-album-player-slider' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $thisHolder = $( this );
						qodefAlbumPlayerSlider.fullHeightSliderCalc( $thisHolder );

						$( window ).resize(
							function () {
								qodefAlbumPlayerSlider.fullHeightSliderCalc( $thisHolder );
							}
						);
					}
				);
			}
		},
		fullHeightSliderCalc: function ( $holder ) {

			if ( $holder.hasClass( 'qodef-full-height-album-player-slider' ) ) {
				var windowHeight = (window.innerHeight || document.documentElement.clientHeight);
				var headerHeight = 0;

				if ( ! qodef.body.hasClass( 'qodef-header--transparent' ) ) {
					headerHeight = qodefGlobal.vars.headerHeight;
				}

				if ( qodefCore.windowWidth > 1024 ) {
					var sliderHeight = windowHeight - headerHeight - qodefGlobal.vars.topAreaHeight - qodefGlobal.vars.adminBarHeight;
				} else {
					sliderHeight = windowHeight - qodefGlobal.vars.mobileHeaderHeight - qodefGlobal.vars.adminBarHeight;
				}

				if ( qodefCore.body.hasClass( 'qodef--passepartout' ) ) {
					var passepartoutSize = parseInt( qodefCore.body.css( 'padding-top' ) );
					sliderHeight -= passepartoutSize;
				}

				$holder.height( sliderHeight );
			}
		}
	};

	qodefCore.shortcodes.micdrop_core_album_player_slider.qodefAlbumPlayerSlider = qodefAlbumPlayerSlider;
	qodefCore.shortcodes.micdrop_core_album_player_slider.qodefSwiper 			 = qodef.qodefSwiper;
	qodefCore.shortcodes.micdrop_core_album_player_slider.qodefAlbumPlayer 		 = qodefCore.shortcodes.micdrop_core_album_player.qodefAlbumPlayer;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_artist_showcase_slider = {};

	$( document ).ready(
		function () {
			qodefArtistShowcaseSlider.init();
		}
	);

	// $( window ).on(
	// 	'load',
	// 	function () {
	// 		qodefArtistShowcaseSlider.init();
	// 	}
	// );

	var qodefArtistShowcaseSlider = {
		init: function () {
			this.holder = $( '.qodef-artist-showcase-slider' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $thisHolder = $( this );

						qodefArtistShowcaseSlider.fullHeightSliderCalc( $thisHolder );
						qodefArtistShowcaseSlider.createSlider( $thisHolder );
						qodefArtistShowcaseSlider.sliderSong( $thisHolder );

						$( window ).resize(
							function () {
								qodefArtistShowcaseSlider.fullHeightSliderCalc( $thisHolder );
							}
						);
					}
				);
			}
		},
		fullHeightSliderCalc: function ( $holder ) {

			if ( $holder.hasClass( 'qodef-artist-showcase-slider' ) ) {
				var windowHeight = (window.innerHeight || document.documentElement.clientHeight);
				var headerHeight = 0;

				if ( ! qodef.body.hasClass( 'qodef-header--transparent' ) ) {
					headerHeight = qodefGlobal.vars.headerHeight;
				}

				if ( qodefCore.windowWidth > 1024 ) {
					var sliderHeight = windowHeight - headerHeight - qodefGlobal.vars.topAreaHeight - qodefGlobal.vars.adminBarHeight;
				} else {
					sliderHeight = windowHeight - qodefGlobal.vars.adminBarHeight;
				}

				if ( qodefCore.body.hasClass( 'qodef--passepartout' ) ) {
					var passepartoutSize = parseInt( qodefCore.body.css( 'padding-top' ) );
					sliderHeight -= passepartoutSize;
				}

				$holder.height( sliderHeight );
			}
		},
		sliderSong: function ( $holder ) {

			var playButton = $holder.find( '.qodef-website-song' );
			var audioTrack = playButton.find( 'audio' ).get( 0 );

			if ( playButton.length ) {
				playButton.each(
					function () {
						/* commented out because media files can't be autoplayed anymore */
						/*audioTrack.play();
						playButton.addClass( 'qodef-track-playing qodef-track-in-progress' );
						$( '.qodef-equalizer-bar' ).removeClass( 'noAnim' );*/

						playButton.on(
							'click',
							function () {
								if ( playButton.hasClass( 'qodef-track-in-progress' ) ) {
									audioTrack.pause();
									playButton.addClass( 'qodef-track-paused' ).removeClass( 'qodef-track-in-progress' );
									$( '.qodef-equalizer-bar' ).addClass( 'noAnim' );
								} else if ( playButton.hasClass( 'qodef-track-paused' ) ) {
									audioTrack.play();
									playButton.addClass( 'qodef-track-playing qodef-track-in-progress' ).removeClass( 'qodef-track-paused' );
									$( '.qodef-equalizer-bar' ).removeClass( 'noAnim' );
								} else {
									audioTrack.play();
									playButton.addClass( 'qodef-track-playing qodef-track-in-progress' );
									$( '.qodef-equalizer-bar' ).removeClass( 'noAnim' );
								}
							}
						);

						playButton.find( 'audio' ).on(
							'ended',
							function () {
								audioTrack.play();
							}
						);
					}
				);
			}
		},
		createSlider: function ( $holder ) {
			var $swiperHolder = $holder.find( '.qodef-m-swiper' ),
				$sliderHolder = $holder.find( '.qodef-m-items' ),
				$pagination   = $holder.find( '.swiper-pagination' );

			var sliderOptions     = typeof $swiperHolder.data( 'options' ) !== 'undefined' ? $swiperHolder.data( 'options' ) : {},
				spaceBetween      = sliderOptions.spaceBetween !== undefined && sliderOptions.spaceBetween !== '' ? sliderOptions.spaceBetween : 0,
				slidesPerView     = sliderOptions.slidesPerView !== undefined && sliderOptions.slidesPerView !== '' ? sliderOptions.slidesPerView : 1,
				centeredSlides    = sliderOptions.centeredSlides !== undefined && sliderOptions.centeredSlides !== '' ? sliderOptions.centeredSlides : false,
				loop              = sliderOptions.loop !== undefined && sliderOptions.loop !== '' ? sliderOptions.loop : true,
				autoplay          = sliderOptions.autoplay !== undefined && sliderOptions.autoplay !== '' ? sliderOptions.autoplay : true,
				speed             = sliderOptions.speed !== undefined && sliderOptions.speed !== '' ? parseInt(
					sliderOptions.speed,
					10
				) : 5000,
				speedAnimation    = sliderOptions.speedAnimation !== undefined && sliderOptions.speedAnimation !== '' ? parseInt(
					sliderOptions.speedAnimation,
					10
				) : 800,
				customStages      = sliderOptions.customStages !== undefined && sliderOptions.customStages !== '' ? sliderOptions.customStages : false,
				outsideNavigation = sliderOptions.outsideNavigation !== undefined && sliderOptions.outsideNavigation === 'yes',
				nextNavigation    = outsideNavigation ? '.swiper-button-next-' + sliderOptions.unique : $swiperHolder.find( '.swiper-button-next' ),
				prevNavigation    = outsideNavigation ? '.swiper-button-prev-' + sliderOptions.unique : $swiperHolder.find( '.swiper-button-prev' ),
				pagination        = $swiperHolder.find( '.swiper-pagination' );

			if ( autoplay !== false && speed !== 5000 ) {
				autoplay = {
					delay: speed
				};
			}

			var $swiper = new Swiper(
				$swiperHolder,
				{
					slidesPerView: slidesPerView,
					centeredSlides: centeredSlides,
					spaceBetween: spaceBetween,
					direction: 'vertical',
					autoplay: autoplay,
					loop: loop,
					speed: speedAnimation,
					navigation: { nextEl: nextNavigation, prevEl: prevNavigation },
					pagination: { el: pagination, type: 'bullets', clickable: true },
					on: {
						init: function () {
							setTimeout(
								function () {
									$sliderHolder.addClass( 'qodef-swiper--initialized' );
								},
								100
							);

							/* slide scroll */
							if ( true ) {
								var scrollStart = false;

								$holder.on(
									'mousewheel',
									function ( e ) {
										e.preventDefault();

										if ( ! scrollStart ) {
											scrollStart = true;

											if ( e.deltaY < 0 ) {
												$swiperHolder[0].swiper.slideNext();
											} else {
												$swiperHolder[0].swiper.slidePrev();
											}

											setTimeout(
												function () {
													scrollStart = false;
												},
												1000
											);
										}
									}
								);
							}
						}
					},
				}
			);
		}
	};

	qodefCore.shortcodes.micdrop_core_artist_showcase_slider.qodefArtistShowcaseSlider = qodefArtistShowcaseSlider;

})( jQuery );


(function ( $ ) {
	'use strict';

	var shortcode = 'micdrop_core_artists_list';

	qodefCore.shortcodes[shortcode]                    = {};
	qodefCore.shortcodes[shortcode].qodefMasonryLayout = qodef.qodefMasonryLayout;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_tracks_list = {};

	$( document ).ready(
		function () {
			qodefTracksList.init();
		}
	);

	$( document ).on(
		'micdrop_core_trigger_album_player_event',
		function ( e, $playerPlayList, event ) {
			qodefTracksList.initTriggered( $playerPlayList, event );
		}
	);

	var qodefTracksList = {
		init: function () {
			this.holder = $( '.qodef-tracks-list' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefTracksList.initItem( $( this ) );
					}
				);
			}
		},
		initItem: function ( $currentItem ) {
			if ( ! qodefCore.body.hasClass( 'single-album' ) ) {
				qodefTracksList.triggerPlayer( $currentItem );
			} else {
				qodefTracksList.triggerTrackClick( $currentItem );
			}
		},
		triggerPlayer: function ( $holder ) {
			$.ajax(
				{
					type: 'GET',
					url: qodefGlobal.vars.restUrl + qodefGlobal.vars.getAlbumSongRestRoute,
					data: {
						album_id: $holder.data( 'album-id' ),
					},
					success: function ( response ) {
						if ( response.status === 'success' ) {
							qodefTracksList.initPlayer( $holder, response.data );
						} else {
							console.log( response.message );
						}
					}
				}
			);
		},
		initPlayer: function ( $holder, data ) {
			var $playerPlayList = new jPlayerPlaylist(
				{
					jPlayer: '#' + $holder.children( '.qodef-m-track-player' ).attr( 'id' ),
					cssSelectorAncestor: '#' + $holder.children( '.qodef-m-track-player' ).attr( 'id' ),
				},
				data,
				{
					supplied: 'mp3',
					wmode: 'window',
					useStateClassSkin: true,
					autoBlur: false,
					smoothPlayBar: true,
					ready: function () {
						qodefTracksList.triggerTrackClick( $holder, $playerPlayList );
					},
					pause: function () {
						qodefTracksList.initTriggered( $playerPlayList, 'pause' );
					},
					play: function () {
						qodefTracksList.initTriggered( $playerPlayList, 'play' );
					}
				}
			);
		},
		initTriggered: function ( $playerPlayList, event ) {
			this.holder = $( '.qodef-tracks-list' );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $thisHolder = $( this );

						if ( typeof event !== 'undefined' ) {
							switch (event) {
								case 'pause':
									qodefTracksList.setActiveTrack( $thisHolder, $playerPlayList, event );
									break;
								case 'play':
									qodefTracksList.setActiveTrack( $thisHolder, $playerPlayList, event );
									break;
							}
						}
					}
				);
			}
		},
		triggerTrackClick: function ( $holder, $playerPlayList ) {
			$holder.find( '.qodef-e-heading-title, .qodef-e-action-control.qodef--play' ).on(
				'click',
				function ( e ) {
					e.preventDefault();

					var $currentTrack = $( this ).parents( '.qodef-m-tracks-list-item' );

					if ( $currentTrack.hasClass( 'qodef--active' ) ) {
						$currentTrack.removeClass( 'qodef--active' );

						qodefTracksList.triggerPlayerEvent( $playerPlayList, $currentTrack.data( 'track-index' ), 'pause' );

						qodefCore.body.trigger(
							'micdrop_core_trigger_tracks_list_event',
							[$holder.data( 'album-id' ), $currentTrack.data( 'track-index' ), 'pause']
						);
					} else {
						qodefTracksList.triggerPlayerEvent( $playerPlayList, $currentTrack.data( 'track-index' ), 'play' );

						qodefCore.body.trigger(
							'micdrop_core_trigger_tracks_list_event',
							[$holder.data( 'album-id' ), $currentTrack.data( 'track-index' ), 'play']
						);
					}
				}
			);
		},
		setActiveTrack: function ( $holder, $playerPlayList, event ) {
			var activeSong = $playerPlayList.original[$playerPlayList.current].unique_id;

			$holder.find( '.qodef-m-tracks-list-item' ).removeClass( 'qodef--active' );

			if ( event !== 'pause' ) {
				$holder.find( '.qodef-m-tracks-list-item[data-track-id="' + activeSong + '"]' ).addClass( 'qodef--active' );
			}
		},
		triggerPlayerEvent: function ( $playerPlayList, trackID, event ) {
			if ( ! qodefCore.body.hasClass( 'single-album' ) ) {
				switch (event) {
					case 'pause':
						$playerPlayList.pause( trackID );
						break;
					case 'play':
						$playerPlayList.play( trackID );
						break;
				}
			}
		}
	};

	qodefCore.shortcodes.micdrop_core_tracks_list.qodefTracksList = qodefTracksList;

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_clients_list             = {};
	qodefCore.shortcodes.micdrop_core_clients_list.qodefSwiper = qodef.qodefSwiper;

})( jQuery );

(function ( $ ) {
	'use strict';

	var shortcode = 'micdrop_core_events_list';

	qodefCore.shortcodes[shortcode] = {};

	if ( typeof qodefCore.listShortcodesScripts === 'object' ) {
		$.each(
			qodefCore.listShortcodesScripts,
			function ( key, value ) {
				qodefCore.shortcodes[shortcode][key] = value;
			}
		);
	}

})( jQuery );

(function ( $ ) {
	'use strict';

	var shortcode = 'micdrop_core_events_slider';

	qodefCore.shortcodes[shortcode] = {};

	if ( typeof qodefCore.listShortcodesScripts === 'object' ) {
		$.each(
			qodefCore.listShortcodesScripts,
			function ( key, value ) {
				qodefCore.shortcodes[shortcode][key] = value;
			}
		);
	}

})( jQuery );

(function ( $ ) {
	'use strict';

	var shortcode = 'micdrop_core_masonry_gallery_list';

	qodefCore.shortcodes[shortcode]                    = {};
	qodefCore.shortcodes[shortcode].qodefMasonryLayout = qodef.qodefMasonryLayout;
	qodefCore.shortcodes[shortcode].qodefMagnificPopup = qodef.qodefMagnificPopup;

})( jQuery );

(function ( $ ) {
	'use strict';

	var shortcode = 'micdrop_core_team_list';

	qodefCore.shortcodes[shortcode] = {};

	if ( typeof qodefCore.listShortcodesScripts === 'object' ) {
		$.each(
			qodefCore.listShortcodesScripts,
			function ( key, value ) {
				qodefCore.shortcodes[shortcode][key] = value;
			}
		);
	}

})( jQuery );

(function ( $ ) {
	'use strict';

	qodefCore.shortcodes.micdrop_core_testimonials_list             = {};
	qodefCore.shortcodes.micdrop_core_testimonials_list.qodefSwiper = qodef.qodefSwiper;

})( jQuery );
