(function ( $ ) {
	'use strict';

	// This case is important when theme is not active
	if ( typeof qodef !== 'object' ) {
		window.qodef = {};
	}

	window.qodefCore                = {};
	qodefCore.shortcodes            = {};
	qodefCore.listShortcodesScripts = {
		qodefSwiper: qodef.qodefSwiper,
		qodefPagination: qodef.qodefPagination,
		qodefFilter: qodef.qodefFilter,
		qodefMasonryLayout: qodef.qodefMasonryLayout,
		qodefJustifiedGallery: qodef.qodefJustifiedGallery,
	};

	qodefCore.body         = $( 'body' );
	qodefCore.html         = $( 'html' );
	qodefCore.windowWidth  = $( window ).width();
	qodefCore.windowHeight = $( window ).height();
	qodefCore.scroll       = 0;

	$( document ).ready(
		function () {
			qodefCore.scroll = $( window ).scrollTop();
			qodefInlinePageStyle.init();
			qodefUncoverSection.init();
		}
	);

	$( window ).resize(
		function () {
			qodefCore.windowWidth  = $( window ).width();
			qodefCore.windowHeight = $( window ).height();
		}
	);

	$( window ).scroll(
		function () {
			qodefCore.scroll = $( window ).scrollTop();
		}
	);

	var qodefScroll = {
		disable: function () {
			if ( window.addEventListener ) {
				window.addEventListener(
					'wheel',
					qodefScroll.preventDefaultValue,
					{ passive: false }
				);
			}

			// window.onmousewheel = document.onmousewheel = qodefScroll.preventDefaultValue;
			document.onkeydown = qodefScroll.keyDown;
		},
		enable: function () {
			if ( window.removeEventListener ) {
				window.removeEventListener(
					'wheel',
					qodefScroll.preventDefaultValue,
					{ passive: false }
				);
			}
			window.onmousewheel = document.onmousewheel = document.onkeydown = null;
		},
		preventDefaultValue: function ( e ) {
			e = e || window.event;
			if ( e.preventDefault ) {
				e.preventDefault();
			}
			e.returnValue = false;
		},
		keyDown: function ( e ) {
			var keys = [37, 38, 39, 40];
			for ( var i = keys.length; i--; ) {
				if ( e.keyCode === keys[i] ) {
					qodefScroll.preventDefaultValue( e );
					return;
				}
			}
		}
	};

	qodefCore.qodefScroll = qodefScroll;

	var qodefScrollbarWidth = {
		getWidth: function () {
			return window.innerWidth - document.documentElement.clientWidth;
		},
	};

	qodefCore.qodefScrollbarWidth = qodefScrollbarWidth;

	var qodefPerfectScrollbar = {
		init: function ( $holder ) {
			if ( $holder.length ) {
				qodefPerfectScrollbar.qodefInitScroll( $holder );
			}
		},
		qodefInitScroll: function ( $holder ) {
			var $defaultParams = {
				wheelSpeed: 0.6,
				suppressScrollX: true
			};

			var $ps = new PerfectScrollbar(
				$holder[0],
				$defaultParams
			);

			$( window ).resize(
				function () {
					$ps.update();
				}
			);
		}
	};

	qodefCore.qodefPerfectScrollbar = qodefPerfectScrollbar;
	
	/*
	 *  Add uncovering section
	 */
	var qodefUncoverSection = {
		init: function () {
			this.holder = $('#qodef-custom-section--uncover');
			
			if (this.holder.length && !qodefCore.html.hasClass('touchevents') && qodef.windowWidth > 1024) {
				qodefUncoverSection.addClass(this.holder);
				qodefUncoverSection.setHeight(this.holder);
				
				$(window).resize(function () {
					qodefUncoverSection.setHeight(qodefUncoverSection.holder);
				});
			}
		},
		setHeight: function ($holder) {
			$holder.css('height', 'auto');
			
			var sectionHeight = $holder.outerHeight();
			
			if (sectionHeight > 0) {
				$('#qodef-page-content').css({ 'margin-bottom': sectionHeight });
				$holder.css('height', sectionHeight);
			}
			
			document.addEventListener('scroll', function () {
				var scrolledNearBottomOfPage = document.documentElement.scrollHeight - qodefCore.scroll - qodefCore.windowHeight < 100;
				
				if ( scrolledNearBottomOfPage ) {
					$holder.css('z-index', '2');
				} else {
					$holder.css('z-index', '0');
				}
				
			}, {
				passive: true
			});
		},
		addClass: function () {
			qodefCore.body.addClass('qodef-page-has-custom-section--uncover');
		},
	};
	
	qodefCore.qodefUncoverSection = qodefUncoverSection;

	var qodefInlinePageStyle = {
		init: function () {
			this.holder = $( '#micdrop-core-page-inline-style' );

			if ( this.holder.length ) {
				var style = this.holder.data( 'style' );

				if ( style.length ) {
					$( 'head' ).append( '<style type="text/css">' + style + '</style>' );
				}
			}
		}
	};

})( jQuery );
