<?php

if ( ! function_exists( 'micdrop_core_add_blog_single_options' ) ) {
	/**
	 * Function that add options for this module
	 */
	function micdrop_core_add_blog_single_options( $tab ) {

		// Hook to include additional options first in single blog options
		do_action( 'micdrop_core_action_first_blog_single_options_map', $tab );

		if ( $tab ) {
			$layout_options = apply_filters( 'micdrop_core_filter_blog_single_layout_options', array ( '' => esc_html__( 'Default', 'micdrop-core' ) ) );
			if ( count( $layout_options ) > 1 ) {
				$tab -> add_field_element(
					array (
						'field_type'    => 'select',
						'name'          => 'qodef_blog_single_post_template',
						'title'         => esc_html__( 'Post Template', 'micdrop-core' ),
						'description'   => esc_html__( 'Choose post template', 'micdrop-core' ),
						'default_value' => '',
						'options'       => $layout_options,
					)
				);
			}

			$tab->add_field_element(
				array(
					'field_type'    => 'yesno',
					'name'          => 'qodef_blog_single_title_center',
					'title'         => esc_html__( 'Center Title', 'micdrop-core' ),
					'description'   => esc_html__( 'Center post title', 'micdrop-core' ),
					'default_value' => 'no',
					'dependency'    => array(
						'show' => array(
							'qodef_blog_single_post_template' => array(
								'values' => '',
								'default_value' => '',
							),
						),
					),
				)
			);

			$tab -> add_field_element(
				array (
					'field_type'    => 'yesno',
					'name'          => 'qodef_blog_single_dark_skin',
					'title'         => esc_html__( 'Dark Skin', 'micdrop-core' ),
					'description'   => esc_html__( 'This option applies to blog lists and single posts on which the info is displayed over the image', 'micdrop-core' ),
					'default_value' => 'no',
				)
			);

			$tab -> add_field_element(
				array (
					'field_type'  => 'text',
					'name'        => 'qodef_blog_single_featured_image_height',
					'title'       => esc_html__( 'Media Height', 'micdrop-core' ),
					'description' => esc_html__( 'Set the height for featured image or video post', 'micdrop-core' ),
					'args'        => array (
						'suffix' => esc_html__( 'px', 'micdrop-core' ),
					),
					'dependency'  => array (
						'show' => array (
							'qodef_blog_single_post_template' => array (
								'values'        => 'info-below-image',
								'default_value' => '',
							),
						),
					),
				)
			);

			$tab -> add_field_element(
				array (
					'field_type'    => 'yesno',
					'name'          => 'qodef_blog_single_featured_image_parallax',
					'title'         => esc_html__( 'Parallax Featured Image', 'micdrop-core' ),
					'description'   => esc_html__( 'Enabling this option will set parallax featured image behavior', 'micdrop-core' ),
					'default_value' => 'no',
					'dependency'  => array (
						'show' => array (
							'qodef_blog_single_post_template' => array (
								'values'        => 'info-below-image',
								'default_value' => '',
							),
						),
					),
				)
			);

			$tab -> add_field_element(
				array (
					'field_type'  => 'select',
					'name'        => 'qodef_blog_single_enable_page_title',
					'title'       => esc_html__( 'Enable Page Title', 'micdrop-core' ),
					'description' => esc_html__( 'Use this option to enable/disable page title on blog single', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'no_yes' ),
				)
			);

			$tab -> add_field_element(
				array (
					'field_type'    => 'select',
					'name'          => 'qodef_blog_single_set_post_title_in_title_area',
					'title'         => esc_html__( 'Show Post Title in Title Area', 'micdrop-core' ),
					'description'   => esc_html__( 'Enabling this option will show post title in title area on single post pages', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
					'dependency'    => array (
						'hide' => array (
							'qodef_blog_single_enable_page_title' => array (
								'values'        => 'no',
								'default_value' => '',
							),
						),
					),
				)
			);

			$tab -> add_field_element(
				array (
					'field_type'  => 'select',
					'name'        => 'qodef_blog_single_sidebar_layout',
					'title'       => esc_html__( 'Sidebar Layout', 'micdrop-core' ),
					'description' => esc_html__( 'Choose default sidebar layout for blog single', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'sidebar_layouts' ),
				)
			);

			$custom_sidebars = micdrop_core_get_custom_sidebars();
			if ( ! empty( $custom_sidebars ) && count( $custom_sidebars ) > 1 ) {
				$tab -> add_field_element(
					array (
						'field_type'  => 'select',
						'name'        => 'qodef_blog_single_custom_sidebar',
						'title'       => esc_html__( 'Custom Sidebar', 'micdrop-core' ),
						'description' => esc_html__( 'Choose a custom sidebar to display on blog single', 'micdrop-core' ),
						'options'     => $custom_sidebars,
					)
				);
			}

			$tab -> add_field_element(
				array (
					'field_type'  => 'select',
					'name'        => 'qodef_blog_single_sidebar_grid_gutter',
					'title'       => esc_html__( 'Set Grid Gutter', 'micdrop-core' ),
					'description' => esc_html__( 'Choose grid gutter size to set space between content and sidebar for blog single', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'items_space' ),
				)
			);
		}
	}

	add_action( 'micdrop_core_action_after_blog_single_options_map', 'micdrop_core_add_blog_single_options' );
}
