<?php

if ( ! function_exists( 'micdrop_core_add_blog_list_shortcode' ) ) {
	/**
	 * Function that isadding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_blog_list_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Blog_List_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_blog_list_shortcode' );
}

if ( class_exists( 'MicdropCore_List_Shortcode' ) ) {
	class MicdropCore_Blog_List_Shortcode extends MicdropCore_List_Shortcode {

		public function __construct() {
			$this->set_post_type( 'post' );
			$this->set_post_type_taxonomy( 'category' );
			$this->set_post_type_additional_taxonomies( array( 'post_tag' ) );
			$this->set_layouts( apply_filters( 'micdrop_core_filter_blog_list_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'micdrop_core_filter_blog_list_extra_options', array() ) );
			$this->set_hover_animation_options( apply_filters( 'micdrop_core_filter_blog_list_hover_animation_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_INC_URL_PATH . '/blog/shortcodes/blog-list' );
			$this->set_base( 'micdrop_core_blog_list' );
			$this->set_name( esc_html__( 'Blog List', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays list of blog posts', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_scripts(
				apply_filters( 'micdrop_core_filter_blog_list_register_scripts', array() )
			);
			$this->set_necessary_styles(
				apply_filters( 'micdrop_core_filter_blog_list_register_styles', array() )
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->map_list_options();
			$this->map_query_options();
			$this->map_layout_options(
				array(
					'layouts'          => $this->get_layouts(),
					'hover_animations' => $this->get_hover_animation_options(),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'video_post_format_media',
					'title'         => esc_html__( 'Video Post Format Media', 'micdrop-core' ),
					'options'       => array(
						''               => esc_html__( 'Default', 'micdrop-core' ),
						'video'          => esc_html__( 'Video', 'micdrop-core' ),
						'featured-image' => esc_html__( 'Featured Image', 'micdrop-core' ),
					),
					'default_value' => '',
					'dependency'    => array(
						'hide' => array(
							'layout' => array(
								'values'        => apply_filters( 'micdrop_core_filter_blog_list_show_video_post_format_media_dependency', array() ),
								'default_value' => '',
							),
						),
					),
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'audio_post_format_media',
					'title'         => esc_html__( 'Audio Post Format Media', 'micdrop-core' ),
					'options'       => array(
						''               => esc_html__( 'Default', 'micdrop-core' ),
						'audio'          => esc_html__( 'Audio', 'micdrop-core' ),
						'featured-image' => esc_html__( 'Featured Image', 'micdrop-core' ),
					),
					'default_value' => '',
					'dependency'    => array(
						'hide' => array(
							'layout' => array(
								'values'        => apply_filters( 'micdrop_core_filter_blog_list_show_audio_post_format_media_dependency', array() ),
								'default_value' => '',
							),
						),
					),
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'hide_categories',
					'title'         => esc_html__( 'Hide Categories', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes' ),
					'default_value' => '',
					'dependency'    => array(
						'hide' => array(
							'layout' => array(
								'values'        => array( 'simple' ),
								'default_value' => '',
							),
						),
					),
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'hide_date',
					'title'         => esc_html__( 'Hide Date', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes' ),
					'default_value' => '',
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'hide_video_audio_post_info',
					'title'         => esc_html__( 'Hide Video/Audio Post Info', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'yes_no' ),
					'default_value' => '',
					'dependency'    => array(
						'hide' => array(
							'layout' => array(
								'values'        => apply_filters( 'micdrop_core_filter_blog_list_hide_video_audio_post_info_dependency', array() ),
								'default_value' => 'yes',
							),
						),
					),
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'excerpt_length',
					'title'      => esc_html__( 'Excerpt Length', 'micdrop-core' ),
					'group'      => esc_html__( 'Layout', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'border_top',
					'title'         => esc_html__( 'Enable border top', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes' ),
					'default_value' => '',
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'layout' => array(
								'values'        => array( 'info-left' ),
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'skin',
					'title'      => esc_html__( 'Skin', 'micdrop-core' ),
					'options'    => array(
						''     => esc_html__( 'Default', 'micdrop-core' ),
                        'light' => esc_html__( 'Light', 'micdrop-core' ),
						'dark' => esc_html__( 'Dark', 'micdrop-core' ),
					),
				)
			);
			$this->map_additional_options();
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_title',
					'title'         => esc_html__( 'Top Info Title', 'micdrop-core' ),
					'default_value' => '',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'top_info_title_tag',
					'title'         => esc_html__( 'Top Info Title Tag', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h2',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_link_text',
					'title'         => esc_html__( 'Top Info Link Text', 'micdrop-core' ),
					'default_value' => 'Show All',
					'dependency'    => array(
						'hide' => array(
							'behavior' => array(
								'values'        => 'slider',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'top_info_link_target',
					'title'         => esc_html__( 'Top Info Link Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
					'dependency'    => array(
						'hide' => array(
							'behavior' => array(
								'values'        => 'slider',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_link',
					'title'         => esc_html__( 'Top Info Link', 'micdrop-core' ),
					'default_value' => '',
					'dependency'    => array(
						'hide' => array(
							'behavior' => array(
								'values'        => 'slider',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_margin_right',
					'title'      => esc_html__( 'Title Margin Right', 'micdrop-core' ),
				)
			);
			$this->map_extra_options();
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_blog_list', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function load_assets() {
			parent::load_assets();

			$is_allowed = apply_filters( 'micdrop_core_filter_load_blog_list_assets', false, $this->get_atts() );

			if ( $is_allowed ) {
				wp_enqueue_style( 'wp-mediaelement' );
				wp_enqueue_script( 'wp-mediaelement' );
				wp_enqueue_script( 'mediaelement-vimeo' );
			}
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['post_type']       = $this->get_post_type();
			$atts['taxonomy_filter'] = $this->get_post_type_filter_taxonomy( $atts );

			// Additional query args
			$atts['additional_query_args'] = $this->get_additional_query_args( $atts );

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['query_result']   = new \WP_Query( micdrop_core_get_query_params( $atts ) );
			$atts['slider_attr']    = $this->get_slider_data( $atts );
			$atts['data_attr']      = micdrop_core_get_pagination_data( MICDROP_CORE_REL_PATH, 'blog/shortcodes', 'blog-list', 'post', $atts );

			$atts['this_shortcode'] = $this;

			return micdrop_core_get_template_part( 'blog/shortcodes/blog-list', 'templates/content', $atts['behavior'], $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-blog';

			if ( ! empty( $atts['layout'] ) && 'standard' === $atts['layout'] ) {
				$holder_classes[] = 'qodef--list';
			}

			//hide date
			if ( 'yes' === $atts['hide_date'] ) {
				$holder_classes[] = 'qodef-hide-date';
			}

			//border top
			if ( 'yes' === $atts['border_top'] ) {
				$holder_classes[] = 'qodef-blog-border-top';
			}

			//audio featured image
			if ( 'featured-image' === $atts['audio_post_format_media'] ) {
				$holder_classes[] = 'qodef-blog-audio-featured-image';
			}

			$holder_classes[] = isset( $atts['skin'] ) && ! empty( $atts['skin'] ) ? 'qodef-skin--' . $atts['skin'] : '';
			$holder_classes[] = isset( $atts['hide_video_audio_post_info'] ) && ! empty( $atts['hide_video_audio_post_info'] ) ? 'qodef-hide-video-audio-post-info--' . $atts['hide_video_audio_post_info'] : '';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-item-layout--' . $atts['layout'] : '';

			if ( 'slider' !== $atts['behavior'] && ( ! empty( $atts['top_info_title'] ) || ! empty( $atts['top_info_link_text'] ) ) ) {
				$holder_classes[] = 'qodef-top-info--yes';
			} elseif ( 'slider' === $atts['behavior'] && 'no' !== $atts['slider_navigation'] ) {
				$holder_classes[] = 'qodef-top-info--yes';
			}

			$list_classes   = $this->get_list_classes( $atts );
			$holder_classes = array_merge( $holder_classes, $list_classes );

			return implode( ' ', $holder_classes );
		}

		public function get_item_classes( $atts ) {
			$item_classes = $this->init_item_classes();

			$item_classes[] = 'qodef-blog-item';

			$list_item_classes = $this->get_list_item_classes( $atts );

			$item_classes = array_merge( $item_classes, $list_item_classes );

			return implode( ' ', $item_classes );
		}

		public function get_title_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['title_margin_right'] ) ) {
				$styles[] = 'margin-right: ' . $atts['title_margin_right'];
			}

			return $styles;
		}
	}
}
