<?php

if ( ! function_exists( 'micdrop_core_add_blog_single_variation_info_below_image' ) ) {
	function micdrop_core_add_blog_single_variation_info_below_image( $variations ) {
		$variations[ 'info-below-image' ] = esc_html__( 'Wide Blog', 'micdrop-core' );

		return $variations;
	}

	add_filter( 'micdrop_core_filter_blog_single_layout_options', 'micdrop_core_add_blog_single_variation_info_below_image' );
}

if ( ! function_exists( 'micdrop_core_disable_page_title_for_blog_single_info_below_image' ) ) {
	/**
	 * Function that disable page title area for variation
	 *
	 * @param $enable_page_title bool
	 *
	 * @return bool
	 */
	function micdrop_core_disable_page_title_for_blog_single_info_below_image( $enable_page_title ) {
		$template = micdrop_core_get_post_value_through_levels( 'qodef_blog_single_post_template' );

		if ( is_singular( 'post' ) && 'info-below-image' === $template ) {
			$enable_page_title = true;
		}

		return $enable_page_title;
	}

	add_filter( 'micdrop_filter_enable_page_title', 'micdrop_core_disable_page_title_for_blog_single_info_below_image' );
}

if ( ! function_exists( 'micdrop_core_blog_single_info_below_image_media' ) ) {
	/**
	 * Function that load media part template
	 *
	 */
	function micdrop_core_blog_single_info_below_image_media() {
		$params   = array();
		$template = micdrop_core_get_post_value_through_levels( 'qodef_blog_single_post_template' );

		if ( is_singular( 'post' ) && 'info-below-image' === $template ) {
			$featured_image_parallax = micdrop_core_get_post_value_through_levels( 'qodef_blog_single_featured_image_parallax' );
			$dark_skin               = micdrop_core_get_post_value_through_levels( 'qodef_blog_single_dark_skin' );

			$params['featured_image_parallax'] = $featured_image_parallax;
			$params['holder_classes']          = array(
				'qodef-e',
			);

			$params['holder_classes'][]  = ( 'yes' === $featured_image_parallax ) ? 'qodef-parallax' : '';
			$params['holder_classes'][]  = ( 'yes' === $dark_skin ) ? 'qodef-skin--dark' : '';
			$params['content_classes']   = array(
				'qodef-e-content',
			);
			$params['content_classes'][] = ( 'yes' === $featured_image_parallax ) ? 'qodef-parallax-content-holder' : '';

			micdrop_core_template_part( 'blog', 'single/variations/info-below-image/layout/media', '', $params );
		}
	}

	add_action( 'micdrop_action_before_page_inner', 'micdrop_core_blog_single_info_below_image_media' );
}

if ( ! function_exists( 'micdrop_core_set_blog_single_info_below_image_styles' ) ) {
	/**
	 * Function that generates blog single media inline styles
	 *
	 * @param $style string
	 *
	 * @return string
	 */
	function micdrop_core_set_blog_single_info_below_image_styles( $style ) {
		$styles = array();

		$template   = micdrop_core_get_post_value_through_levels( 'qodef_blog_single_post_template' );
		$wide_image = micdrop_core_get_post_value_through_levels( 'qodef_wide_title_image' );

		$image = ! empty( $wide_image ) ? $wide_image : get_post_thumbnail_id( '' );

		if ( is_singular( 'post' ) && 'info-below-image' === $template ) {
			$featured_image_height   = micdrop_core_get_post_value_through_levels( 'qodef_blog_single_featured_image_height' );
			$featured_image_parallax = micdrop_core_get_post_value_through_levels( 'qodef_blog_single_featured_image_parallax' );

			if ( '' !== $featured_image_height ) {
				$styles_1440 = array();
				$styles_1366 = array();
				$styles_1024 = array();
				$styles_680  = array();

				$styles['height']      = intval( $featured_image_height ) . 'px';
				$styles_1440['height'] = intval( $featured_image_height / 1.233 ) . 'px';
				$styles_1366['height'] = intval( $featured_image_height / 1.551 ) . 'px';
				$styles_1024['height'] = intval( $featured_image_height / 1.48 ) . 'px';
				$styles_680['height']  = intval( $featured_image_height / 1.296 ) . 'px';
			}

			if ( 'yes' !== $featured_image_parallax ) {
				$styles['background-image'] = 'url(' . wp_get_attachment_image_url( $image, 'full' ) . ')';
			}

			if ( ! empty( $styles ) ) {
				$style .= qode_framework_dynamic_style( '.qodef-blog--info-below-image #qodef-media', $styles );
			}

			if ( ! empty( $styles_1440 ) ) {
				$style .= qode_framework_dynamic_style_responsive( '.qodef-blog--info-below-image #qodef-media', $styles_1440, '', '1440' );
			}

			if ( ! empty( $styles_1366 ) ) {
				$style .= qode_framework_dynamic_style_responsive( '.qodef-blog--info-below-image #qodef-media', $styles_1366, '', '1366' );
			}

			if ( ! empty( $styles_1024 ) ) {
				$style .= qode_framework_dynamic_style_responsive( '.qodef-blog--info-below-image #qodef-media', $styles_1024, '', '1024' );
			}

			if ( ! empty( $styles_680 ) ) {
				$style .= qode_framework_dynamic_style_responsive( '.qodef-blog--info-below-image #qodef-media', $styles_680, '', '680' );
			}
		}

		return $style;
	}

	add_filter( 'micdrop_filter_add_inline_style', 'micdrop_core_set_blog_single_info_below_image_styles' );
}
