<?php

if ( ! function_exists( 'micdrop_core_add_general_page_meta_box' ) ) {
	/**
	 * Function that add general meta box options for this module
	 *
	 * @param object $page
	 */
	function micdrop_core_add_general_page_meta_box( $page ) {

		$general_tab = $page->add_tab_element(
			array(
				'name'        => 'tab-page',
				'icon'        => 'fa fa-cog',
				'title'       => esc_html__( 'Page Settings', 'micdrop-core' ),
				'description' => esc_html__( 'General page layout settings', 'micdrop-core' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_page_custom_css_class',
				'title'       => esc_html__( 'Page Custom CSS Class', 'micdrop-core' ),
				'description' => esc_html__( 'Set custom CSS Class to body tag', 'micdrop-core' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_main_color',
				'title'       => esc_html__( 'Main Color', 'micdrop-core' ),
				'description' => esc_html__( 'Choose the most dominant theme color', 'micdrop-core' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_additional_color',
				'title'       => esc_html__( 'Additional Color', 'micdrop-core' ),
				'description' => esc_html__( 'Choose additional theme color mostly used for borders and gray text', 'micdrop-core' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_page_background_color',
				'title'       => esc_html__( 'Page Background Color', 'micdrop-core' ),
				'description' => esc_html__( 'Set background color', 'micdrop-core' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'image',
				'name'        => 'qodef_page_background_image',
				'title'       => esc_html__( 'Page Background Image', 'micdrop-core' ),
				'description' => esc_html__( 'Set background image', 'micdrop-core' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_page_background_repeat',
				'title'       => esc_html__( 'Page Background Image Repeat', 'micdrop-core' ),
				'description' => esc_html__( 'Set background image repeat', 'micdrop-core' ),
				'options'     => array(
					''          => esc_html__( 'Default', 'micdrop-core' ),
					'no-repeat' => esc_html__( 'No Repeat', 'micdrop-core' ),
					'repeat'    => esc_html__( 'Repeat', 'micdrop-core' ),
					'repeat-x'  => esc_html__( 'Repeat-x', 'micdrop-core' ),
					'repeat-y'  => esc_html__( 'Repeat-y', 'micdrop-core' ),
				),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_page_background_size',
				'title'       => esc_html__( 'Page Background Image Size', 'micdrop-core' ),
				'description' => esc_html__( 'Set background image size', 'micdrop-core' ),
				'options'     => array(
					''        => esc_html__( 'Default', 'micdrop-core' ),
					'contain' => esc_html__( 'Contain', 'micdrop-core' ),
					'cover'   => esc_html__( 'Cover', 'micdrop-core' ),
				),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_page_background_attachment',
				'title'       => esc_html__( 'Page Background Image Attachment', 'micdrop-core' ),
				'description' => esc_html__( 'Set background image attachment', 'micdrop-core' ),
				'options'     => array(
					''       => esc_html__( 'Default', 'micdrop-core' ),
					'fixed'  => esc_html__( 'Fixed', 'micdrop-core' ),
					'scroll' => esc_html__( 'Scroll', 'micdrop-core' ),
				),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_page_content_padding',
				'title'       => esc_html__( 'Page Content Padding', 'micdrop-core' ),
				'description' => esc_html__( 'Set padding that will be applied for page content in format: top right bottom left (e.g. 10px 5px 10px 5px)', 'micdrop-core' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_page_content_padding_mobile',
				'title'       => esc_html__( 'Page Content Padding Mobile', 'micdrop-core' ),
				'description' => esc_html__( 'Set padding that will be applied for page content on mobile screens (1024px and below) in format: top right bottom left (e.g. 10px 5px 10px 5px)', 'micdrop-core' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'    => 'select',
				'name'          => 'qodef_boxed',
				'title'         => esc_html__( 'Boxed Layout', 'micdrop-core' ),
				'description'   => esc_html__( 'Set boxed layout', 'micdrop-core' ),
				'default_value' => '',
				'options'       => micdrop_core_get_select_type_options_pool( 'yes_no' ),
			)
		);

		$boxed_section = $general_tab->add_section_element(
			array(
				'name'       => 'qodef_boxed_section',
				'title'      => esc_html__( 'Boxed Layout Section', 'micdrop-core' ),
				'dependency' => array(
					'hide' => array(
						'qodef_boxed' => array(
							'values'        => 'no',
							'default_value' => '',
						),
					),
				),
			)
		);

		$boxed_section->add_field_element(
			array(
				'field_type'    => 'select',
				'name'          => 'qodef_boxed_disabled_680',
				'title'         => esc_html__( 'Disable Boxed Layout On Mobile', 'micdrop-core' ),
				'default_value' => '',
				'options'       => micdrop_core_get_select_type_options_pool( 'yes_no' ),
			)
		);

		$boxed_section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_boxed_background_color',
				'title'       => esc_html__( 'Boxed Background Color', 'micdrop-core' ),
				'description' => esc_html__( 'Set boxed background color', 'micdrop-core' ),
			)
		);

		$boxed_section->add_field_element(
			array(
				'field_type'  => 'image',
				'name'        => 'qodef_boxed_background_pattern',
				'title'       => esc_html__( 'Boxed Background Pattern', 'micdrop-core' ),
				'description' => esc_html__( 'Set boxed background pattern', 'micdrop-core' ),
			)
		);

		$boxed_section->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_boxed_background_pattern_behavior',
				'title'       => esc_html__( 'Boxed Background Pattern Behavior', 'micdrop-core' ),
				'description' => esc_html__( 'Set boxed background pattern behavior', 'micdrop-core' ),
				'options'     => array(
					''       => esc_html__( 'Default', 'micdrop-core' ),
					'fixed'  => esc_html__( 'Fixed', 'micdrop-core' ),
					'scroll' => esc_html__( 'Scroll', 'micdrop-core' ),
				),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'    => 'select',
				'name'          => 'qodef_passepartout',
				'title'         => esc_html__( 'Passepartout', 'micdrop-core' ),
				'description'   => esc_html__( 'Enabling this option will display a passepartout around website content', 'micdrop-core' ),
				'default_value' => '',
				'options'       => micdrop_core_get_select_type_options_pool( 'yes_no' ),
			)
		);

		$passepartout_section = $general_tab->add_section_element(
			array(
				'name'       => 'qodef_passepartout_section',
				'dependency' => array(
					'hide' => array(
						'qodef_passepartout' => array(
							'values'        => 'no',
							'default_value' => '',
						),
					),
				),
			)
		);

		$passepartout_section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_passepartout_color',
				'title'       => esc_html__( 'Passepartout Color', 'micdrop-core' ),
				'description' => esc_html__( 'Choose background color for passepartout', 'micdrop-core' ),
			)
		);

		$passepartout_section->add_field_element(
			array(
				'field_type'  => 'image',
				'name'        => 'qodef_passepartout_image',
				'title'       => esc_html__( 'Passepartout Background Image', 'micdrop-core' ),
				'description' => esc_html__( 'Set background image for passepartout', 'micdrop-core' ),
			)
		);

		$passepartout_section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_passepartout_size',
				'title'       => esc_html__( 'Passepartout Size', 'micdrop-core' ),
				'description' => esc_html__( 'Enter size amount for passepartout', 'micdrop-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px or %', 'micdrop-core' ),
				),
			)
		);

		$passepartout_section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_passepartout_size_responsive',
				'title'       => esc_html__( 'Passepartout Responsive Size', 'micdrop-core' ),
				'description' => esc_html__( 'Enter size amount for passepartout for smaller screens (1024px and below)', 'micdrop-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px or %', 'micdrop-core' ),
				),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_content_width',
				'title'       => esc_html__( 'Initial Width of Content', 'micdrop-core' ),
				'description' => esc_html__( 'Choose the initial width of content which is in grid (applies to pages set to "Default Template" and rows set to "In Grid")', 'micdrop-core' ),
				'options'     => micdrop_core_get_select_type_options_pool( 'content_width' ),
			)
		);

		$general_tab->add_field_element(
			array(
				'field_type'    => 'yesno',
				'default_value' => 'no',
				'name'          => 'qodef_content_behind_header',
				'title'         => esc_html__( 'Always put content behind header', 'micdrop-core' ),
				'description'   => esc_html__( 'Enabling this option will put page content behind page header', 'micdrop-core' ),
			)
		);

		// Hook to include additional options after module options
		do_action( 'micdrop_core_action_after_general_page_meta_box_map', $general_tab );
	}

	add_action( 'micdrop_core_action_after_general_meta_box_map', 'micdrop_core_add_general_page_meta_box', 9 );
}

if ( ! function_exists( 'micdrop_core_add_general_page_meta_box_callback' ) ) {
	/**
	 * Function that set current meta box callback as general callback functions
	 *
	 * @param array $callbacks
	 *
	 * @return array
	 */
	function micdrop_core_add_general_page_meta_box_callback( $callbacks ) {
		$callbacks['page'] = 'micdrop_core_add_general_page_meta_box';

		return $callbacks;
	}

	add_filter( 'micdrop_core_filter_general_meta_box_callbacks', 'micdrop_core_add_general_page_meta_box_callback' );
}
