<?php

abstract class MicdropCore_Header {
	private $overriding_whole_header = false;
	private $layout;
	private $layout_slug = '';
	private $search_layout;
	protected $default_header_height;
	protected $header_height;

	public function __construct() {
		$this->set_header_height();

		add_action( 'micdrop_core_action_before_main_css', array( $this, 'enqueue_assets' ) );
		add_action( 'micdrop_core_action_before_main_css', array( $this, 'enqueue_additional_assets' ) );
		add_filter( 'micdrop_filter_localize_main_js', array( $this, 'set_global_javascript_variables' ) );
		add_filter( 'micdrop_core_filter_content_margin', array( $this, 'get_content_margin' ) );
		add_filter( 'micdrop_core_filter_title_padding', array( $this, 'get_title_padding' ) );
		add_filter( 'micdrop_filter_add_inline_style', array( $this, 'set_inline_header_styles' ) );
		add_filter( 'micdrop_filter_header_inner_class', array( $this, 'set_header_inner_classes' ), 10, 2 );
		add_filter( 'micdrop_core_filter_nav_menu_header_selector', array( $this, 'set_nav_menu_header_selector' ) );
		add_filter( 'micdrop_core_filter_nav_menu_narrow_header_selector', array( $this, 'set_nav_menu_narrow_header_selector' ) );
	}

	public function get_layout() {
		return $this->layout;
	}

	public function set_layout( $layout ) {
		$this->layout = $layout;
	}

	public function get_layout_slug() {
		return $this->layout_slug;
	}

	public function set_layout_slug( $layout_slug ) {
		$this->layout_slug = $layout_slug;
	}

	public function get_search_layout() {
		return $this->search_layout;
	}

	public function set_search_layout( $search_layout ) {
		$this->search_layout = $search_layout;
	}

	public function is_whole_header_override() {
		return $this->overriding_whole_header;
	}

	public function set_overriding_whole_header( $overriding_whole_header ) {
		$this->overriding_whole_header = $overriding_whole_header;
	}

	/**
	 * swap dash with underscore
	 *
	 * header slug must be same as folder name, we're using dash as delimiter
	 * options and metaboxes, we're using underscore as delimiter
	 *
	 * @return mixed
	 */
	public function get_formatted_layout() {
		return str_replace( '-', '_', $this->get_layout() );
	}

	public function load_template( $parameters = array() ) {
		$parameters = apply_filters( 'micdrop_core_filter_header_template', $parameters );

		return micdrop_core_get_template_part( 'header/layouts/' . $this->get_layout(), 'templates/' . $this->get_layout(), $this->get_layout_slug(), $parameters );
	}

	public function enqueue_assets() {
		wp_enqueue_script( 'hoverIntent' );
	}

	public function enqueue_additional_assets() {
		return false;
	}

	public function set_global_javascript_variables( $global_vars ) {
		$global_vars['headerHeight'] = $this->header_height;

		return $global_vars;
	}

	public function get_header_transparency() {
		$background_color = micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_header_background_color' );

		if ( ! empty( $background_color ) ) {
			return ! preg_match( '/^#[a-f0-9]{6}$/i', $background_color ); // hex color is valid
		}

		return false;
	}

	public function content_behind_header() {
		return 'yes' === micdrop_core_get_post_value_through_levels( 'qodef_content_behind_header' );
	}

	public function get_content_margin( $margin ) {

		if ( $this->get_header_transparency() || $this->content_behind_header() ) {
			$margin += $this->header_height;
		}

		return $margin;
	}

	public function get_title_padding( $padding ) {

		if ( $this->get_header_transparency() || $this->content_behind_header() ) {
			$padding += $this->header_height;
		}

		return $padding;
	}

	function set_header_height() {
		$header_height = micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_header_height' );
		$header_height = ! empty( $header_height ) ? intval( $header_height ) : $this->default_header_height;

		$this->header_height = apply_filters( 'micdrop_core_filter_set_header_height', $header_height );
	}

	function set_header_inner_classes( $class, $layout ) {
		// Check is content in grid
		$class[] = 'yes' === micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_header_in_grid' ) ? 'qodef-content-grid' : '';

		// Check header skin
		$header_skin = micdrop_core_get_post_value_through_levels( 'qodef_header_skin' );
		if ( ! empty( $header_skin ) && 'none' !== $header_skin && 'default' === $layout && ! is_tax( 'artist' ) && ! is_tax( 'event-types' ) && ! is_product_tag() && ! is_product_category() ) {
			$class[] = 'qodef-skin--' . $header_skin;
		}

		/* artist taxonomy header skin */
		$queried_tax             = get_queried_object();
		$tax_id                  = isset( $queried_tax->term_id ) ? $queried_tax->term_id : '';
		$artist_header_skin_meta = get_term_meta( $tax_id, 'qodef_artist_header_skin', true );
		$artist_header_skin      = ! empty( $artist_header_skin_meta ) ? $artist_header_skin_meta : '';

		if ( is_tax( 'artist' ) ) {
			if ( ! empty( $artist_header_skin ) && 'default' === $layout ) {
				$class[] = 'qodef-skin--' . $artist_header_skin;
			} elseif ( ! empty( $header_skin ) && 'none' !== $header_skin && 'default' === $layout ) {
				$class[] = 'qodef-skin--' . $header_skin;
			}
		}

		/* event-types taxonomy header skin */
		$queried_tax                  = get_queried_object();
		$tax_id                       = isset( $queried_tax->term_id ) ? $queried_tax->term_id : '';
		$event_types_header_skin_meta = get_term_meta( $tax_id, 'qodef_event_types_header_skin', true );
		$event_types_header_skin      = ! empty( $event_types_header_skin_meta ) ? $event_types_header_skin_meta : '';

		if ( is_tax( 'event-types' ) ) {
			if ( ! empty( $event_types_header_skin ) && 'default' === $layout ) {
				$class[] = 'qodef-skin--' . $event_types_header_skin;
			} elseif ( ! empty( $header_skin ) && 'none' !== $header_skin && 'default' === $layout ) {
				$class[] = 'qodef-skin--' . $header_skin;
			}
		}

		/* product archive list header skin */
		$product_archive_list_header_skin_options = micdrop_core_get_post_value_through_levels( 'qodef_woo_product_archive_header_skin' );
		$product_archive_list_header_skin         = ! empty( $product_archive_list_header_skin_options ) ? $product_archive_list_header_skin_options : '';

		if(function_exists('is_product_tag')){
			if ( is_product_tag() || is_product_category() ) {
				if ( ! empty( $product_archive_list_header_skin ) && 'default' === $layout ) {
					$class[] = 'qodef-skin--' . $product_archive_list_header_skin;
				} elseif ( ! empty( $header_skin ) && 'none' !== $header_skin && 'default' === $layout ) {
					$class[] = 'qodef-skin--' . $header_skin;
				}
			}
		}
		
		// minimal header opener in center
		if ( 'minimal' === $this->get_formatted_layout() ) {
			$class[] = 'yes' === micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_header_opener_in_center' ) ? 'qodef-minimal-header-opener-in-center' : '';
		}

		// hide widget when fullscreen is open
		if ( 'minimal' === $this->get_formatted_layout() ) {
			$class[] = 'yes' === micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_hide_widget_on_fullscreen_menu' ) ? 'qodef-minimal-header-hide-widget-open-menu' : '';
		}

		return $class;
	}

	public function set_inline_header_styles( $style ) {
		$styles = array();

		$height           = micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_header_height' );
		$background_color = micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_header_background_color' );

		if ( ! empty( $height ) ) {
			$styles['height'] = intval( $height ) . 'px';
		}

		if ( ! empty( $background_color ) ) {
			$styles['background-color'] = $background_color;
		}

		if ( ! empty( $styles ) ) {
			$style .= qode_framework_dynamic_style( '.qodef-header--' . $this->get_layout() . ' #qodef-page-header', $styles );
		}

		$inner_styles = array();

		$side_padding = micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_header_side_padding' );
		$border_color = micdrop_core_get_post_value_through_levels( 'qodef_' . $this->get_formatted_layout() . '_header_border_color' );

		if ( '' !== $side_padding ) {
			if ( qode_framework_string_ends_with_space_units( $side_padding ) ) {
				$inner_styles['padding-left']  = $side_padding;
				$inner_styles['padding-right'] = $side_padding;
			} else {
				$inner_styles['padding-left']  = intval( $side_padding ) . 'px';
				$inner_styles['padding-right'] = intval( $side_padding ) . 'px';
			}
		}

		if ( ! empty( $inner_styles ) ) {
			$style .= qode_framework_dynamic_style( '.qodef-header--' . $this->get_layout() . ' #qodef-page-header-inner', $inner_styles );

			// applay same padding to breadcrumbs
			$style .= qode_framework_dynamic_style( '.qodef-page-title .qodef-m-content.qodef-content-full-width', $inner_styles );
		}

		$inner_after_styles = array();

		if ( '' !== $side_padding ) {
			if ( qode_framework_string_ends_with_space_units( $side_padding ) ) {
				$inner_after_styles['clip-path'] = 'inset(0 ' . $side_padding . ')';
			} else {
				$inner_after_styles['clip-path'] = 'inset(0 ' . intval( $side_padding ) . 'px)';
			}
		}

		if ( ! empty( $border_color ) ) {
			$inner_after_styles['background-color'] = $border_color;
			$inner_after_styles['height']           = '1px';
		}

		if ( ! empty( $inner_after_styles ) ) {
			$style .= qode_framework_dynamic_style( '.qodef-header--' . $this->get_layout() . ' #qodef-page-header-inner:after', $inner_after_styles );
		}

		return $style;
	}

	public function set_nav_menu_header_selector( $selector ) {
		return $selector;
	}

	public function set_nav_menu_narrow_header_selector( $selector ) {
		return $selector;
	}
}
