<?php

if ( ! function_exists( 'micdrop_core_add_standard_header_options' ) ) {
	/**
	 * Function that add additional header layout options
	 *
	 * @param object $page
	 * @param array $general_header_tab
	 */
	function micdrop_core_add_standard_header_options( $page, $general_header_tab ) {

		$section = $general_header_tab->add_section_element(
			array(
				'name'        => 'qodef_standard_header_section',
				'title'       => esc_html__( 'Standard Header', 'micdrop-core' ),
				'description' => esc_html__( 'Standard header settings', 'micdrop-core' ),
				'dependency'  => array(
					'show' => array(
						'qodef_header_layout' => array(
							'values'        => 'standard',
							'default_value' => '',
						),
					),
				),
			)
		);

		$section->add_field_element(
			array(
				'field_type'    => 'yesno',
				'name'          => 'qodef_standard_header_in_grid',
				'title'         => esc_html__( 'Content in Grid', 'micdrop-core' ),
				'description'   => esc_html__( 'Set content to be in grid', 'micdrop-core' ),
				'default_value' => 'no',
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_standard_header_height',
				'title'       => esc_html__( 'Header Height', 'micdrop-core' ),
				'description' => esc_html__( 'Enter header height', 'micdrop-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px', 'micdrop-core' ),
				),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_standard_header_side_padding',
				'title'       => esc_html__( 'Header Side Padding', 'micdrop-core' ),
				'description' => esc_html__( 'Enter side padding for header area', 'micdrop-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px or %', 'micdrop-core' ),
				),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_standard_header_background_color',
				'title'       => esc_html__( 'Header Background Color', 'micdrop-core' ),
				'description' => esc_html__( 'Enter header background color', 'micdrop-core' ),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_standard_header_border_color',
				'title'       => esc_html__( 'Header Border Color', 'micdrop-core' ),
				'description' => esc_html__( 'Enter header border color', 'micdrop-core' ),
			)
		);

		$section->add_field_element(
			array(
				'field_type'    => 'select',
				'name'          => 'qodef_standard_header_menu_position',
				'title'         => esc_html__( 'Menu position', 'micdrop-core' ),
				'default_value' => 'right',
				'options'       => array(
					'left'   => esc_html__( 'Left', 'micdrop-core' ),
					'center' => esc_html__( 'Center', 'micdrop-core' ),
					'right'  => esc_html__( 'Right', 'micdrop-core' ),
				),
			)
		);
	}

	add_action( 'micdrop_core_action_after_header_options_map', 'micdrop_core_add_standard_header_options', 10, 2 );
}
