<?php

if ( ! function_exists( 'micdrop_core_add_sticky_header_options' ) ) {
	/**
	 * Function that add additional header layout global options
	 *
	 * @param object $page
	 * @param object $section
	 */
	function micdrop_core_add_sticky_header_options( $page, $section ) {

		$sticky_section = $section->add_section_element(
			array(
				'name'       => 'qodef_sticky_header_section',
				'dependency' => array(
					'show' => array(
						'qodef_header_scroll_appearance' => array(
							'values'        => 'sticky',
							'default_value' => '',
						),
					),
				),
			)
		);

		$sticky_section->add_field_element(
			array(
				'field_type'    => 'select',
				'name'          => 'qodef_sticky_header_appearance',
				'title'         => esc_html__( 'Sticky Header Appearance', 'micdrop-core' ),
				'description'   => esc_html__( 'Select the appearance of sticky header when you scrolling the page', 'micdrop-core' ),
				'options'       => array(
					'down' => esc_html__( 'Show Sticky on Scroll Down/Up', 'micdrop-core' ),
					'up'   => esc_html__( 'Show Sticky on Scroll Up', 'micdrop-core' ),
				),
				'default_value' => 'down',
			)
		);

		$sticky_section->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_sticky_header_skin',
				'title'       => esc_html__( 'Sticky Header Skin', 'micdrop-core' ),
				'description' => esc_html__( 'Choose a predefined sticky header style for header elements', 'micdrop-core' ),
				'options'     => array(
					'none'  => esc_html__( 'None', 'micdrop-core' ),
					'light' => esc_html__( 'Light', 'micdrop-core' ),
					'dark'  => esc_html__( 'Dark', 'micdrop-core' ),
				),
			)
		);

		$sticky_section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_sticky_header_scroll_amount',
				'title'       => esc_html__( 'Sticky Scroll Amount', 'micdrop-core' ),
				'description' => esc_html__( 'Enter scroll amount for sticky header to appear', 'micdrop-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px', 'micdrop-core' ),
				),
			)
		);

		$sticky_section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_sticky_header_side_padding',
				'title'       => esc_html__( 'Sticky Header Side Padding', 'micdrop-core' ),
				'description' => esc_html__( 'Enter side padding for sticky header area', 'micdrop-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px or %', 'micdrop-core' ),
				),
			)
		);

		$sticky_section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_sticky_header_background_color',
				'title'       => esc_html__( 'Sticky Header Background Color', 'micdrop-core' ),
				'description' => esc_html__( 'Enter sticky header background color', 'micdrop-core' ),
			)
		);
	}

	add_action( 'micdrop_core_action_after_header_scroll_appearance_options_map', 'micdrop_core_add_sticky_header_options', 10, 2 );
}

if ( ! function_exists( 'micdrop_core_add_sticky_header_logo_options' ) ) {
	/**
	 * Function that add additional header logo options
	 *
	 * @param object $page
	 * @param array $header_tab
	 * @param array $logo_image_section
	 */
	function micdrop_core_add_sticky_header_logo_options( $page, $header_tab, $logo_image_section ) {

		if ( $header_tab ) {
			$logo_image_section->add_field_element(
				array(
					'field_type'  => 'image',
					'name'        => 'qodef_logo_sticky',
					'title'       => esc_html__( 'Logo - Sticky', 'micdrop-core' ),
					'description' => esc_html__( 'Choose sticky logo image', 'micdrop-core' ),
					'multiple'    => 'no',
				)
			);
		}
	}

	add_action( 'micdrop_core_action_after_header_logo_image_section_options_map', 'micdrop_core_add_sticky_header_logo_options', 10, 3 );
}
