<?php

if ( ! function_exists( 'micdrop_core_add_page_mobile_header_meta_box' ) ) {
	/**
	 * Function that add general meta box options for this module
	 *
	 * @param object $page
	 */
	function micdrop_core_add_page_mobile_header_meta_box( $page ) {

		if ( $page ) {
			$mobile_header_tab = $page->add_tab_element(
				array(
					'name'        => 'tab-mobile-header',
					'icon'        => 'fa fa-cog',
					'title'       => esc_html__( 'Mobile Header Settings', 'micdrop-core' ),
					'description' => esc_html__( 'Mobile header layout settings', 'micdrop-core' ),
				)
			);

			$mobile_header_tab->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_mobile_header_layout',
					'title'       => esc_html__( 'Mobile Header Layout', 'micdrop-core' ),
					'description' => esc_html__( 'Choose a mobile header layout to set for your website', 'micdrop-core' ),
					'args'        => array( 'images' => true ),
					'options'     => micdrop_core_header_radio_to_select_options( apply_filters( 'micdrop_core_filter_mobile_header_layout_option', array() ) ),
				)
			);

			$mobile_header_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_mobile_header_in_grid',
					'title'         => esc_html__( 'Content in Grid', 'micdrop-core' ),
					'description'   => esc_html__( 'Set content to be in grid', 'micdrop-core' ),
					'default_value' => '',
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes' ),
				)
			);

			$mobile_header_tab->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_mobile_header_skin',
					'title'       => esc_html__( 'Mobile Header Skin', 'micdrop-core' ),
					'description' => esc_html__( 'Choose a predefined header style for header elements', 'micdrop-core' ),
					'options'     => array(
						''      => esc_html__( 'Default', 'micdrop-core' ),
						'none'  => esc_html__( 'None', 'micdrop-core' ),
						'light' => esc_html__( 'Light', 'micdrop-core' ),
						'dark'  => esc_html__( 'Dark', 'micdrop-core' ),
					),
				)
			);

			// Hook to include additional options after module options
			do_action( 'micdrop_core_action_after_page_mobile_header_meta_map', $mobile_header_tab );
		}
	}

	add_action( 'micdrop_core_action_after_general_meta_box_map', 'micdrop_core_add_page_mobile_header_meta_box' );
}

if ( ! function_exists( 'micdrop_core_add_general_mobile_header_meta_box_callback' ) ) {
	/**
	 * Function that set current meta box callback as general callback functions
	 *
	 * @param array $callbacks
	 *
	 * @return array
	 */
	function micdrop_core_add_general_mobile_header_meta_box_callback( $callbacks ) {
		$callbacks['mobile-header'] = 'micdrop_core_add_page_mobile_header_meta_box';

		return $callbacks;
	}

	add_filter( 'micdrop_core_filter_general_meta_box_callbacks', 'micdrop_core_add_general_mobile_header_meta_box_callback' );
}
