<?php

if ( ! function_exists( 'micdrop_core_register_albums_for_meta_options' ) ) {
	/**
	 * Function that add custom post type into global meta box allowed items array for saving meta box options
	 *
	 * @param array $post_types
	 *
	 * @return array
	 */
	function micdrop_core_register_albums_for_meta_options( $post_types ) {
		$post_types[] = 'album';

		return $post_types;
	}

	add_filter( 'qode_framework_filter_meta_box_save', 'micdrop_core_register_albums_for_meta_options' );
	add_filter( 'qode_framework_filter_meta_box_remove', 'micdrop_core_register_albums_for_meta_options' );
}

if ( ! function_exists( 'micdrop_core_add_albums_custom_post_type' ) ) {
	/**
	 * Function that adds custom post type
	 *
	 * @param array $cpts
	 *
	 * @return array
	 */
	function micdrop_core_add_albums_custom_post_type( $cpts ) {
		$cpts[] = 'MicdropCore_Album_CPT';

		return $cpts;
	}

	add_filter( 'micdrop_core_filter_register_custom_post_types', 'micdrop_core_add_albums_custom_post_type' );
}

if ( class_exists( 'QodeFrameworkCustomPostType' ) ) {
	class MicdropCore_Album_CPT extends QodeFrameworkCustomPostType {

		public function map_post_type() {
			$name = esc_html__( 'Album', 'micdrop-core' );
			$this->set_base( 'album' );
			$this->set_menu_position( 15 );
			$this->set_menu_icon( 'dashicons-format-audio' );
			$this->set_slug( 'album' );
			$this->set_name( $name );
			$this->set_path( MICDROP_CORE_CPT_PATH . '/album' );
			$this->set_labels(
				array(
					'name'          => esc_html__( 'Micdrop Album', 'micdrop-core' ),
					'singular_name' => esc_html__( 'Album', 'micdrop-core' ),
					'add_item'      => esc_html__( 'New Album', 'micdrop-core' ),
					'add_new_item'  => esc_html__( 'Add New Album', 'micdrop-core' ),
					'edit_item'     => esc_html__( 'Edit Album', 'micdrop-core' ),
				)
			);
			$this->set_supports(
				array(
					'title',
					'thumbnail',
					'editor',
					'excerpt',
					'page-attributes',
				)
			);
			$this->add_post_taxonomy(
				array(
					'base'          => 'genre',
					'slug'          => 'genre',
					'singular_name' => esc_html__( 'Genre', 'micdrop-core' ),
					'plural_name'   => esc_html__( 'Genres', 'micdrop-core' ),
				)
			);
			$this->add_post_taxonomy(
				array(
					'base'          => 'album-label',
					'slug'          => 'album-label',
					'singular_name' => esc_html__( 'Label', 'micdrop-core' ),
					'plural_name'   => esc_html__( 'Labels', 'micdrop-core' ),
				)
			);
			$this->add_post_taxonomy(
				array(
					'base'          => 'artist',
					'slug'          => 'artist',
					'singular_name' => esc_html__( 'Artist', 'micdrop-core' ),
					'plural_name'   => esc_html__( 'Artists', 'micdrop-core' ),
				)
			);
		}
	}
}
