<?php

if ( ! function_exists( 'micdrop_core_add_album_options' ) ) {
	/**
	 * Function that add general options for this module
	 */
	function micdrop_core_add_album_options() {
		$qode_framework    = qode_framework_get_framework_root();
		$list_item_layouts = apply_filters( 'micdrop_core_filter_album_list_layouts', array() );
		$options_map       = micdrop_core_get_variations_options_map( $list_item_layouts );

		$page = $qode_framework->add_options_page(
			array(
				'scope'       => MICDROP_CORE_OPTIONS_NAME,
				'type'        => 'admin',
				'slug'        => 'album',
				'layout'      => 'tabbed',
				'icon'        => 'fa fa-cog',
				'title'       => esc_html__( 'Album', 'micdrop-core' ),
				'description' => esc_html__( 'Global Album Options', 'micdrop-core' ),
			)
		);

		if ( $page ) {

			// Hook to include additional options before module options
			do_action( 'micdrop_core_action_before_album_options_map', $page );

			$single_tab = $page->add_tab_element(
				array(
					'name'        => 'tab-single',
					'icon'        => 'fa fa-cog',
					'title'       => esc_html__( 'Single Settings', 'micdrop-core' ),
					'description' => esc_html__( 'Settings related to album single pages', 'micdrop-core' ),
				)
			);

			$single_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_single_layout',
					'title'         => esc_html__( 'Single Layout', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose default layout for album single', 'micdrop-core' ),
					'default_value' => apply_filters( 'micdrop_core_filter_album_single_layout_default_value', '' ),
					'options'       => apply_filters( 'micdrop_core_filter_album_single_layout_options', array() ),
				)
			);

			// Hook to include additional options after single module options
			do_action( 'micdrop_core_action_after_album_options_single', $single_tab );

			$list_tab = $page->add_tab_element(
				array(
					'name'        => 'tab-list',
					'icon'        => 'fa fa-cog',
					'title'       => esc_html__( 'List Settings', 'micdrop-core' ),
					'description' => esc_html__( 'Settings related to album archive pages', 'micdrop-core' ),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_archive_item_layout',
					'title'         => esc_html__( 'Item Layout', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose layout for list item on archive lists', 'micdrop-core' ),
					'options'       => $list_item_layouts,
					'default_value' => 'standard',
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_album_archive_item_hover_gradient',
					'title'      => esc_html__( 'Album Hover Gradient', 'micdrop-core' ),
					'options'    => array(
						'default'    => esc_html__( 'Default', 'micdrop-core' ),
						'vibrant'    => esc_html__( 'Vibrant', 'micdrop-core' ),
						'monochrome' => esc_html__( 'Monochrome', 'micdrop-core' ),
					),
					'dependency' => array(
						'show' => array(
							'qodef_album_archive_item_layout' => array(
								'values'        => 'standard',
								'default_value' => '',
							),
						),
					),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_album_archive_behavior',
					'title'       => esc_html__( 'List Appearance', 'micdrop-core' ),
					'description' => esc_html__( 'Choose an appearance style for archive lists', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'list_behavior' ),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_archive_item_enable_stores',
					'title'         => esc_html__( 'Enable Platform Buttons', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'yes',
					'dependency'    => array(
						'show' => array(
							'qodef_album_archive_behavior' => array(
								'values'        => array( 'columns', '' ),
								'default_value' => '',
							),
						),
					),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_album_archive_columns',
					'title'       => esc_html__( 'Number of Columns', 'micdrop-core' ),
					'description' => esc_html__( 'Choose number of columns for archive lists', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'columns_number' ),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_album_archive_space',
					'title'       => esc_html__( 'Space Between Items', 'micdrop-core' ),
					'description' => esc_html__( 'Choose space between items for archive lists', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'items_space' ),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_album_archive_columns_responsive',
					'title'       => esc_html__( 'Columns Responsive', 'micdrop-core' ),
					'description' => esc_html__( 'Choose whether you wish to use predefined column number responsive settings, or to set column numbers for each responsive stage individually', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'columns_responsive' ),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_archive_columns_1440',
					'title'         => esc_html__( 'Number of Columns 1367px - 1440px', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose number of columns for screens between 1367 and 1440 px for archive lists', 'micdrop-core' ),
					'default_value' => '3',
					'options'       => micdrop_core_get_select_type_options_pool( 'columns_number' ),
					'dependency'    => array(
						'show' => array(
							'qodef_album_archive_columns_responsive' => array(
								'values'        => 'custom',
								'default_value' => '',
							),
						),
					),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_archive_columns_1366',
					'title'         => esc_html__( 'Number of Columns 1025px - 1366px', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose number of columns for screens between 1025 and 1366 px for archive lists', 'micdrop-core' ),
					'default_value' => '3',
					'options'       => micdrop_core_get_select_type_options_pool( 'columns_number' ),
					'dependency'    => array(
						'show' => array(
							'qodef_album_archive_columns_responsive' => array(
								'values'        => 'custom',
								'default_value' => '',
							),
						),
					),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_archive_columns_1024',
					'title'         => esc_html__( 'Number of Columns 769px - 1024px', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose number of columns for screens between 769 and 1024 px for archive lists', 'micdrop-core' ),
					'default_value' => '3',
					'options'       => micdrop_core_get_select_type_options_pool( 'columns_number' ),
					'dependency'    => array(
						'show' => array(
							'qodef_album_archive_columns_responsive' => array(
								'values'        => 'custom',
								'default_value' => '',
							),
						),
					),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_archive_columns_768',
					'title'         => esc_html__( 'Number of Columns 681px - 768px', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose number of columns for screens between 681 and 768 px for archive lists', 'micdrop-core' ),
					'default_value' => '3',
					'options'       => micdrop_core_get_select_type_options_pool( 'columns_number' ),
					'dependency'    => array(
						'show' => array(
							'qodef_album_archive_columns_responsive' => array(
								'values'        => 'custom',
								'default_value' => '',
							),
						),
					),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_archive_columns_680',
					'title'         => esc_html__( 'Number of Columns 481px - 680px', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose number of columns for screens between 481 and 680 px for archive lists', 'micdrop-core' ),
					'default_value' => '3',
					'options'       => micdrop_core_get_select_type_options_pool( 'columns_number' ),
					'dependency'    => array(
						'show' => array(
							'qodef_album_archive_columns_responsive' => array(
								'values'        => 'custom',
								'default_value' => '',
							),
						),
					),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_archive_columns_480',
					'title'         => esc_html__( 'Number of Columns 0 - 480px', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose number of columns for screens between 0 and 480 px for archive lists', 'micdrop-core' ),
					'default_value' => '3',
					'options'       => micdrop_core_get_select_type_options_pool( 'columns_number' ),
					'dependency'    => array(
						'show' => array(
							'qodef_album_archive_columns_responsive' => array(
								'values'        => 'custom',
								'default_value' => '',
							),
						),
					),
				)
			);

			// Hook to include additional options after list module options
			do_action( 'micdrop_core_action_after_album_options_single', $list_tab );

			// Hook to include additional options after module options
			do_action( 'micdrop_core_action_after_album_options_map', $page );
		}
	}

	add_action( 'micdrop_core_action_default_options_init', 'micdrop_core_add_album_options', micdrop_core_get_admin_options_map_position( 'album' ) );
}
