<?php

if ( ! function_exists( 'micdrop_core_add_album_single_meta_box' ) ) {
	/**
	 * Function that add general options for this module
	 */
	function micdrop_core_add_album_single_meta_box() {
		$qode_framework = qode_framework_get_framework_root();

		$page = $qode_framework->add_options_page(
			array(
				'scope'  => array( 'album' ),
				'type'   => 'meta',
				'slug'   => 'album',
				'title'  => esc_html__( 'Album', 'micdrop-core' ),
				'layout' => 'tabbed',
			)
		);

		if ( $page ) {

			/* General sections */

			$general_section = $page->add_tab_element(
				array(
					'name'        => 'tab-general',
					'title'       => esc_html__( 'General Settings', 'micdrop-core' ),
					'description' => esc_html__( 'General information about album single.', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_album_single_layout',
					'title'       => esc_html__( 'Album Layout', 'micdrop-core' ),
					'description' => esc_html__( 'Choose layout for album single page', 'micdrop-core' ),
					'options'     => apply_filters( 'micdrop_core_filter_album_single_layout_options', array( '' => esc_html__( 'Default', 'micdrop-core' ) ) ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'date',
					'name'        => 'qodef_album_single_release_date',
					'title'       => esc_html__( 'Release Date', 'micdrop-core' ),
					'description' => esc_html__( 'Enter album release date', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_album_single_video_link',
					'title'       => esc_html__( 'Latest Video Link', 'micdrop-core' ),
					'description' => esc_html__( 'Enter video link', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_masonry_image_dimension_album',
					'title'       => esc_html__( 'Image Dimension', 'micdrop-core' ),
					'description' => esc_html__( 'Choose an image layout for "masonry behavior" album list. If you are using fixed image proportions on the list, choose an option other than default', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'masonry_image_dimension' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_album_single_back_to_link',
					'title'       => esc_html__( '"Back To" Link', 'micdrop-core' ),
					'description' => esc_html__( 'Choose "Back To" page to link from album single', 'micdrop-core' ),
					'options'     => qode_framework_get_pages( true ),
				)
			);

			$info_items_repeater = $general_section->add_repeater_element(
				array(
					'name'        => 'qodef_album_single_info_items',
					'title'       => esc_html__( 'Info Items', 'micdrop-core' ),
					'description' => esc_html__( 'Enter additional info for album item', 'micdrop-core' ),
					'button_text' => esc_html__( 'Add New Info', 'micdrop-core' ),
				)
			);

			$info_items_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_info_item_title',
					'title'      => esc_html__( 'Title', 'micdrop-core' ),
				)
			);

			$info_items_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_info_item_text',
					'title'      => esc_html__( 'Text', 'micdrop-core' ),
				)
			);

			$info_items_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_info_item_link',
					'title'      => esc_html__( 'Text Link', 'micdrop-core' ),
				)
			);

			/* Tracks sections */

			$tracks_section = $page->add_tab_element(
				array(
					'name'        => 'tab-tracks',
					'title'       => esc_html__( 'Tracks Settings', 'micdrop-core' ),
					'description' => esc_html__( 'Populate album single tracks information', 'micdrop-core' ),
				)
			);

			$tracks_repeater = $tracks_section->add_repeater_element(
				array(
					'name'        => 'qodef_album_single_tracks',
					'title'       => esc_html__( 'Tracks', 'micdrop-core' ),
					'button_text' => esc_html__( 'Add New Track', 'micdrop-core' ),
				)
			);

			$tracks_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_track_title',
					'title'      => esc_html__( 'Title', 'micdrop-core' ),
				)
			);

			$tracks_repeater->add_field_element(
				array(
					'field_type' => 'file',
					'name'       => 'qodef_album_single_track_file',
					'title'      => esc_html__( 'Audio File (mp3)', 'micdrop-core' ),
					'args'       => array(
						'allowed_type' => '[audio/mpeg]',
					),
				)
			);

			$tracks_repeater->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_album_single_track_link_type',
					'title'         => esc_html__( 'Track Link Type', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose a link type for album track', 'micdrop-core' ),
					'options'       => array(
						''              => esc_html__( 'Default', 'micdrop-core' ),
						'free-download' => esc_html__( 'Free Download', 'micdrop-core' ),
						'buy-track'     => esc_html__( 'Buy Track', 'micdrop-core' ),
					),
					'default_value' => 'free-download',
				)
			);

			$tracks_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_track_buy_track_link',
					'title'      => esc_html__( 'Track Buy Link', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_album_single_track_link_type' => array(
								'values'        => 'buy-track',
								'default_value' => '',
							),
						),
					),
				)
			);

			$tracks_repeater->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_album_single_track_buy_track_link_target',
					'title'      => esc_html__( 'Track Buy Link Target', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'link_target', false ),
					'dependency' => array(
						'show' => array(
							'qodef_album_single_track_link_type' => array(
								'values'        => 'buy-track',
								'default_value' => '',
							),
						),
					),
				)
			);

			$tracks_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_track_additional_info',
					'title'      => esc_html__( 'Additional Track Info', 'micdrop-core' ),
				)
			);

			$tracks_repeater->add_field_element(
				array(
					'field_type' => 'textarea',
					'name'       => 'qodef_album_single_track_lyrics',
					'title'      => esc_html__( 'Lyrics', 'micdrop-core' ),
				)
			);

			/* Stores sections */

			$stores_section = $page->add_tab_element(
				array(
					'name'        => 'tab-stores',
					'title'       => esc_html__( 'Stores Settings', 'micdrop-core' ),
					'description' => esc_html__( 'Set available stores for album.', 'micdrop-core' ),
				)
			);

			$stores_repeater = $stores_section->add_repeater_element(
				array(
					'name'        => 'qodef_album_single_stores',
					'title'       => esc_html__( 'Stores', 'micdrop-core' ),
					'button_text' => esc_html__( 'Add New Item', 'micdrop-core' ),
				)
			);

			$stores_repeater->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_album_single_stores_name',
					'title'      => esc_html__( 'Store', 'micdrop-core' ),
					'options'    => array(
						'amazonmp3'   => esc_html__( 'AmazonMP3', 'micdrop-core' ),
						'bandcamp'    => esc_html__( 'Bandcamp', 'micdrop-core' ),
						'deezer'      => esc_html__( 'Deezer', 'micdrop-core' ),
						'google-play' => esc_html__( 'Google Play', 'micdrop-core' ),
						'itunes'      => esc_html__( 'iTunes', 'micdrop-core' ),
						'spotify'     => esc_html__( 'Spotify', 'micdrop-core' ),
						'soundcloud'  => esc_html__( 'Soundcloud', 'micdrop-core' ),
						'youtube'     => esc_html__( 'YouTube', 'micdrop-core' ),
					),
				)
			);

			$stores_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_stores_link',
					'title'      => esc_html__( 'Store Link', 'micdrop-core' ),
				)
			);

			/* Reviews sections */

			$reviews_section = $page->add_tab_element(
				array(
					'name'  => 'tab-reviews',
					'title' => esc_html__( 'Reviews Settings', 'micdrop-core' ),
				)
			);

			$reviews_section->add_field_element(
				array(
					'field_type'  => 'image',
					'name'        => 'qodef_album_single_reviews_background_image',
					'title'       => esc_html__( 'Reviews Background Image', 'micdrop-core' ),
					'description' => esc_html__( 'Enter reviews area background image', 'micdrop-core' ),
				)
			);

			$reviews_repeater = $reviews_section->add_repeater_element(
				array(
					'name'        => 'qodef_album_single_reviews',
					'title'       => esc_html__( 'Reviews', 'micdrop-core' ),
					'description' => esc_html__( 'Populate album single reviews info', 'micdrop-core' ),
					'button_text' => esc_html__( 'Add New Review', 'micdrop-core' ),
				)
			);

			$reviews_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_review_title',
					'title'      => esc_html__( 'Title', 'micdrop-core' ),
				)
			);

			$reviews_repeater->add_field_element(
				array(
					'field_type' => 'textarea',
					'name'       => 'qodef_album_single_review_text',
					'title'      => esc_html__( 'Text', 'micdrop-core' ),
				)
			);

			/* Social sections */

			$social_section = $page->add_tab_element(
				array(
					'name'        => 'tab-social',
					'title'       => esc_html__( 'Social Networks Settings', 'micdrop-core' ),
					'description' => esc_html__( 'Populate album single social networks info', 'micdrop-core' ),
				)
			);

			$social_icons_repeater = $social_section->add_repeater_element(
				array(
					'name'        => 'qodef_album_single_social_icons',
					'title'       => esc_html__( 'Social Networks', 'micdrop-core' ),
					'button_text' => esc_html__( 'Add New Network', 'micdrop-core' ),
				)
			);

			$social_icons_repeater->add_field_element(
				array(
					'field_type' => 'iconpack',
					'name'       => 'qodef_album_single_icon',
					'title'      => esc_html__( 'Icon', 'micdrop-core' ),
				)
			);

			$social_icons_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_album_single_icon_link',
					'title'      => esc_html__( 'Icon Link', 'micdrop-core' ),
				)
			);

			$social_icons_repeater->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_album_single_icon_target',
					'title'      => esc_html__( 'Icon Target', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'link_target' ),
				)
			);

			// Hook to include additional options after module options
			do_action( 'micdrop_core_action_after_album_single_meta_box_map', $page );
		}
	}

	add_action( 'micdrop_core_action_default_meta_boxes_init', 'micdrop_core_add_album_single_meta_box' );
}

if ( ! function_exists( 'micdrop_core_include_general_meta_boxes_for_album_single' ) ) {
	/**
	 * Function that add general meta box options for this module
	 */
	function micdrop_core_include_general_meta_boxes_for_album_single() {
		$callbacks = micdrop_core_general_meta_box_callbacks();

		if ( ! empty( $callbacks ) ) {
			foreach ( $callbacks as $module => $callback ) {

				if ( 'page-sidebar' !== $module ) {
					add_action( 'micdrop_core_action_after_album_single_meta_box_map', $callback );
				}
			}
		}
	}

	add_action( 'micdrop_core_action_default_meta_boxes_init', 'micdrop_core_include_general_meta_boxes_for_album_single', 8 ); // Permission 8 is set in order to load it before default meta box function
}
