<?php

if ( ! function_exists( 'micdrop_core_generate_album_single_layout' ) ) {
	/**
	 * Function that return default layout for custom post type single page
	 *
	 * @return string
	 */
	function micdrop_core_generate_album_single_layout() {
		$template = micdrop_core_get_post_value_through_levels( 'qodef_album_single_layout' );

		return ! empty( $template ) ? $template : '';
	}

	add_filter( 'micdrop_core_filter_album_single_layout', 'micdrop_core_generate_album_single_layout' );
}

if ( ! function_exists( 'micdrop_core_get_album_holder_classes' ) ) {
	/**
	 * Function that return classes for the main album holder
	 *
	 * @return string
	 */
	function micdrop_core_get_album_holder_classes() {
		$classes = array( 'qodef-album-single' );

		$item_layout = micdrop_core_generate_album_single_layout();
		if ( ! empty( $item_layout ) ) {
			$classes[] = 'qodef-item-layout--' . $item_layout;
		}

		return implode( ' ', $classes );
	}
}

if ( ! function_exists( 'micdrop_core_set_album_single_body_classes' ) ) {
	/**
	 * Function that add additional class name into global class list for body tag
	 *
	 * @param array $classes
	 *
	 * @return array
	 */
	function micdrop_core_set_album_single_body_classes( $classes ) {
		$item_layout = micdrop_core_generate_album_single_layout();

		if ( is_singular( 'album' ) && ! empty( $item_layout ) ) {
			$classes[] = 'qodef-album-single-layout--' . $item_layout;
		}

		return $classes;
	}

	add_filter( 'body_class', 'micdrop_core_set_album_single_body_classes' );
}

if ( ! function_exists( 'micdrop_core_set_artist_single_body_classes' ) ) {
	/**
	 * Function that add additional class name into global class list for body tag
	 *
	 * @param array $classes
	 *
	 * @return array
	 */
	function micdrop_core_set_artist_single_body_classes( $classes ) {
		$queried_tax      = get_queried_object();
		$tax_id           = isset( $queried_tax->term_id ) ? $queried_tax->term_id : '';
		$artist_skin_meta = get_term_meta( $tax_id, 'qodef_artist_skin', true );
		$artist_skin      = ! empty( $artist_skin_meta ) ? 'qodef-artist-skin--' . $artist_skin_meta : '';

		if ( is_tax( 'artist' ) && ! empty( $artist_skin ) ) {
			$classes[] = $artist_skin;
		}

		return $classes;
	}

	add_filter( 'body_class', 'micdrop_core_set_artist_single_body_classes' );
}

if ( ! function_exists( 'micdrop_core_album_register_artist_archive_template' ) ) {
	/**
	 * Registers portfolio archive template if one does'nt exists in theme.
	 * Hooked to archive_template filter
	 *
	 * @param $archive string current template
	 *
	 * @return string string changed template
	 */
	function micdrop_core_album_register_artist_archive_template( $archive ) {
		$queried_tax = get_queried_object();

		if ( ! empty( $queried_tax ) && $queried_tax->taxonomy == 'artist' && file_exists( MICDROP_CORE_CPT_PATH . '/album/templates/taxonomy-artist.php' ) ) {
			$archive = MICDROP_CORE_CPT_PATH . '/album/templates/taxonomy-artist.php';
		}

		return $archive;
	}

	add_filter( 'taxonomy_template', 'micdrop_core_album_register_artist_archive_template' );
}

if ( ! function_exists( 'micdrop_core_set_artist_single_page_title_text' ) ) {
	/**
	 * Function that set current post title text
	 *
	 * @param $title string
	 *
	 * @return string
	 */
	function micdrop_core_set_artist_single_page_title_text( $title ) {

		if ( is_tax( 'artist' ) ) {
			$title = esc_html__( 'Artist', 'micdrop-core' );
		}

		return $title;
	}

	add_filter( 'micdrop_filter_page_title_text', 'micdrop_core_set_artist_single_page_title_text' );
}

if ( ! function_exists( 'micdrop_core_generate_album_archive_with_shortcode' ) ) {
	/**
	 * Function that executes album list shortcode with params on archive pages
	 *
	 * @param string $tax - type of taxonomy
	 * @param string $tax_slug - slug of taxonomy
	 * @param array $additional_params
	 */
	function micdrop_core_generate_album_archive_with_shortcode( $tax, $tax_slug, $additional_params = array() ) {
		$params = array();

		$params['additional_params']  = 'tax';
		$params['tax']                = $tax;
		$params['tax_slug']           = $tax_slug;
		$params['layout']             = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_item_layout' );
		$params['behavior']           = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_behavior' );
		$params['columns']            = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_columns' );
		$params['space']              = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_space' );
		$params['enable_stores']      = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_item_enable_stores' );
		$params['hover_gradient']     = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_item_hover_gradient' );
		$params['columns_responsive'] = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_columns_responsive' );
		$params['columns_1440']       = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_columns_1440' );
		$params['columns_1366']       = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_columns_1366' );
		$params['columns_1024']       = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_columns_1024' );
		$params['columns_768']        = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_columns_768' );
		$params['columns_680']        = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_columns_680' );
		$params['columns_480']        = micdrop_core_get_post_value_through_levels( 'qodef_album_archive_columns_480' );

		if ( ! empty( $additional_params ) ) {
			$params = array_merge( $params, $additional_params );
		}

		echo MicdropCore_Album_List_Shortcode::call_shortcode( $params );
	}
}

if ( ! function_exists( 'micdrop_core_album_set_admin_options_map_position' ) ) {
	/**
	 * Function that set dashboard admin options map position for this module
	 *
	 * @param int $position
	 * @param string $map
	 *
	 * @return int
	 */
	function micdrop_core_album_set_admin_options_map_position( $position, $map ) {

		if ( 'album' === $map ) {
			$position = 60;
		}

		return $position;
	}

	add_filter( 'micdrop_core_filter_admin_options_map_position', 'micdrop_core_album_set_admin_options_map_position', 10, 2 );
}

if ( ! function_exists( 'micdrop_core_album_breadcrumbs_title' ) ) {
	/**
	 * Improve main breadcrumbs template with additional cases
	 *
	 * @param string|html $wrap_child
	 * @param array $settings
	 *
	 * @return string|html
	 */
	function micdrop_core_album_breadcrumbs_title( $wrap_child, $settings ) {
		if ( is_tax( 'genre' ) ) {
			$wrap_child  = '';
			$term_object = get_term( get_queried_object_id(), 'genre' );

			if ( isset( $term_object->parent ) && 0 !== $term_object->parent ) {
				$parent      = get_term( $term_object->parent );
				$wrap_child .= sprintf( $settings['link'], get_term_link( $parent->term_id ), $parent->name ) . $settings['separator'];
			}

			$wrap_child .= sprintf( $settings['current_item'], single_cat_title( '', false ) );
		} elseif ( is_tax( 'artist' ) ) {
			$wrap_child  = '';
			$term_object = get_term( get_queried_object_id(), 'artist' );

			if ( isset( $term_object->parent ) && 0 !== $term_object->parent ) {
				$parent      = get_term( $term_object->parent );
				$wrap_child .= sprintf( $settings['link'], get_term_link( $parent->term_id ), $parent->name ) . $settings['separator'];
			}

			$wrap_child .= sprintf( $settings['current_item'], single_cat_title( '', false ) );
		} elseif ( is_singular( 'album' ) ) {
			$wrap_child = '';
			$post_terms = wp_get_post_terms( get_the_ID(), 'artist' );

			if ( ! empty( $post_terms ) ) {
				$post_term = $post_terms[0];
				if ( isset( $post_term->parent ) && 0 !== $post_term->parent ) {
					$parent      = get_term( $post_term->parent );
					$wrap_child .= sprintf( $settings['link'], get_term_link( $parent->term_id ), $parent->name ) . $settings['separator'];
				}
				$wrap_child .= sprintf( $settings['link'], get_term_link( $post_term ), $post_term->name ) . $settings['separator'];
			}

			$wrap_child .= sprintf( $settings['current_item'], get_the_title() );
		}

		return $wrap_child;
	}

	add_filter( 'micdrop_core_filter_breadcrumbs_content', 'micdrop_core_album_breadcrumbs_title', 10, 2 );
}
