<?php

if ( ! function_exists( 'micdrop_core_add_album_disc_shortcode' ) ) {
	/**
	 * Function that isadding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_album_disc_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Album_Disc_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_album_disc_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_Album_Disc_Shortcode extends MicdropCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/album-disc' );
			$this->set_base( 'micdrop_core_album_disc' );
			$this->set_name( esc_html__( 'Album Disc', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays album, disc image', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'cd_case_image',
					'title'      => esc_html__( 'CD Case Image', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'cd_image',
					'title'      => esc_html__( 'CD Image', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'image_size',
					'title'      => esc_html__( 'Image Size', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'link',
					'title'      => esc_html__( 'Image Link', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'link_target',
					'title'         => esc_html__( 'Link Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
				)
			);
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['case_image']     = $this->get_case_image( $atts );
			$atts['disc_image']     = $this->get_disc_image( $atts );

			return micdrop_core_get_template_part( 'post-types/album/shortcodes/album-disc', 'templates/album-disc', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-album-disc';

			return implode( ' ', $holder_classes );
		}

		public function get_case_image( $atts ) {
			$image = '';

			if ( ! empty( $atts['cd_case_image'] ) ) {
				$image_id = $atts['cd_case_image'];
				$image    = micdrop_core_get_list_shortcode_item_image( 'full', $image_id );
			}

			return $image;
		}

		public function get_disc_image( $atts ) {
			$styles = array();

			if ( ! empty( $atts['cd_image'] ) ) {
				$styles[] = 'background-image: url(' . esc_url( wp_get_attachment_url( $atts['cd_image'] ) ) . ')';
			}

			return $styles;
		}
	}
}
