<?php

if ( ! function_exists( 'micdrop_core_add_album_list_shortcode' ) ) {
	/**
	 * Function that isadding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_album_list_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Album_List_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_album_list_shortcode' );
}

if ( class_exists( 'MicdropCore_List_Shortcode' ) ) {
	class MicdropCore_Album_List_Shortcode extends MicdropCore_List_Shortcode {

		public function __construct() {
			$this->set_post_type( 'album' );
			$this->set_post_type_additional_taxonomies( array( 'genre', 'album-label', 'artist' ) );
			$this->set_layouts( apply_filters( 'micdrop_core_filter_album_list_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'micdrop_core_filter_album_list_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/album-list' );
			$this->set_base( 'micdrop_core_album_list' );
			$this->set_name( esc_html__( 'Album List', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays list of album', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->map_query_options( array( 'post_type' => $this->get_post_type() ) );
			$this->map_list_options(
				array(
					'exclude_behavior' => array( 'justified-gallery' ),
				)
			);
			$this->map_layout_options(
				array(
					'layouts'                 => $this->get_layouts(),
					'default_value_title_tag' => 'h5',
				)
			);
			$this->map_additional_options();
			$this->set_option(
				array(
					'field_type'  => 'select',
					'name'        => 'raise_middle_column',
					'title'       => esc_html__( 'Raise Middle Column', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'no_yes' ),
					'description' => 'Enable this option to place the middle column above the adjacent columns.(3 column layout)',
					'group'       => esc_html__( 'Layout', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'show_top_info',
					'title'      => esc_html__( 'Show Top Info', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'no_yes' ),
					'group'      => esc_html__( 'Top Info', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_title',
					'title'         => esc_html__( 'Top Info Title', 'micdrop-core' ),
					'default_value' => '',
					'group'         => esc_html__( 'Top Info', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'show_top_info' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_link_text',
					'title'         => esc_html__( 'Top Info Link Text', 'micdrop-core' ),
					'default_value' => 'Show All',
					'group'         => esc_html__( 'Top Info', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'show_top_info' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'top_info_link_target',
					'title'      => esc_html__( 'Top Info Link Target', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'group'      => esc_html__( 'Top Info', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'show_top_info' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_link',
					'title'         => esc_html__( 'Top Info Link', 'micdrop-core' ),
					'default_value' => '',
					'group'         => esc_html__( 'Top Info', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'show_top_info' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'show_artist',
					'title'         => esc_html__( 'Show Artist', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
					'dependency'    => array(
						'behavior' => array(
							'values'        => 'columns',
							'default_value' => 'default',
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'show_more_button',
					'title'         => esc_html__( 'Show More Button', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'behavior' => array(
								'values'        => array( 'columns' ),
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'more_button_link',
					'title'         => esc_html__( 'More Button Link', 'micdrop-core' ),
					'default_value' => '',
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'show_more_button' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'more_button_link_target',
					'title'         => esc_html__( 'More Button Link Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'show_more_button' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'more_button_link_text',
					'title'         => esc_html__( 'More Button Link Text', 'micdrop-core' ),
					'default_value' => 'View More',
					'group'         => esc_html__( 'Layout', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'show_more_button' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_link',
					'title'         => esc_html__( 'Top Info Link', 'micdrop-core' ),
					'default_value' => '',
					'group'         => esc_html__( 'Top Info', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'show_top_info' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'hide_show_all',
					'title'         => esc_html__( 'Hide Show All', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
					'group'         => esc_html__( 'Additional', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'behavior' => array(
								'values'        => array( 'columns', 'masonry' ),
								'default_value' => 'columns',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'filter_title',
					'title'      => esc_html__( 'Filter Title', 'micdrop-core' ),
					'group'      => esc_html__( 'Additional', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'behavior' => array(
								'values'        => array( 'columns', 'masonry' ),
								'default_value' => 'columns',
							),
						),
					),
				)
			);
			$this->map_extra_options();
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_album_list', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['post_type']       = $this->get_post_type();
			$atts['taxonomy_filter'] = $this->get_post_type_filter_taxonomy( $atts );

			// Additional query args
			$atts['additional_query_args'] = $this->get_additional_query_args( $atts );

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['item_classes']   = $this->get_item_classes( $atts );
			$atts['query_result']   = new \WP_Query( micdrop_core_get_query_params( $atts ) );
			$atts['slider_attr']    = $this->get_slider_data( $atts );
			$atts['data_attr']      = micdrop_core_get_pagination_data( MICDROP_CORE_REL_PATH, 'post-types/album/shortcodes', 'album-list', 'album', $atts );

			$atts['this_shortcode'] = $this;

			return micdrop_core_get_template_part( 'post-types/album/shortcodes/album-list', 'templates/content', $atts['behavior'], $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-album-list';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';

			if ( isset( $atts['enable_stores'] ) && 'yes' === $atts['enable_stores'] ) {
				$holder_classes[] = 'qodef-stores--enabled';
			}

			//raise_middle_column
			if ( isset( $atts['raise_middle_column'] ) && 'yes' === $atts['raise_middle_column'] ) {
				$holder_classes[] = 'qodef-raise-middle-column--' . $atts['raise_middle_column'];
			}

			if ( isset( $atts['show_more_button'] ) && 'yes' === $atts['show_more_button'] ) {
				$holder_classes[] = 'more-button--' . $atts['show_more_button'];
			}

			if ( isset( $atts['show_top_info'] ) && 'yes' === $atts['show_top_info'] ) {
				$holder_classes[] = 'qodef-top-info--' . $atts['show_top_info'];
			}

			if ( isset( $atts['hide_show_all'] ) && 'yes' === $atts['hide_show_all'] ) {
				$holder_classes[] = 'qodef-filter-show-all-hidden qodef-filter-show-all-hidden-loading';
			}

			$holder_classes[] = ! empty( $atts['filter_title'] ) ? 'qodef-filter_title--yes' : '';
			$holder_classes[] = ! empty( $atts['hover_gradient'] ) ? 'qodef--hover-gradient-' . $atts['hover_gradient'] : '';

			$list_classes   = $this->get_list_classes( $atts );
			$holder_classes = array_merge( $holder_classes, $list_classes );

			return implode( ' ', $holder_classes );
		}

		public function get_item_classes( $atts ) {
			$item_classes = $this->init_item_classes();

			$list_item_classes = $this->get_list_item_classes( $atts );

			$item_classes = array_merge( $item_classes, $list_item_classes );

			return implode( ' ', $item_classes );
		}


		public function get_title_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['text_transform'] ) ) {
				$styles[] = 'text-transform: ' . $atts['text_transform'];
			}

			return $styles;
		}
	}
}
