<?php

if ( ! function_exists( 'micdrop_core_add_album_player_slider_shortcode' ) ) {
	/**
	 * Function that isadding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_album_player_slider_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Album_Player_Slider_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_album_player_slider_shortcode' );
}

if ( class_exists( 'MicdropCore_List_Shortcode' ) ) {
	class MicdropCore_Album_Player_Slider_Shortcode extends MicdropCore_List_Shortcode {

		public function __construct() {
			$this->set_post_type( 'album' );
			$this->set_post_type_additional_taxonomies( array( 'genre', 'album-label', 'artist' ) );
			$this->set_layouts( apply_filters( 'micdrop_core_filter_album_player_slider_layouts', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/album-player-slider' );
			$this->set_base( 'micdrop_core_album_player_slider' );
			$this->set_name( esc_html__( 'Album Player Slider', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays list of album', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );

			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->map_query_options( array( 'post_type' => $this->get_post_type() ) );
			$this->map_list_options(
				array(
					'exclude_behavior' => array( 'behavior', 'columns', 'masonry', 'justified-gallery' ),
					'exclude_option'   => array( 'space' ),
				)
			);
			$this->map_layout_options( array( 'layouts' => $this->get_layouts() ) );
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'background_text_fill_color',
					'title'      => esc_html__( 'Background Text Fill Color', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'album_disc',
					'title'      => esc_html__( 'Albums Disc Image', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'slider_autoplay',
					'title'      => esc_html__( 'Enable Slider Autoplay', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'yes_no' ),
					'default'    => '',
				)
			);
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_album_player_slider', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['post_type'] = $this->get_post_type();

			// Predefined shortcode options
			$atts['behavior']           = 'slider';
			$atts['space']              = 'album-player-space';
			$atts['centered_slides']    = 'yes';
			$atts['columns']            = 3;
			$atts['columns_responsive'] = 'custom';
			$atts['columns_1440']       = 3;
			$atts['columns_1366']       = 3;
			$atts['columns_1024']       = 3;
			$atts['columns_768']        = 1;
			$atts['columns_680']        = 1;
			$atts['columns_480']        = 1;

			// Additional query args
			$atts['additional_query_args'] = $this->get_additional_query_args( $atts );

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['item_classes']   = $this->get_item_classes( $atts );
			$atts['bg_text_styles'] = $this->get_background_text_styles( $atts );
			$atts['query_result']   = new \WP_Query( micdrop_core_get_query_params( $atts ) );
			$atts['slider_attr']    = $this->get_slider_data( $atts );
			$atts['this_shortcode'] = $this;

			return micdrop_core_get_template_part( 'post-types/album/shortcodes/album-player-slider', 'templates/content', $atts['behavior'], $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-album-player-slider';
			$holder_classes[] = 'qodef-full-height-album-player-slider'; // to init full height
			$holder_classes[] = 'qodef-cursor-nav'; // to init cursor navigation
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';

			$list_classes   = $this->get_list_classes( $atts );
			$holder_classes = array_merge( $holder_classes, $list_classes );

			return implode( ' ', $holder_classes );
		}

		public function get_item_classes( $atts ) {
			$item_classes = $this->init_item_classes();

			$list_item_classes = $this->get_list_item_classes( $atts );

			$item_classes = array_merge( $item_classes, $list_item_classes );

			return implode( ' ', $item_classes );
		}

		public function get_title_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['text_transform'] ) ) {
				$styles[] = 'text-transform: ' . $atts['text_transform'];
			}

			return $styles;
		}

		public function get_background_text_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['background_text_fill_color'] ) ) {
				$styles[] = 'color: ' . $atts['background_text_fill_color'];
			}

			return $styles;
		}
	}
}
