<?php

if ( ! function_exists( 'micdrop_core_add_album_player_shortcode' ) ) {
	/**
	 * Function that isadding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_album_player_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Album_Player_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_album_player_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_Album_Player_Shortcode extends MicdropCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'micdrop_core_filter_album_player_layouts', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/album-player' );
			$this->set_base( 'micdrop_core_album_player' );
			$this->set_name( esc_html__( 'Album Player', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays player of album', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );

			$this->set_scripts(
				array(
					'jplaylist' => array(
						'registered' => false,
						'url'        => MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/album-player/assets/js/plugins/jplayer.playlist.min.js',
						'dependency' => array( 'jquery' ),
					),
					'jplayer'   => array(
						'registered' => false,
						'url'        => MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/album-player/assets/js/plugins/jquery.jplayer.min.js',
						'dependency' => array( 'jquery' ),
					),
				)
			);

			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);

			$this->set_option(
				array(
					'field_type' => 'hidden',
					'name'       => 'album_disc',
					'title'      => esc_html__( 'Album Disc', 'micdrop-core' ),
				)
			);

			$options_map = micdrop_core_get_variations_options_map( $this->get_layouts() );
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'micdrop-core' ),
					'options'       => $this->get_layouts(),
					'default_value' => $options_map['default_value'],
					'visibility'    => array( 'map_for_page_builder' => $options_map['visibility'] ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'background_color',
					'title'      => esc_html__( 'Background Color', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'album',
					'title'      => esc_html__( 'Album', 'micdrop-core' ),
					'options'    => qode_framework_get_cpt_items( 'album' ),
				)
			);
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_album_player', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function load_assets() {
			wp_enqueue_script( 'jplaylist' );
			wp_enqueue_script( 'jplayer' );
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['holder_classes']       = $this->get_holder_classes( $atts );
			$atts['player_holder_styles'] = $this->get_player_holder_styles( $atts );

			return micdrop_core_get_template_part( 'post-types/album/shortcodes/album-player', 'variations/' . $atts['layout'] . '/templates/holder', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-album-player';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['album'] ) && has_post_thumbnail( $atts['album'] ) ? 'qodef--has-album' : '';

			return implode( ' ', $holder_classes );
		}

		private function get_player_holder_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['background_color'] ) ) {
				$styles[] = 'background-color: ' . $atts['background_color'];
			}

			return $styles;
		}
	}
}
