<?php

if ( ! function_exists( 'micdrop_core_add_artist_showcase_slider_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_artist_showcase_slider_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_artist_showcase_slider_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_artist_showcase_slider_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_artist_showcase_slider_Shortcode extends MicdropCore_List_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'micdrop_core_filter_artist_showcase_slider_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'micdrop_core_filter_artist_showcase_slider_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/artist-showcase-slider' );
			$this->set_base( 'micdrop_core_artist_showcase_slider' );
			$this->set_name( esc_html__( 'Artist Showcase Slider', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds artist showcase slider element', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'slider_autoplay',
					'title'         => esc_html__( 'Enable Slider Autoplay', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'yes',
				)
			);

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'slider_pagination',
					'title'         => esc_html__( 'Enable Slider Pagination', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'no',
				)
			);

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'enable_song_on_load',
					'title'         => esc_html__( 'Enable Song Player', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'no',
				)
			);

			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'song_audio_file_path',
					'title'      => esc_html__( 'Path to audio file', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'enable_song_on_load' => array(
								'values'        => 'yes',
								'default_value' => 'no',
							),
						),
					),
				)
			);

			$this->set_option(
				array(
					'field_type' => 'repeater',
					'name'       => 'slider_items',
					'title'      => esc_html__( 'Slider Items', 'micdrop-core' ),
					'items'      => array(
						array(
							'field_type' => 'color',
							'name'       => 'background_color',
							'title'      => esc_html__( 'Background Color', 'micdrop-core' ),
						),
						array(
							'field_type' => 'image',
							'name'       => 'background_image',
							'title'      => esc_html__( 'Background Image', 'micdrop-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'big_text',
							'title'      => esc_html__( 'Background Text', 'micdrop-core' ),
						),
						array(
							'field_type'  => 'textarea',
							'name'        => 'text',
							'title'       => esc_html__( 'Content', 'micdrop-core' ),
							'description' => esc_html__( 'Accepts simple text, html or even shortcodes', 'micdrop-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'bottom_subtitle',
							'title'      => esc_html__( 'Bottom Subtitle', 'micdrop-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'bottom_title',
							'title'      => esc_html__( 'Bottom Title', 'micdrop-core' ),
						),
						array(
							'field_type'    => 'select',
							'name'          => 'content_in_grid',
							'title'         => esc_html__( 'Content In Grid', 'micdrop-core' ),
							'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
							'default_value' => 'no',
						),
						array(
							'field_type' => 'image',
							'name'       => 'album_cover',
							'title'      => esc_html__( 'Album Cover', 'micdrop-core' ),
						),
						array(
							'field_type' => 'image',
							'name'       => 'album_disc',
							'title'      => esc_html__( 'Album Disc', 'micdrop-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'link',
							'title'      => esc_html__( 'Button Link', 'micdrop-core' ),
						),
						array(
							'field_type'  => 'text',
							'name'        => 'link_text',
							'title'       => esc_html__( 'Button Text', 'micdrop-core' ),
							'description' => esc_html__( 'Default is "Find Out More"', 'micdrop-core' ),
						),
					),
				)
			);
			$this->map_extra_options();
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['slider_attr']    = $this->get_slider_data( $atts );
			$atts['items']          = $this->parse_repeater_items( $atts['slider_items'] );
			$atts['this_shortcode'] = $this;

			return micdrop_core_get_template_part( 'post-types/album/shortcodes/artist-showcase-slider', 'templates/artist-showcase-slider', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-artist-showcase-slider';

			$holder_classes[] = ! empty( $atts['slider_autoplay'] ) && ( 'yes' === $atts['slider_autoplay'] ) ? 'qodef-autoplay--enabled' : '';
			$holder_classes[] = ! empty( $atts['slider_pagination'] ) && ( 'yes' === $atts['slider_pagination'] ) ? 'qodef-pagination--enabled' : '';

			return implode( ' ', $holder_classes );
		}

		private function get_title_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['title_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['title_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['title_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['title_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['title_color'] ) ) {
				$styles[] = 'color: ' . $atts['title_color'];
			}

			return $styles;
		}
	}
}
