<?php

if ( ! function_exists( 'micdrop_core_add_artists_lineup_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_artists_lineup_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Artists_Lineup_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_artists_lineup_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_Artists_Lineup_Shortcode extends MicdropCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/artists-lineup' );
			$this->set_base( 'micdrop_core_artists_lineup' );
			$this->set_name( esc_html__( 'Artists Lineup', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds artists lineup holder', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_scripts(
				array(
					'jquery-appear'     => array(
						'registered' => true,
					),
					'perfect-scrollbar' => array(
						'registered' => false,
						'url'        => MICDROP_CORE_URL_PATH . 'assets/plugins/perfect-scrollbar/perfect-scrollbar.jquery.min.js',
						'dependency' => array( 'jquery' ),
					),
				)
			);
			$this->set_necessary_styles(
				array(
					'perfect-scrollbar' => array(
						'registered' => false,
						'url'        => MICDROP_CORE_URL_PATH . 'assets/plugins/perfect-scrollbar/perfect-scrollbar.css',
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'title_tag',
					'title'         => esc_html__( 'Title Tag', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h2',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'link_target',
					'title'         => esc_html__( 'Link Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'repeater',
					'name'       => 'children',
					'title'      => esc_html__( 'Artist Items', 'micdrop-core' ),
					'items'      => array(
						array(
							'field_type'    => 'text',
							'name'          => 'item_link',
							'title'         => esc_html__( 'Link', 'micdrop-core' ),
							'default_value' => '',
						),
						array(
							'field_type'    => 'text',
							'name'          => 'item_title',
							'title'         => esc_html__( 'Title', 'micdrop-core' ),
							'default_value' => '',
						),
						array(
							'field_type'  => 'text',
							'name'        => 'highlight_position',
							'title'       => esc_html__( 'Highlight Text Position', 'micdrop-core' ),
							'description' => esc_html__( 'Enter the positions of the words you would like to display as "highlight" text. Separate start and end positions with commas (e.g. if you would like to wrap from fifth to ninth words, you would enter "5,9") or if you want to highlight whole text fill -1', 'micdrop-core' ),
						),
					),
				)
			);
			$this->map_extra_options();
		}

		public function load_assets() {
			wp_enqueue_script( 'jquery-appear' );
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['items']          = $this->parse_repeater_items( $atts['children'] );

			return micdrop_core_get_template_part( 'post-types/album/shortcodes/artists-lineup', 'templates/artists-lineup', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-artists-lineup';

			return implode( ' ', $holder_classes );
		}
	}
}
