<?php

if ( ! function_exists( 'micdrop_core_add_tracks_list_shortcode' ) ) {
	/**
	 * Function that isadding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_tracks_list_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Tracks_List_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_tracks_list_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_Tracks_List_Shortcode extends MicdropCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'micdrop_core_filter_tracks_list_layouts', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/tracks-list' );
			$this->set_base( 'micdrop_core_tracks_list' );
			$this->set_name( esc_html__( 'Tracks List', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays tracks list of album', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );

			$this->set_scripts(
				array(
					'jplaylist' => array(
						'registered' => false,
						'url'        => MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/album-player/assets/js/plugins/jplayer.playlist.min.js',
						'dependency' => array( 'jquery' ),
					),
					'jplayer'   => array(
						'registered' => false,
						'url'        => MICDROP_CORE_CPT_URL_PATH . '/album/shortcodes/album-player/assets/js/plugins/jquery.jplayer.min.js',
						'dependency' => array( 'jquery' ),
					),
				)
			);

			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);

			$options_map = micdrop_core_get_variations_options_map( $this->get_layouts() );
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'micdrop-core' ),
					'options'       => $this->get_layouts(),
					'default_value' => $options_map['default_value'],
					'visibility'    => array( 'map_for_page_builder' => $options_map['visibility'] ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'album',
					'title'      => esc_html__( 'Album', 'micdrop-core' ),
					'options'    => qode_framework_get_cpt_items( 'album' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'enable_artist_info',
					'title'      => esc_html__( 'Enable Artist Info', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'yes_no' ),
				)
			);
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_tracks_list', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function load_assets() {
			wp_enqueue_script( 'jplaylist' );
			wp_enqueue_script( 'jplayer' );
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );

			return micdrop_core_get_template_part( 'post-types/album/shortcodes/tracks-list', 'variations/' . $atts['layout'] . '/templates/holder', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes   = $this->init_holder_classes();
			$holder_classes[] = 'qodef-tracks-list';

			$album_id = intval( $atts['album'] );
			$tracks   = get_post_meta( $album_id, 'qodef_album_single_tracks', true );

			if ( ! empty( $tracks ) ) {
				foreach ( $tracks as $key => $track ) {
					$link_types = array();

					$link_type = $track['qodef_album_single_track_link_type'];
					if ( ! empty( $link_type ) ) {
						$link_types[] = $link_type;

						$has_buy = in_array( 'buy-track', $link_types );

						if ( $has_buy ) {
							$holder_classes[] = 'qodef-has--buy-track';
							break;
						}
					}
				}
			}

			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['enable_artist_info'] ) && 'yes' === $atts['enable_artist_info'] ? 'qodef--has-artist' : '';

			return implode( ' ', $holder_classes );
		}
	}
}
