<?php

if ( ! function_exists( 'micdrop_core_add_events_options' ) ) {
	/**
	 * Function that add general options for this module
	 */
	function micdrop_core_add_events_options() {
		$qode_framework = qode_framework_get_framework_root();

		$page = $qode_framework->add_options_page(
			array(
				'scope'       => MICDROP_CORE_OPTIONS_NAME,
				'type'        => 'admin',
				'slug'        => 'event-item',
				'layout'      => 'tabbed',
				'icon'        => 'fa fa-cog',
				'title'       => esc_html__( 'Events', 'micdrop-core' ),
				'description' => esc_html__( 'Global Event Options', 'micdrop-core' ),
			)
		);

		if ( $page ) {

			// Hook to include additional options before module options
			do_action( 'micdrop_core_action_before_events_options_map', $page );

			$list_tab = $page->add_tab_element(
				array(
					'name'        => 'tab-list',
					'icon'        => 'fa fa-cog',
					'title'       => esc_html__( 'List Settings', 'micdrop-core' ),
					'description' => esc_html__( 'Settings related to event list pages', 'micdrop-core' ),
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_event_archive_title_layout',
					'title'         => esc_html__( 'Event Archive Title Layout', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose a title layout', 'micdrop-core' ),
					'options'       => apply_filters( 'micdrop_core_filter_title_layout_options', array() ),
					'default_value' => 'standard',
				)
			);

			$list_tab->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_set_event_archive_page_title_area_in_grid',
					'title'       => esc_html__( 'Event Archive Page Title In Grid', 'micdrop-core' ),
					'description' => esc_html__( 'Enabling this option will set page title area to be in grid', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'no_yes' ),
				)
			);

			// Hook to include additional options after single module options
			do_action( 'micdrop_core_action_after_events_options_list', $list_tab );

			// Hook to include additional options after module options
			do_action( 'micdrop_core_action_after_events_options_map', $page );
		}
	}

	add_action( 'micdrop_core_action_default_options_init', 'micdrop_core_add_events_options', micdrop_core_get_admin_options_map_position( 'event-item' ) );
}
