<?php

if ( ! function_exists( 'micdrop_core_add_events_single_meta_box' ) ) {
	/**
	 * Function that add general options for this module
	 */
	function micdrop_core_add_events_single_meta_box() {
		$qode_framework = qode_framework_get_framework_root();

		$page = $qode_framework->add_options_page(
			array(
				'scope'  => array( 'event-item' ),
				'type'   => 'meta',
				'slug'   => 'event-item',
				'title'  => esc_html__( 'Event Item', 'micdrop-core' ),
				'layout' => 'tabbed',
			)
		);

		if ( $page ) {

			/* General sections */

			$general_section = $page->add_section_element(
				array(
					'name'        => 'qodef_event_single_general_section',
					'title'       => esc_html__( 'General Settings', 'micdrop-core' ),
					'description' => esc_html__( 'General information about event single', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_event_single_tickets_status',
					'title'       => esc_html__( 'Tickets Status', 'micdrop-core' ),
					'description' => esc_html__( 'Choose a tickets status for event single', 'micdrop-core' ),
					'options'     => array(
						'available' => esc_html__( 'Available', 'micdrop-core' ),
						'free'      => esc_html__( 'Free', 'micdrop-core' ),
						'sold'      => esc_html__( 'Sold', 'micdrop-core' ),
						'canceled'  => esc_html__( 'Canceled', 'micdrop-core' ),
					),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'date',
					'name'        => 'qodef_event_single_start_date',
					'title'       => esc_html__( 'Event Start Date', 'micdrop-core' ),
					'description' => esc_html__( 'Enter event date', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'date',
					'name'        => 'qodef_event_single_end_date',
					'title'       => esc_html__( 'Event End Date', 'micdrop-core' ),
					'description' => esc_html__( 'Enter event date', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_event_single_time',
					'title'       => esc_html__( 'Event Time', 'micdrop-core' ),
					'description' => esc_html__( 'Enter the time in a HH:MM format. If you are using a 12 hour time format, please also enter AM or PM markers', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_event_single_location',
					'title'       => esc_html__( 'Event Location', 'micdrop-core' ),
					'description' => esc_html__( 'Enter the event location. For example "Dolby Soho, Broadway New York"', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_event_single_stage',
					'title'       => esc_html__( 'Event Stage', 'micdrop-core' ),
					'description' => esc_html__( 'Enter the event stage if available. For example "Main Stage"', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_event_single_website',
					'title'      => esc_html__( 'Event Website', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_event_single_organized_by',
					'title'      => esc_html__( 'Organized By', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_event_single_tickets_link',
					'title'       => esc_html__( 'Buy Tickets Link', 'micdrop-core' ),
					'description' => esc_html__( 'Enter the external link where users can buy the tickets', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_event_single_tickets_link_text',
					'title'      => esc_html__( 'Tickets Link Text', 'micdrop-core' ),
				)
			);

			$general_section->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_event_single_tickets_link_target',
					'title'      => esc_html__( 'Tickets Link Target', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'link_target' ),
				)
			);

			/* Social sections */

			$social_section = $page->add_section_element(
				array(
					'name'        => 'qodef_event_single_social_section',
					'title'       => esc_html__( 'Social Settings', 'micdrop-core' ),
					'description' => esc_html__( 'Social information about event single.', 'micdrop-core' ),
				)
			);

			$social_icons_repeater = $social_section->add_repeater_element(
				array(
					'name'        => 'qodef_events_single_social_icons',
					'title'       => esc_html__( 'Social Networks', 'micdrop-core' ),
					'description' => esc_html__( 'Populate events single social networks info', 'micdrop-core' ),
					'button_text' => esc_html__( 'Add New Network', 'micdrop-core' ),
				)
			);

			$social_icons_repeater->add_field_element(
				array(
					'field_type' => 'iconpack',
					'name'       => 'qodef_events_single_icon',
					'title'      => esc_html__( 'Icon', 'micdrop-core' ),
				)
			);

			$social_icons_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_events_single_icon_link',
					'title'      => esc_html__( 'Icon Link', 'micdrop-core' ),
				)
			);

			$social_icons_repeater->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_events_single_icon_target',
					'title'      => esc_html__( 'Icon Target', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'link_target' ),
				)
			);

			// Hook to include additional options after module options
			do_action( 'micdrop_core_action_after_events_single_meta_box_map', $page );
		}
	}

	add_action( 'micdrop_core_action_default_meta_boxes_init', 'micdrop_core_add_events_single_meta_box' );
}

if ( ! function_exists( 'micdrop_core_include_general_meta_boxes_for_events_single' ) ) {
	/**
	 * Function that add general meta box options for this module
	 */
	function micdrop_core_include_general_meta_boxes_for_events_single() {
		$callbacks = micdrop_core_general_meta_box_callbacks();

		if ( ! empty( $callbacks ) ) {
			foreach ( $callbacks as $module => $callback ) {

				if ( 'page-sidebar' !== $module ) {
					add_action( 'micdrop_core_action_after_events_single_meta_box_map', $callback );
				}
			}
		}
	}

	add_action( 'micdrop_core_action_default_meta_boxes_init', 'micdrop_core_include_general_meta_boxes_for_events_single', 8 ); // Permission 8 is set in order to load it before default meta box function
}
