<?php

if ( ! function_exists( 'micdrop_core_generate_events_single_layout' ) ) {
	/**
	 * Function that return default layout for custom post type single page
	 *
	 * @return string
	 */
	function micdrop_core_generate_events_single_layout() {
		$template = 'default';

		return $template;
	}

	add_filter( 'micdrop_core_filter_events_single_layout', 'micdrop_core_generate_events_single_layout' );
}

if ( ! function_exists( 'micdrop_core_generate_events_archive_with_shortcode' ) ) {
	/**
	 * Function that executes events list shortcode with params on archive pages
	 *
	 * @param string $tax - type of taxonomy
	 * @param string $tax_slug - slug of taxonomy
	 */
	function micdrop_core_generate_events_archive_with_shortcode( $tax, $tax_slug ) {
		$params = array();

		$params['behavior']          = 'columns';
		$params['title_tag']         = 'h5';
		$params['additional_params'] = 'tax';
		$params['tax']               = $tax;
		$params['tax_slug']          = $tax_slug;

		echo MicdropCore_Events_Slider_Shortcode::call_shortcode( $params );
	}
}

if ( ! function_exists( 'micdrop_core_set_event_types_page_title_text' ) ) {
	/**
	 * Function that set current post title text
	 *
	 * @param $title string
	 *
	 * @return string
	 */
	function micdrop_core_set_event_types_page_title_text( $title ) {

		if ( is_tax( 'event-types' ) ) {
			$taxonomy_slug = 'event-types';
			$taxonomy      = get_term( get_queried_object_id(), $taxonomy_slug );

			if ( ! empty( $taxonomy ) ) {
				$title = esc_html( $taxonomy->name );
			}
		}

		return $title;
	}

	add_filter( 'micdrop_filter_page_title_text', 'micdrop_core_set_event_types_page_title_text' );
}

if ( ! function_exists( 'micdrop_core_event_breadcrumbs_title' ) ) {
	/**
	 * Improve main breadcrumbs template with additional cases
	 *
	 * @param string|html $wrap_child
	 * @param array $settings
	 *
	 * @return string|html
	 */
	function micdrop_core_event_breadcrumbs_title( $wrap_child, $settings ) {
		if ( is_tax( 'event-types' ) ) {
			$wrap_child  = '';
			$term_object = get_term( get_queried_object_id(), 'event-types' );

			if ( isset( $term_object->parent ) && 0 !== $term_object->parent ) {
				$parent      = get_term( $term_object->parent );
				$wrap_child .= sprintf( $settings['link'], get_term_link( $parent->term_id ), $parent->name ) . $settings['separator'];
			}

			$wrap_child .= sprintf( $settings['current_item'], single_cat_title( '', false ) );
		}

		return $wrap_child;
	}

	add_filter( 'micdrop_core_filter_breadcrumbs_content', 'micdrop_core_event_breadcrumbs_title', 10, 2 );
}

if ( ! function_exists( 'micdrop_core_set_event_types_body_classes' ) ) {
	/**
	 * Function that add additional class name into global class list for body tag
	 *
	 * @param array $classes
	 *
	 * @return array
	 */
	function micdrop_core_set_event_types_body_classes( $classes ) {
		$queried_tax           = get_queried_object();
		$tax_id                = isset( $queried_tax->term_id ) ? $queried_tax->term_id : '';
		$event_types_skin_meta = get_term_meta( $tax_id, 'qodef_event_types_skin', true );
		$event_types_skin      = ! empty( $event_types_skin_meta ) ? 'qodef-event-types-skin--' . $event_types_skin_meta : '';

		if ( is_tax( 'event-types' ) && ! empty( $event_types_skin ) ) {
			$classes[] = $event_types_skin;
		}

		return $classes;
	}

	add_filter( 'body_class', 'micdrop_core_set_event_types_body_classes' );
}
