<?php

if ( ! function_exists( 'micdrop_core_add_events_slider_shortcode' ) ) {
	/**
	 * Function that isadding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_events_slider_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Events_Slider_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_events_slider_shortcode' );
}

if ( class_exists( 'MicdropCore_List_Shortcode' ) ) {
	class MicdropCore_Events_Slider_Shortcode extends MicdropCore_List_Shortcode {

		public function __construct() {
			$this->set_post_type( 'event-item' );
			$this->set_post_type_additional_taxonomies( array( 'event-types' ) );
			$this->set_layouts( apply_filters( 'micdrop_core_filter_events_slider_layouts', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/events/shortcodes/events-slider' );
			$this->set_base( 'micdrop_core_events_slider' );
			$this->set_name( esc_html__( 'Events Slider', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays list of events', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'skin',
					'title'         => esc_html__( 'Skin', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'skin', true, array( 'light' ) ),
					'default_value' => '',
				)
			);
			$this->map_list_options(
				array(
					'exclude_behavior' => array( 'justified-gallery', 'masonry' ),
					'default_value'    => 'slider',
				)
			);
			$this->map_query_options(
				array(
					'post_type'        => $this->get_post_type(),
					'include_order_by' => array(
						'start-date' => esc_html__( 'Start Date', 'micdrop-core' ),
						'upcoming'   => esc_html__( 'Current and Upcoming', 'micdrop-core' ),
						'past'       => esc_html__( 'Past', 'micdrop-core' ),
					),
				)
			);

			$this->map_layout_options(
				array(
					'layouts'                 => $this->get_layouts(),
					'default_value_title_tag' => 'span',
				)
			);
			$this->map_additional_options(
				array(
					'exclude_filter' => true,
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_title',
					'title'         => esc_html__( 'Top Info Title', 'micdrop-core' ),
					'default_value' => '',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'top_info_title_tag',
					'title'         => esc_html__( 'Top Info Title Tag', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h2',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_link_text',
					'title'         => esc_html__( 'Top Info Link Text', 'micdrop-core' ),
					'default_value' => 'Show All',
					'dependency'    => array(
						'hide' => array(
							'behavior' => array(
								'values'        => 'slider',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'top_info_link_target',
					'title'      => esc_html__( 'Top Info Link Target', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'dependency' => array(
						'hide' => array(
							'behavior' => array(
								'values'        => 'slider',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'top_info_link',
					'title'         => esc_html__( 'Top Info Link', 'micdrop-core' ),
					'default_value' => '',
					'dependency'    => array(
						'hide' => array(
							'behavior' => array(
								'values'        => 'slider',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->map_extra_options();
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_events_slider', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['post_type'] = $this->get_post_type();

			// Predefined shortcode options
			$atts['layout'] = 'info-on-image';

			// Additional query args
			$atts['additional_query_args'] = array_merge( $this->get_additional_query_args( $atts ), $this->get_additional_meta_query( $atts ) );

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['item_classes']   = $this->get_item_classes( $atts );
			$atts['query_result']   = new \WP_Query( micdrop_core_get_query_params( $atts ) );
			$atts['slider_attr']    = $this->get_slider_data( $atts );
			$atts['data_attr']      = micdrop_core_get_pagination_data( MICDROP_CORE_REL_PATH, 'post-types/events/shortcodes', 'events-slider', 'events', $atts );

			$atts['this_shortcode'] = $this;

			return micdrop_core_get_template_part( 'post-types/events/shortcodes/events-slider', 'templates/content', $atts['behavior'], $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-events-slider';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-item-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['skin'] ) ? 'qodef-skin--' . $atts['skin'] : '';

			if ( 'slider' !== $atts['behavior'] && ( ! empty( $atts['top_info_title'] ) || ! empty( $atts['top_info_link_text'] ) ) ) {
				$holder_classes[] = 'qodef-top-info--yes';
			} elseif ( 'slider' === $atts['behavior'] && 'no' !== $atts['slider_navigation'] ) {
				$holder_classes[] = 'qodef-top-info--yes';
			}

			$list_classes   = $this->get_list_classes( $atts );
			$holder_classes = array_merge( $holder_classes, $list_classes );

			return implode( ' ', $holder_classes );
		}

		private function get_item_classes( $atts ) {
			$item_classes = $this->init_item_classes();

			$list_item_classes = $this->get_list_item_classes( $atts );

			$item_classes = array_merge( $item_classes, $list_item_classes );

			return implode( ' ', $item_classes );
		}

		private function get_additional_meta_query( $atts ) {
			$query_args = array();
			$meta_query = array();

			switch ( $atts['orderby'] ) {
				case 'start-date':
					$query_args['orderby']  = 'meta_value';
					$query_args['meta_key'] = 'qodef_event_single_start_date';
					break;
				case 'upcoming':
					$query_args['orderby'] = 'meta_value';

					$meta_query = array(
						'relation' => 'OR',
						array(
							'key'     => 'qodef_event_single_end_date',
							'value'   => gmdate( 'Y-m-d' ),
							'compare' => '>=',
						),
						array(
							'relation' => 'AND',
							array(
								'key'     => 'qodef_event_single_end_date',
								'compare' => 'NOT EXISTS',
							),
							array(
								'key'     => 'qodef_event_single_start_date',
								'value'   => gmdate( 'Y-m-d' ),
								'compare' => '>=',
							),
						),
					);
					break;
				case 'past':
					$query_args['orderby'] = 'meta_value';

					$meta_query = array(
						'relation' => 'OR',
						array(
							'key'     => 'qodef_event_single_end_date',
							'value'   => gmdate( 'Y-m-d' ),
							'compare' => '<',
						),
						array(
							'relation' => 'AND',
							array(
								'key'     => 'qodef_event_single_end_date',
								'compare' => 'NOT EXISTS',
							),
							array(
								'key'     => 'qodef_event_single_start_date',
								'value'   => gmdate( 'Y-m-d' ),
								'compare' => '<',
							),
						),
					);
					break;
			}

			if ( is_array( $meta_query ) && count( $meta_query ) ) {
				$query_args['meta_query'][] = $meta_query;
			}

			return $query_args;
		}

		public function get_title_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['text_transform'] ) ) {
				$styles[] = 'text-transform: ' . $atts['text_transform'];
			}

			return $styles;
		}
	}
}
