<?php

if ( ! function_exists( 'micdrop_core_add_masonry_gallery_meta_box' ) ) {
	/**
	 * Function that adds fields for masonry gallery
	 */
	function micdrop_core_add_masonry_gallery_meta_box() {
		$qode_framework = qode_framework_get_framework_root();

		$page = $qode_framework->add_options_page(
			array(
				'scope' => array( 'masonry-gallery' ),
				'type'  => 'meta',
				'slug'  => 'masonry-gallery',
				'title' => esc_html__( 'Masonry Gallery Parameters', 'micdrop-core' ),
			)
		);

		if ( $page ) {

			$page->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_masonry_gallery_item_layout',
					'title'         => esc_html__( 'Item Layout', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose default layout for masonry gallery item', 'micdrop-core' ),
					'options'       => array(
						'standard' => esc_html__( 'Standard', 'micdrop-core' ),
						'simple'   => esc_html__( 'Simple', 'micdrop-core' ),
						'textual'  => esc_html__( 'Textual', 'micdrop-core' ),
					),
					'default_value' => 'standard',
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_masonry_gallery_item_dimension',
					'title'       => esc_html__( 'Masonry Item Dimension', 'micdrop-core' ),
					'description' => esc_html__( 'Choose an item dimension layout "masonry behavior" for masonry gallery list.', 'micdrop-core' ),
					'options'     => micdrop_core_get_select_type_options_pool( 'masonry_image_dimension' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_masonry_gallery_item_title_tag',
					'title'      => esc_html__( 'Title Tag', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'title_tag' ),
					'dependency' => array(
						'hide' => array(
							'qodef_masonry_gallery_item_layout' => array(
								'values'        => array( 'simple' ),
								'default_value' => 'standard',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'textarea',
					'name'       => 'qodef_masonry_gallery_item_text',
					'title'      => esc_html__( 'Text', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_masonry_gallery_item_layout' => array(
								'values'        => array( 'textual' ),
								'default_value' => 'standard',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_masonry_gallery_item_text_tag',
					'title'      => esc_html__( 'Text Tag', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'title_tag' ),
					'dependency' => array(
						'show' => array(
							'qodef_masonry_gallery_item_layout' => array(
								'values'        => array( 'textual' ),
								'default_value' => 'standard',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_masonry_gallery_item_button_label',
					'title'      => esc_html__( 'Button Label', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_masonry_gallery_item_layout' => array(
								'values'        => array( 'textual' ),
								'default_value' => 'standard',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_masonry_gallery_item_video_url',
					'title'       => esc_html__( 'Video URL', 'micdrop-core' ),
					'description' => esc_html__( 'Input self hosted video link here and it will be displayed instead of the featured image.', 'micdrop-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_masonry_gallery_item_link',
					'title'      => esc_html__( 'Link', 'micdrop-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_masonry_gallery_item_link_target',
					'title'      => esc_html__( 'Target', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'link_target', false ),
				)
			);

			// Hook to include additional options after module options
			do_action( 'micdrop_core_action_after_masonry_gallery_meta_box_map', $page );
		}
	}

	add_action( 'micdrop_core_action_default_meta_boxes_init', 'micdrop_core_add_masonry_gallery_meta_box' );
}
