<?php

if ( ! function_exists( 'micdrop_core_add_masonry_gallery_list_shortcode' ) ) {
	/**
	 * Function that is adding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_masonry_gallery_list_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Masonry_Gallery_List_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_masonry_gallery_list_shortcode' );
}

if ( class_exists( 'MicdropCore_List_Shortcode' ) ) {
	class MicdropCore_Masonry_Gallery_List_Shortcode extends MicdropCore_List_Shortcode {

		public function __construct() {
			$this->set_post_type( 'masonry-gallery' );
			$this->set_post_type_additional_taxonomies( array( 'masonry-gallery-category' ) );
			$this->set_extra_options( apply_filters( 'micdrop_core_filter_masonry_gallery_list_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_CPT_URL_PATH . '/masonry-gallery/shortcodes/masonry-gallery-list' );
			$this->set_base( 'micdrop_core_masonry_gallery_list' );
			$this->set_name( esc_html__( 'Masonry Gallery List', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays list of masonry gallery', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_scripts(
				array(
					'jquery-magnific-popup' => array(
						'registered' => true,
					),
				)
			);
			$this->set_necessary_styles(
				array(
					'magnific-popup' => array(
						'registered' => true,
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->map_list_options(
				array(
					'exclude_behavior' => array( 'slider', 'justified-gallery' ),
					'exclude_option'   => array( 'images_proportion' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'image_hover_animation',
					'title'         => esc_html__( 'Image Hover Animation', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'no',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'link_action',
					'title'         => esc_html__( 'Image Link Action', 'micdrop-core' ),
					'options'       => array(
						''           => esc_html__( 'No Action', 'micdrop-core' ),
						'open-popup' => esc_html__( 'Open Popup', 'micdrop-core' ),
					),
					'default_value' => '',
				)
			);
			$this->map_query_options( array( 'post_type' => $this->get_post_type() ) );
			$this->map_extra_options();
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['post_type'] = $this->get_post_type();

			// Additional query args
			$atts['additional_query_args'] = $this->get_additional_query_args( $atts );

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['item_classes']   = $this->get_item_classes( $atts );
			$atts['query_result']   = new \WP_Query( micdrop_core_get_query_params( $atts ) );

			$atts['this_shortcode'] = $this;

			return micdrop_core_get_template_part( 'post-types/masonry-gallery/shortcodes/masonry-gallery-list', 'templates/content', $atts['behavior'], $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-masonry-gallery-list';
			$holder_classes[] = ! empty( $atts['image_hover_animation'] ) ? 'qodef-image-hover-animation--' . $atts['image_hover_animation'] : '';
			$holder_classes[] = ! empty( $atts['link_action'] ) && 'open-popup' === $atts['link_action'] ? 'qodef-magnific-popup qodef-popup-gallery' : '';

			$list_classes   = $this->get_list_classes( $atts );
			$holder_classes = array_merge( $holder_classes, $list_classes );

			return implode( ' ', $holder_classes );
		}

		public function get_item_classes( $atts ) {
			$item_classes = $this->init_item_classes();

			$list_item_classes = $this->get_list_item_classes( $atts );

			if ( isset( $atts['layout'] ) && ! empty( $atts['layout'] ) ) {
				$list_item_classes[] = 'qodef-layout--' . $atts['layout'];
			}

			if ( isset( $atts['video_class'] ) && ! empty( $atts['video_class'] ) ) {
				$list_item_classes[] = 'qodef-has-video--yes';
			}

			if ( isset( $atts['video_behavior_class'] ) && ! empty( $atts['video_behavior_class'] ) ) {
				$list_item_classes[] = 'qodef-url--popup';
			}

			$item_classes = array_merge( $item_classes, $list_item_classes );

			return implode( ' ', $item_classes );
		}

		public function get_item_layout( $atts ) {
			$item_layout = micdrop_core_get_option_value( 'meta-box', 'qodef_masonry_gallery_item_layout', '', get_the_ID() );

			return $item_layout;
		}

		public function get_item_video_class( $atts ) {
			$video_class = micdrop_core_get_option_value( 'meta-box', 'qodef_masonry_gallery_item_video_url', '', get_the_ID() );

			return $video_class;
		}

		public function get_item_video_behavior_class( $atts ) {
			$video_behavior_class = '';

			if ( ! empty( $atts['link_action'] ) ) {
				$video_behavior_class = $atts['link_action'];
			}

			return $video_behavior_class;
		}

		public function get_item_image_dimension( $atts ) {

			if ( ! empty( $atts['behavior'] ) && 'masonry' === $atts['behavior'] && ! empty( $atts['masonry_images_proportion'] ) && 'fixed' === $atts['masonry_images_proportion'] ) {
				$image_dimension = micdrop_core_get_custom_image_size_meta( 'meta-box', 'qodef_masonry_gallery_item_dimension', get_the_ID() );
			} else {
				$image_dimension = array(
					'size'  => 'full',
					'class' => 'qodef-item--full',
				);
			}

			return $image_dimension;
		}
	}
}
