(function ( $ ) {
	'use strict';

	var horizontalLayout                              = {};
	qodefCore.shortcodes.horizontalLayout             = horizontalLayout;
	qodefCore.shortcodes.wonderment_core_scroll_right = {};

	horizontalLayout.qodefHorizontalLayout          = qodefHorizontalLayout;
	horizontalLayout.qodefElementorHorizontalLayout = qodefElementorHorizontalLayout;

	$( window ).on(
		'load',
		function () {
			qodefHorizontalLayout().init();
			qodefElementorHorizontalLayout();
		}
	);

	$( window ).resize(
		function () {
			qodefHorizontalLayout().init();
		}
	);

	/**
	 * Init Horizontal Layout Shortcode
	 */
	function qodefHorizontalLayout() {
		var $wrapper                          = $( '.qodef-hl-items-wrapper' ),
			$holder                           = $( '.qodef-horizontal-scroll-showcase' ),
			$items                            = $( '.qodef-hl-item' ),
			$scrollArea                       = $( '#qodef-hl-scroll-area' ),
			$tops                             = $( '.qodef-hli-top' ),
			$btms                             = $( '.qodef-hli-btm' ),
			$intro                            = $( '.qodef-hl-intro' ),
			$cta                              = $( '.qodef-hl-cta' ),
			$hiddenItems                      = $( '.qodef--has-horizontal-appear' ),
			$parallaxImage                    = $( '.qodef-hli-btm-bg-image-inner img' ),
			numOfItems                        = $items.length,
			btmOffset                         = 0,
			reverted                          = false,
			ctaW,
			introW,
			speed                             = 200, //vh per item
			first_item_addition_width         = 12,
			intro_section_subtractional_width = 86;

		var c, w, offset, wrapperW,
			sX = 0,
			dX = 0;

		//trigger calculations
		var calc = function () {
			setVars();
			reset();
			setX();
			setPositions();
		};

		//variables for calculation
		var setVars = function () {

			/* vertical header check */
			if ( $( '.qodef-header--vertical-sliding #qodef-page-header' ).length && window.innerWidth > 1024 ) {
				c = $( '.qodef-header--vertical-sliding #qodef-page-header' ).width();
			} else if ( $( '.qodef-header--vertical #qodef-page-header' ).length && window.innerWidth > 1024 ) {
				c = $( '.qodef-header--vertical #qodef-page-header' ).width();
			} else {
				c = 0;
			}
			w        = window.innerWidth > 1024 ? window.innerWidth / 2.84866468 : window.innerWidth;
			offset   = window.innerWidth > 1024 ? window.innerWidth / 2.84866468 : window.innerWidth;
			//intro offset offset = window.innerWidth > 1024 ? window.innerWidth / 2.59459459 : window.innerWidth;
			ctaW     = $cta.innerWidth();
			$intro.css( 'width', '100%' ); // reset width because of resize
			introW   = $intro.innerWidth() - intro_section_subtractional_width;
			wrapperW = (numOfItems - 1) * w + offset + ctaW + introW + first_item_addition_width - intro_section_subtractional_width;
		};

		//calc next x value based on scroll position
		var setX = function () {
			sX = 1 - (qodef.scroll) / (parseFloat( $scrollArea.height() ) - screen.height);
		};

		//position items incrementally to the right
		var setPositions = function () {
			$items.each( function ( i ) {
				if ( window.innerWidth > 1024 ) {
					$( this ).css(
						'right',
						(numOfItems - i - 1) * w + ctaW
					);
				} else {
					$items.removeAttr( 'style' );
				}
			} );
		};

		var val;

		//animate rAF
		var animate = function ( $active ) {
			reverted = false;
			val = Math.min(
				parseFloat( (1 - ($active.offset().left - c) / (offset - c)).toFixed( 4 ) ),
				1
			); //0-1

			//prev
			$active.prevAll( '.qodef-hl-item' ).css( {
				'width': offset + 'px'
			} );
			$active.prevAll().find( '.qodef-hli-btm-inner' ).height( '100%' );
			//active
			$active.css( {
				'width': w + (offset - w) * val + 'px'
			} );
			//next
			$active.next( '.qodef-hl-item' ).css( {
				'width': w + 'px'
			} );
		};

		//reset values
		var reset = function () {
			reverted = true;

			if ( window.innerWidth > 1024 ) {
				$items.width( w );
				$items.first().width( w + first_item_addition_width );
				$cta.css(
					'transform',
					'translate3d(100%, 0px, 0px)'
				);

				$intro.width( introW );
			}
		};

		//set active item if in between 0 and offset values
		var setActive = function () {
			var $active = $items.filter( function () {
				var $item = $( this );

				return $item.offset().left <= offset && $item.offset().left > 0;
			} );

			$active.length && animate( $active.first() );
		};

		var setVisibleClass = function () {

			$hiddenItems.each( function () {
				var item = $( this );

				if ( qodef.windowWidth - c + 100 > item.offset().left || item.offset().left <= 0 ) {
					item.not( '.qodef-appeared' ).addClass( 'qodef--appeared' );
				}
			} );
		};

		var setVisibleClassPhone = function () {

			$hiddenItems.each( function () {
				var item = $( this );

				item.appear(
					function () {
						item.addClass( 'qodef--appeared ' );
					},
					{ accX: 0, accY: -50 }
				);
			} );
		};

		//60fps render
		var render = function () {
			/*dX = lerp(dX, sX, 0.1);*/
			dX = lerp(
				sX,
				dX,
				.1
			);
			dX = Math.max(
				dX,
				0
			);
			if ( window.innerWidth > 1024 ) dX = parseFloat( dX.toFixed( 4 ) );

			if ( window.innerWidth > 1024 ) {
				$wrapper.css(
					'transform',
					'translate3d(' + dX * (wrapperW - window.innerWidth + c) + 'px, 0, 0)'
				);
				$cta.css(
					'transform',
					'translate3d(' + dX * ctaW + 'px, 0, 0)'
				);

				/* active class for z-index change */
				if ( dX === 0 ) {
					$cta.addClass( 'qodef-active-cta' );
				} else {
					$cta.removeClass( 'qodef-active-cta' );
				}

				setActive();
				! reverted && qodef.scroll == 0 && reset();

				requestAnimationFrame( render );
			} else {
				$wrapper.removeAttr( 'style' );
				$cta.removeAttr( 'style' );
				$items.removeAttr( 'style' );
			}
		};

		var parallaxBackground = function () {
			$parallaxImage.each( function () {
				var $thisItem     = $( this ),
					thisItemLeft  = $thisItem.offset().left,
					thisItemWidth = $thisItem.outerWidth(),
					thisItemRight = thisItemLeft + thisItemWidth,
					progressVal   = 0,
					modifier      = 'translateX',
					modifierUnit  = 'px',
					startValue    = 150,
					endValue      = 0;

				// Set init value
				$thisItem.waitForImages( function () {
					$thisItem.css(
						'transform',
						modifier + '(' + startValue + modifierUnit + ')'
					);
				} );

				var renderParallax = function ( $item ) {
					if ( $item.length ) {
						$item.css(
							'transform',
							modifier + '(' + (endValue + (1 - (progressVal * 1) * 1) * Math.abs( 1 - startValue )) + modifierUnit + ')'
						);
					}
					requestAnimationFrame( renderParallax );
				};

				$( window ).on(
					'scroll',
					function () {
						if ( qodef.scroll + window.innerWidth > thisItemLeft ) {
							progressVal = Math.abs( qodef.scroll + window.innerWidth - thisItemRight ) / window.innerWidth;
							if ( progressVal < 1 ) {
								$thisItem.css(
									'transform',
									modifier + '(' + (endValue + (1 - (progressVal * 1) * 1) * Math.abs( 1 - startValue )) + modifierUnit + ')'
								);
							}
						}
					}
				);
			} );
		};

		//linear interpolation
		var lerp = function ( a, b, n ) {
			return (1 - n) * a + n * b;
		};

		var init = function () {
			qodef.body.addClass( 'qodef-with-horizontal-scroll-showcase' );

			if ( window.innerWidth > 1024 ) {
				calc();
				$scrollArea.height( numOfItems * speed + 'vh' );

				if ( qodefCore.html.hasClass( 'touchevents' ) ) {
					window.addEventListener(
						'touchmove',
						setX
					);
				} else {
					window.addEventListener(
						'scroll',
						setX
					);
				}

				//resize debounce
				var resizeTimer;
				window.addEventListener(
					'resize',
					function () {
						clearTimeout( resizeTimer );
						resizeTimer = setTimeout(
							function () {
								calc();
							},
							250
						);

					}
				);

				requestAnimationFrame( render );

				setTimeout(
					function () {
						setVisibleClass();
					},
					100
				);

				setTimeout(
					function () {
						//parallaxBackground();
					},
					200
				);

				$( window ).scroll( function () {
					setVisibleClass();
				} );
			} else {
				setVisibleClassPhone();
			}
		};

		return {
			init: function () {
				$wrapper.length && init();

				setTimeout(
					function () {
						$holder.addClass( 'qodef-appear' );

						var htmlTag = $holder.closest( 'body' ).parent( 'html' );

						if ( ! htmlTag.hasClass( 'qodef-horizontal-scroll-showcase-initialized' ) ) {
							htmlTag.addClass( 'qodef-horizontal-scroll-showcase-initialized' );
						}
					},
					100
				);
			},
		};
	}

	/**
	 * Elementor
	 */
	function qodefElementorHorizontalLayout() {
		$( window ).on(
			'elementor/frontend/init',
			function () {
				elementorFrontend.hooks.addAction(
					'frontend/element_ready/qodef_horizontal_layout.default',
					function () {
						qodefHorizontalLayout().init();
					}
				);
			}
		);
	}

})( jQuery );
