<?php

if ( ! function_exists( 'micdrop_core_add_image_gallery_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_image_gallery_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Image_Gallery_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_image_gallery_shortcode' );
}

if ( class_exists( 'MicdropCore_List_Shortcode' ) ) {
	class MicdropCore_Image_Gallery_Shortcode extends MicdropCore_List_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_SHORTCODES_URL_PATH . '/image-gallery' );
			$this->set_base( 'micdrop_core_image_gallery' );
			$this->set_name( esc_html__( 'Image Gallery', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds image gallery element', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_scripts(
				array(
					'jquery-magnific-popup' => array(
						'registered' => true,
					),
				)
			);
			$this->set_necessary_styles(
				array(
					'magnific-popup' => array(
						'registered' => true,
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'images',
					'multiple'   => 'yes',
					'title'      => esc_html__( 'Images', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'image_size',
					'title'       => esc_html__( 'Image Size', 'micdrop-core' ),
					'description' => esc_html__( 'For predefined image sizes input thumbnail, medium, large or full. If you wish to set a custom image size, type in the desired image dimensions in pixels (e.g. 400x400).', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'image_border',
					'title'         => esc_html__( 'Image Border', 'micdrop-core' ),
					'description'   => esc_html__( 'Enabling this option will show border around the image ( default color is transparent ).', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'image_action',
					'title'      => esc_html__( 'Image Action', 'micdrop-core' ),
					'options'    => array(
						''            => esc_html__( 'No Action', 'micdrop-core' ),
						'open-popup'  => esc_html__( 'Open Popup', 'micdrop-core' ),
						'custom-link' => esc_html__( 'Custom Link', 'micdrop-core' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'target',
					'title'         => esc_html__( 'Custom Link Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'image_action' => array(
								'values'        => 'custom-link',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option( array(
				'field_type'    => 'textarea',
				'name'          => 'custom_links',
				'title'         => esc_html__( 'Custom Link', 'micdrop-core' ),
				'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
				'description'=> esc_html__( 'Delimit links by comma', 'micdrop-core' ),
				'dependency'    => array(
					'show' => array(
						'image_action' => array(
							'values'        => 'custom-link',
							'default_value' => ''
						)
					)
				)
			) );
			$this->set_option( array(
				'field_type'    => 'textarea',
				'name'          => 'custom_text',
				'title'         => esc_html__( 'Custom Text', 'micdrop-core' ),
				'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
				'description'=> esc_html__( 'Delimit Text by comma', 'micdrop-core' ),
				'dependency'    => array(
					'show' => array(
						'image_action' => array(
							'values'        => 'custom-link',
							'default_value' => ''
						)
					)
				)
			) );
            $this->set_option(
                array(
                    'field_type' => 'color',
                    'name'       => 'text_color',
                    'title'      => esc_html__( 'Text Color', 'micdrop-core' ),
                )
            );
			$this->set_option( array(
				'field_type'    => 'select',
				'name'          => 'image_hover_animation',
				'title'         => esc_html__( 'Image Hover Animation', 'micdrop-core' ),
				'options'	    => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
			) );
			$this->set_option( array(
				'field_type'    => 'select',
				'name'          => 'image_hover_eye',
				'title'         => esc_html__( 'Image Hover Eye', 'micdrop-core' ),
				'options'	    => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
				'dependency'    => array(
					'show' => array(
						'image_hover_animation' => array(
							'values'        => 'yes',
							'default_value' => ''
						)
					)
				),
			) );
			$this->map_list_options(
				array(
					'exclude_behavior' => array( 'justified-gallery' ),
					'exclude_option'   => array( 'images_proportion' ),
					'group'            => esc_html__( 'Gallery Settings', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'indent_slider',
					'title'      => esc_html__( 'Indent Slider', 'micdrop-core' ),
					'description' => esc_html__( 'Applicable above 1024px.', 'micdrop-core' ),
					'options'    => array(
						''                  => esc_html__( 'No', 'micdrop-core' ),
						'evenly'            => esc_html__( 'Evenly', 'micdrop-core' ),
						'more-to-the-left'  => esc_html__( 'More to the left', 'micdrop-core' ),
						'more-to-the-right' => esc_html__( 'More to the right', 'micdrop-core' ),
					),
					'default_value' => '',
					'dependency'    => array(
						'show' => array(
							'behavior' => array(
								'values'        => 'slider',
								'default_value' => '',
							),
						),
					),
					'group'            => esc_html__( 'Gallery Settings', 'micdrop-core' ),
				)
			);
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_image_gallery', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function load_assets() {

			if ( isset( $atts['image_action'] ) && 'open-popup' === $atts['image_action'] ) {
				wp_enqueue_style( 'magnific-popup' );
				wp_enqueue_script( 'jquery-magnific-popup' );
			}
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['item_classes']   = $this->get_item_classes( $atts );
			$atts['slider_attr']    = $this->get_slider_data( $atts );
			$atts['images']         = $this->generate_images_params( $atts );
			$atts['custom_links']   = $this->getCustomLinks( $atts );
			$atts['custom_text']    = $this->getCustomText( $atts );
			$atts['text_color']     = $this->getTextColor( $atts );

			return micdrop_core_get_template_part( 'shortcodes/image-gallery', 'templates/image-gallery', $atts['behavior'], $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-image-gallery';
			$holder_classes[] = ! empty( $atts['image_hover_animation'] ) ? 'qodef-image-hover-animation--' . $atts['image_hover_animation'] : '';
			$holder_classes[] = 'yes' === $atts['image_hover_eye']  ? 'qodef-image-hover--eye' : '';
			$holder_classes[] = ! empty( $atts['image_action'] ) && 'open-popup' === $atts['image_action'] ? 'qodef-magnific-popup qodef-popup-gallery' : '';
			$holder_classes[] = ! empty( $atts['indent_slider'] ) && 'slider' === $atts['behavior'] ? 'qodef-indent-slider--' . $atts['indent_slider'] : '';
			$holder_classes[] = ! empty( $atts['image_border'] ) ? 'qodef-image-border--' . $atts['image_border'] : '';

			$list_classes   = $this->get_list_classes( $atts );
			$holder_classes = array_merge( $holder_classes, $list_classes );

			return implode( ' ', $holder_classes );
		}

		private function getCustomLinks( $atts ) {
			$custom_links = array();

			if ( ! empty( $atts['custom_links'] ) ) {
				$custom_links = array_map( 'trim', explode( ',', $atts['custom_links'] ) );
			}

			return $custom_links;
		}

		private function getCustomText( $atts ) {
			$custom_text = array();

			if ( ! empty( $atts['custom_text'] ) ) {
				$custom_text = array_map( 'trim', explode( ',', $atts['custom_text'] ) );
			}

			return $custom_text;
		}

		//getTextColor
        private function getTextColor( $atts ) {
            $styles = array();

            if ( ! empty( $atts['text_color'] ) ) {
                $styles[] = 'color: ' . $atts['text_color'];
            }

            return $styles;
        }

		public function get_item_classes( $atts ) {
			$item_classes   = $this->init_item_classes();
			$item_classes[] = 'qodef-image-wrapper';

			$list_item_classes = $this->get_list_item_classes( $atts );

			$item_classes = array_merge( $item_classes, $list_item_classes );

			return implode( ' ', $item_classes );
		}

		private function generate_images_params( $atts ) {
			$image_ids = array();
			$images    = array();
			$i         = 0;

			if ( '' !== $atts['images'] && is_string( $atts['images'] ) ) {
				$image_ids = explode( ',', $atts['images'] );
			}

			$image_size = $this->generate_image_size( $atts );

			foreach ( $image_ids as $id ) {

				$image['image_id']   = intval( $id );
				$image_original      = wp_get_attachment_image_src( $id, 'full' );
				$image['url']        = $this->generate_image_url( $id, $atts, $image_original[0] );
				$image['alt']        = get_post_meta( $id, '_wp_attachment_image_alt', true );
				$image['image_size'] = $image_size;

				$images[ $i ] = $image;
				$i ++;
			}

			return $images;
		}

		private function generate_image_size( $atts ) {
			$image_size = trim( $atts['image_size'] );
			preg_match_all( '/\d+/', $image_size, $matches ); /* check if numeral width and height are entered */
			if ( in_array( $image_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full' ), true ) ) {
				return $image_size;
			} elseif ( ! empty( $matches[0] ) ) {
				return array(
					$matches[0][0],
					$matches[0][1],
				);
			} else {
				return 'full';
			}
		}

		private function generate_image_url( $id, $atts, $default ) {
			if ( 'custom-link' === $atts['image_action'] ) {
				$url = get_post_meta( $id, 'qodef_image_gallery_custom_link', true );
				if ( empty( $url ) ) {
					$url = $default;
				}
			} else {
				$url = $default;
			}

			return $url;
		}
	}
}
