<?php

if ( ! function_exists( 'micdrop_core_add_image_with_text_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_image_with_text_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Image_With_Text_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_image_with_text_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_Image_With_Text_Shortcode extends MicdropCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'micdrop_core_filter_image_with_text_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'micdrop_core_filter_image_with_text_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_SHORTCODES_URL_PATH . '/image-with-text' );
			$this->set_base( 'micdrop_core_image_with_text' );
			$this->set_name( esc_html__( 'Image With Text', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds image with text element', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_scripts(
				array(
					'jquery-magnific-popup' => array(
						'registered' => true,
					),
				)
			);
			$this->set_necessary_styles(
				array(
					'magnific-popup' => array(
						'registered' => true,
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'skin',
					'title'         => esc_html__( 'Skin', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'skin', true, array( 'light' ) ),
					'default_value' => '',
				)
			);

			$options_map = micdrop_core_get_variations_options_map( $this->get_layouts() );

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'micdrop-core' ),
					'options'       => $this->get_layouts(),
					'default_value' => $options_map['default_value'],
					'visibility'    => array( 'map_for_page_builder' => $options_map['visibility'] ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'image',
					'title'      => esc_html__( 'Image', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'video_url',
					'title'       => esc_html__( 'Video URL', 'micdrop-core' ),
					'description' => esc_html__( 'Input self hosted video link here and it will be displayed instead of the image.', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'image_hover_animation',
					'title'         => esc_html__( 'Image Hover Animation', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'yes',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'decoration_dots',
					'title'         => esc_html__( 'Show Decoration Dots', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'yes',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'decoration_dots_color',
					'title'      => esc_html__( 'Decoration Dots Color', 'micdrop-core' ),
					'dependency' => array(
						'hide' => array(
							'decoration_dots' => array(
								'values'        => 'no',
								'default_value' => 'yes',
							),
						),
					),

				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'image_border',
					'title'         => esc_html__( 'Image Border', 'micdrop-core' ),
					'description'   => esc_html__( 'Enabling this option will show border around the image ( default color is transparent ).', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'image_border_color',
					'title'      => esc_html__( 'Border Color', 'micdrop-core' ),
					'dependency' => array(
						'hide' => array(
							'image_border' => array(
								'values'        => 'no',
								'default_value' => 'yes',
							),
						),
					),

				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'image_size',
					'title'       => esc_html__( 'Image Size', 'micdrop-core' ),
					'description' => esc_html__( 'For predefined image sizes input thumbnail, medium, large or full. If you wish to set a custom image size, type in the desired image dimensions in pixels (e.g. 400x400).', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'image_action',
					'title'      => esc_html__( 'Image Action', 'micdrop-core' ),
					'options'    => array(
						''            => esc_html__( 'No Action', 'micdrop-core' ),
						'open-popup'  => esc_html__( 'Open Popup', 'micdrop-core' ),
						'custom-link' => esc_html__( 'Custom Link', 'micdrop-core' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'link',
					'title'      => esc_html__( 'Custom Link', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'image_action' => array(
								'values'        => 'custom-link',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'target',
					'title'         => esc_html__( 'Custom Link Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'image_action' => array(
								'values'        => 'custom-link',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title',
					'title'      => esc_html__( 'Title', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'title_tag',
					'title'         => esc_html__( 'Title Tag', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'title_tag', true ),
					'default_value' => 'h6',
					'group'         => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'title_color',
					'title'      => esc_html__( 'Title Color', 'micdrop-core' ),
					'group'      => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_margin_top',
					'title'      => esc_html__( 'Title Margin Top', 'micdrop-core' ),
					'group'      => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'textarea',
					'name'       => 'text',
					'title'      => esc_html__( 'Text', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'text_color',
					'title'      => esc_html__( 'Text Color', 'micdrop-core' ),
					'group'      => esc_html__( 'Text Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'text_margin_top',
					'title'      => esc_html__( 'Text Margin Top', 'micdrop-core' ),
					'group'      => esc_html__( 'Text Style', 'micdrop-core' ),
				)
			);
			$this->map_extra_options();
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_image_with_text', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function load_assets() {
			$atts = $this->get_atts();

			if ( isset( $atts['image_action'] ) && 'open-popup' === $atts['image_action'] ) {
				wp_enqueue_style( 'magnific-popup' );
				wp_enqueue_script( 'jquery-magnific-popup' );
			}
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes']    = $this->get_holder_classes( $atts );
			$atts['title_styles']      = $this->get_title_styles( $atts );
			$atts['text_styles']       = $this->get_text_styles( $atts );
			$atts['dots_styles']       = $this->get_dots_styles( $atts );
			$atts['img_border_styles'] = $this->get_img_border_styles( $atts );
			$atts['image_params']      = $this->generate_image_params( $atts );

			return micdrop_core_get_template_part( 'shortcodes/image-with-text', 'variations/' . $atts['layout'] . '/templates/' . $atts['layout'], '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-image-with-text';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['skin'] ) ? 'qodef-skin--' . $atts['skin'] : '';
			$holder_classes[] = ! empty( $atts['image_hover_animation'] ) ? 'qodef-image-hover-animation--' . $atts['image_hover_animation'] : '';
			$holder_classes[] = ! empty( $atts['decoration_dots'] ) ? 'qodef-image-decoration-dots--' . $atts['decoration_dots'] : '';
			$holder_classes[] = ! empty( $atts['image_border'] ) ? 'qodef-image-border--' . $atts['image_border'] : '';
			$holder_classes[] = ! empty( $atts['video_url'] ) ? 'qodef-has-video--yes' : '';

			return implode( ' ', $holder_classes );
		}

		private function get_title_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['title_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['title_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['title_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['title_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['title_color'] ) ) {
				$styles[] = 'color: ' . $atts['title_color'];
			}

			return $styles;
		}

		private function get_text_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['text_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['text_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['text_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['text_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['text_color'] ) ) {
				$styles[] = 'color: ' . $atts['text_color'];
			}

			return $styles;
		}

		private function get_dots_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['decoration_dots_color'] ) ) {
				$styles[] = 'color: ' . $atts['decoration_dots_color'];
			}

			return $styles;
		}

		private function get_img_border_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['image_border_color'] ) ) {
				$styles[] = 'color: ' . $atts['image_border_color'];
			}

			return $styles;
		}

		private function generate_image_params( $atts ) {
			$image = array();

			if ( ! empty( $atts['image'] ) ) {
				$id = $atts['image'];

				$image['image_id'] = intval( $id );
				$image_original    = wp_get_attachment_image_src( $id, 'full' );
				$image['url']      = $image_original[0];
				$image['alt']      = get_post_meta( $id, '_wp_attachment_image_alt', true );

				$image_size = trim( $atts['image_size'] );
				preg_match_all( '/\d+/', $image_size, $matches ); /* check if numeral width and height are entered */
				if ( in_array( $image_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full' ), true ) ) {
					$image['image_size'] = $image_size;
				} elseif ( ! empty( $matches[0] ) ) {
					$image['image_size'] = array(
						$matches[0][0],
						$matches[0][1]
					);
				} else {
					$image['image_size'] = 'full';
				}
			}

			return $image;
		}
	}
}
