<?php

if ( ! function_exists( 'micdrop_core_add_section_title_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_section_title_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Section_Title_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_section_title_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_Section_Title_Shortcode extends MicdropCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_SHORTCODES_URL_PATH . '/section-title' );
			$this->set_base( 'micdrop_core_section_title' );
			$this->set_name( esc_html__( 'Section Title', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds section title element', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle',
					'title'      => esc_html__( 'Subtitle', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'subtitle_color',
					'title'      => esc_html__( 'Subtitle Color', 'micdrop-core' ),
					'group'      => esc_html__( 'Subtitle Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title',
					'title'      => esc_html__( 'Title', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'line_break_positions',
					'title'       => esc_html__( 'Positions of Line Break', 'micdrop-core' ),
					'description' => esc_html__( 'Enter the positions of the words after which you would like to create a line break. Separate the positions with commas (e.g. if you would like the first, third, and fourth word to have a line break, you would enter "1,3,4")', 'micdrop-core' ),
					'group'       => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'disable_title_break_words',
					'title'         => esc_html__( 'Disable Title Line Break', 'micdrop-core' ),
					'description'   => esc_html__( 'Enabling this option will disable title line breaks for screen size 1024 and lower', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
					'group'         => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'title_tag',
					'title'         => esc_html__( 'Title Tag', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h4',
					'group'         => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'title_color',
					'title'      => esc_html__( 'Title Color', 'micdrop-core' ),
					'group'      => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_margin',
					'title'      => esc_html__( 'Title Margin (10px 0 5px)', 'micdrop-core' ),
					'group'      => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'enable_bottom_border',
					'title'      => esc_html__( 'Show Bottom Border', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'no_yes' ),
					'group'      => esc_html__( 'Title Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'link',
					'title'      => esc_html__( 'Title Custom Link', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'target',
					'title'         => esc_html__( 'Custom Link Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'image_action' => array(
								'values'        => 'custom-link',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'textarea',
					'name'       => 'content_text',
					'title'      => esc_html__( 'Text', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'text_color',
					'title'      => esc_html__( 'Text Color', 'micdrop-core' ),
					'group'      => esc_html__( 'Text Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'text_margin_top',
					'title'      => esc_html__( 'Text Margin Top', 'micdrop-core' ),
					'group'      => esc_html__( 'Text Style', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'content_alignment',
					'title'      => esc_html__( 'Content Alignment', 'micdrop-core' ),
					'options'    => array(
						''       => esc_html__( 'Default', 'micdrop-core' ),
						'left'   => esc_html__( 'Left', 'micdrop-core' ),
						'center' => esc_html__( 'Center', 'micdrop-core' ),
						'right'  => esc_html__( 'Right', 'micdrop-core' ),
					),
				)
			);
			$this->import_shortcode_options(
				array(
					'shortcode_base'    => 'micdrop_core_button',
					'exclude'           => array( 'custom_class' ),
					'additional_params' => array(
						'nested_group' => esc_html__( 'Button', 'micdrop-core' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'show_purchase_button',
					'title'      => esc_html__( 'Show Purchase Button', 'micdrop-core' ),
					'options'    => micdrop_core_get_select_type_options_pool( 'no_yes' ),
					'group'      => esc_html__( 'Purchase Button', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'purchase_button_text',
					'title'         => esc_html__( 'Purchase Button Text', 'micdrop-core' ),
					'default_value' => 'Buy',
					'group'         => esc_html__( 'Purchase Button', 'micdrop-core' ),
					'dependency'    => array(
						'show' => array(
							'show_purchase_button' => array(
								'values'        => 'yes',
								'default_value' => '',
								'size'          => 'large',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'purchase_button_link',
					'title'      => esc_html__( 'Purchase Button Link', 'micdrop-core' ),
					'group'      => esc_html__( 'Purchase Button', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'show_purchase_button' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'purchase_button_target',
					'title'         => esc_html__( 'Purchase Button Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'group'         => esc_html__( 'Purchase Button', 'micdrop-core' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'show_purchase_button' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'buttons_holder_margin_top',
					'title'      => esc_html__( 'Buttons Holder Margin Top', 'micdrop-core' ),
					'group'      => esc_html__( 'Buttons Holder Style', 'micdrop-core' ),
				)
			);
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes']         = $this->get_holder_classes( $atts );
			$atts['title']                  = $this->get_modified_title( $atts );
			$atts['subtitle_styles']        = $this->get_subtitle_styles( $atts );
			$atts['title_styles']           = $this->get_title_styles( $atts );
			$atts['text_styles']            = $this->get_text_styles( $atts );
			$atts['button_params']          = $this->generate_button_params( $atts );
			$atts['purchase_button_params'] = $this->generate_purchase_button_params( $atts );
			$atts['buttons_holder_styles']  = $this->get_buttons_holder_styles( $atts );

			return micdrop_core_get_template_part( 'shortcodes/section-title', 'templates/section-title', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-section-title';
			$holder_classes[] = ! empty( $atts['content_alignment'] ) ? 'qodef-alignment--' . $atts['content_alignment'] : 'qodef-alignment--left';
			$holder_classes[] = ! empty( $atts['show_purchase_button'] ) ? 'qodef-purchase-btn--' . $atts['show_purchase_button'] : '';
			$holder_classes[] = 'yes' === $atts['disable_title_break_words'] ? 'qodef-title-break--disabled' : '';
			$holder_classes[] = 'yes' === $atts['enable_bottom_border'] ? 'qodef-title-border-bottom' : '';

			return implode( ' ', $holder_classes );
		}

		private function get_modified_title( $atts ) {
			$title = $atts['title'];

			if ( ! empty( $title ) && ! empty( $atts['line_break_positions'] ) ) {
				$split_title          = explode( ' ', $title );
				$line_break_positions = explode( ',', str_replace( ' ', '', $atts['line_break_positions'] ) );

				foreach ( $line_break_positions as $position ) {
					$position = intval( $position );
					if ( isset( $split_title[ $position - 1 ] ) && ! empty( $split_title[ $position - 1 ] ) ) {
						$split_title[ $position - 1 ] = $split_title[ $position - 1 ] . '<br />';
					}
				}

				$title = implode( ' ', $split_title );
			}

			return $title;
		}

		private function get_title_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['title_color'] ) ) {
				$styles[] = 'color: ' . $atts['title_color'];
			}

			if ( ! empty( $atts['title_margin'] ) ) {
				$styles[] = 'margin: ' . $atts['title_margin'];
			}

			return $styles;
		}

		private function get_subtitle_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['subtitle_color'] ) ) {
				$styles[] = 'color: ' . $atts['subtitle_color'];
			}

			return $styles;
		}

		private function get_text_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['text_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['text_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['text_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['text_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['text_color'] ) ) {
				$styles[] = 'color: ' . $atts['text_color'];
			}

			return $styles;
		}

		private function generate_button_params( $atts ) {
			$params = $this->populate_imported_shortcode_atts(
				array(
					'shortcode_base' => 'micdrop_core_button',
					'exclude'        => array( 'custom_class' ),
					'atts'           => $atts,
				)
			);

			return $params;
		}

		private function generate_purchase_button_params( $atts ) {
			$params = array(
				'custom_class'  => 'qodef-purchase-button',
				'button_layout' => 'filled',
				'text'          => $atts['purchase_button_text'],
				'link'          => $atts['purchase_button_link'],
				'target'        => $atts['purchase_button_target'],
			);

			return $params;
		}

		private function get_buttons_holder_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['buttons_holder_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['buttons_holder_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['buttons_holder_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['buttons_holder_margin_top'] ) . 'px';
				}
			}

			return $styles;
		}
	}
}
