<?php

if ( ! function_exists( 'micdrop_core_add_video_holder_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_video_holder_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Video_Holder_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_video_holder_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_Video_Holder_Shortcode extends MicdropCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_SHORTCODES_URL_PATH . '/video-holder' );
			$this->set_base( 'micdrop_core_video_holder' );
			$this->set_name( esc_html__( 'Video Holder', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds video holder element', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'video_source',
					'title'      => esc_html__( 'Link to Self Hosted Video', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'hidden',
					'name'       => 'video_image_fallback',
					'title'      => esc_html__( 'Image Fallback for the Video', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'enable_appear',
					'title'         => esc_html__( 'Enable Appear Animation', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes' ),
					'default_value' => 'no',
				)
			);
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'micdrop_core_video_holder', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );

			return micdrop_core_get_template_part( 'shortcodes/video-holder', 'templates/video-holder', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-video-holder';
			$holder_classes[] = ! empty( $atts['enable_appear'] ) && 'yes' === $atts['enable_appear'] ? 'qodef--has-appear' : '';

			return implode( ' ', $holder_classes );
		}
	}
}
