<?php

if ( ! function_exists( 'micdrop_core_add_video_with_interactive_banners_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function micdrop_core_add_video_with_interactive_banners_shortcode( $shortcodes ) {
		$shortcodes[] = 'MicdropCore_Video_With_Interactive_Banners_Shortcode';

		return $shortcodes;
	}

	add_filter( 'micdrop_core_filter_register_shortcodes', 'micdrop_core_add_video_with_interactive_banners_shortcode' );
}

if ( class_exists( 'MicdropCore_Shortcode' ) ) {
	class MicdropCore_Video_With_Interactive_Banners_Shortcode extends MicdropCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( MICDROP_CORE_SHORTCODES_URL_PATH . '/video-with-interactive-banners' );
			$this->set_base( 'micdrop_core_video_with_interactive_banners' );
			$this->set_name( esc_html__( 'Video With Interactive Banners', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds video with interactive banners holder', 'micdrop-core' ) );
			$this->set_category( esc_html__( 'Micdrop Core', 'micdrop-core' ) );
			$this->set_scripts(
				array(
					'jquery-appear'     => array(
						'registered' => true,
					),
					'perfect-scrollbar' => array(
						'registered' => false,
						'url'        => MICDROP_CORE_URL_PATH . 'assets/plugins/perfect-scrollbar/perfect-scrollbar.jquery.min.js',
						'dependency' => array( 'jquery' ),
					),
				)
			);
			$this->set_necessary_styles(
				array(
					'perfect-scrollbar' => array(
						'registered' => false,
						'url'        => MICDROP_CORE_URL_PATH . 'assets/plugins/perfect-scrollbar/perfect-scrollbar.css',
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'maintain_full_height',
					'title'         => esc_html__( 'Maintain Full Height', 'micdrop-core' ),
					'description'   => esc_html__( 'Useful when this is topmost section on the page so element will be reduced for header height', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'fixed_area_position',
					'title'         => esc_html__( 'Fixed Area Position', 'micdrop-core' ),
					'options'       => array(
						''      => esc_html__( 'Default', 'micdrop-core' ),
						'right' => esc_html__( 'Right', 'micdrop-core' ),
					),
					'default_value' => '',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'fixed_area_content',
					'title'         => esc_html__( 'Fixed Area Content', 'micdrop-core' ),
					'options'       => array(
						'video' => esc_html__( 'Video', 'micdrop-core' ),
						'image' => esc_html__( 'Image', 'micdrop-core' ),
					),
					'default_value' => 'video',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'fixed_area_video',
					'title'      => esc_html__( 'Fixed Area Video', 'micdrop-core' ),
					'dependency' => array(
						'show' => array(
							'fixed_area_content' => array(
								'values'        => 'video',
								'default_value' => 'video',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'image',
					'name'        => 'fixed_area_image',
					'title'       => esc_html__( 'Fixed Area Image', 'micdrop-core' ),
					'description' => esc_html__( 'Used as fallback when Fixed Area Content is set to Video', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'fixed_area_title',
					'title'      => esc_html__( 'Fixed Area Title', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'fixed_area_title_tag',
					'title'         => esc_html__( 'Fixed Area Title Tag', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h1',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'fixed_area_title_font_size',
					'title'      => esc_html__( 'Fixed Area Title Font Size', 'micdrop-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'link_target',
					'title'         => esc_html__( 'Link Target', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'repeater',
					'name'       => 'children',
					'title'      => esc_html__( 'Banner Items', 'micdrop-core' ),
					'items'      => array(
						array(
							'field_type'    => 'text',
							'name'          => 'item_link',
							'title'         => esc_html__( 'Link', 'micdrop-core' ),
							'default_value' => '',
						),
						array(
							'field_type'    => 'text',
							'name'          => 'item_title',
							'title'         => esc_html__( 'Title', 'micdrop-core' ),
							'default_value' => '',
						),
						array(
							'field_type' => 'image',
							'name'       => 'item_image',
							'title'      => esc_html__( 'Item Image', 'micdrop-core' ),
						),
					),
				)
			);
			$this->map_extra_options();
		}

		public function load_assets() {
			wp_enqueue_script( 'jquery-appear' );
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['title_styles']   = $this->get_title_styles( $atts );
			$atts['items']          = $this->parse_repeater_items( $atts['children'] );

			return micdrop_core_get_template_part( 'shortcodes/video-with-interactive-banners', 'templates/video-with-interactive-banners', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-video-with-interactive-banners';
			$holder_classes[] = ! empty( $atts['fixed_area_title_font_size'] ) ? 'qodef-custom-font-size--yes' : '';
			$holder_classes[] = ! empty( $atts['maintain_full_height'] ) && 'yes' === $atts['maintain_full_height'] ? 'qodef-maintain-full-height--yes' : '';
			$holder_classes[] = ! empty( $atts['fixed_area_position'] ) ? 'qodef-fixed-area-position--' . $atts['fixed_area_position'] : '';

			return implode( ' ', $holder_classes );
		}

		private function get_title_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['fixed_area_title_font_size'] ) {
				if ( qode_framework_string_ends_with_typography_units( $atts['fixed_area_title_font_size'] ) ) {
					$styles[] = 'font-size: ' . $atts['fixed_area_title_font_size'];
				} else {
					$styles[] = 'font-size: ' . intval( $atts['fixed_area_title_font_size'] ) . 'px';
				}
			}

			return $styles;
		}
	}
}
