(function ( $ ) {
	'use strict';
	
	$( document ).ready(
		function () {
			qodefSpinner.init();
		}
	);
	
	$( window ).on(
		'load',
		function () {
			qodefSpinner.windowLoaded = true;
			
			if (document.visibilityState === 'visible') {
				qodefSpinner.fadeOutLoader();
			} else {
				if ( $('#qodef-page-spinner.qodef-layout--textual').length ) {
					$('#qodef-page-spinner.qodef-layout--textual').addClass('qodef--animation-paused');
				}
				
				document.addEventListener("visibilitychange", function() {
					if (document.visibilityState === 'visible') {
						if ( $('#qodef-page-spinner.qodef-layout--textual').length ){
							$('#qodef-page-spinner.qodef-layout--textual').removeClass('qodef--animation-paused');
							qodefSpinner.animateSpinner();
						} else {
							qodefSpinner.fadeOutLoader();
						}
					}
				});
			}
		}
	);
	
	$( window ).on(
		'elementor/frontend/init',
		function () {
			var isEditMode = Boolean( elementorFrontend.isEditMode() );
			
			if ( isEditMode ) {
				qodefSpinner.init( isEditMode );
			}
		}
	);
	
	var qodefSpinner = {
		holder: '',
		windowLoaded: false,
		init: function ( isEditMode ) {
			this.holder = $( '#qodef-page-spinner:not(.qodef--custom-spinner)' );
			
			if ( this.holder.length ) {
				qodefSpinner.animateSpinner( isEditMode );
			}
		},
		animateSpinner: function ( isEditMode ) {
			if ( isEditMode ) {
				qodefSpinner.fadeOutLoader();
			} else if ( this.holder.hasClass('qodef-layout--textual') ){
				var line = this.holder.find('.qodef-e-line'),
					text1 = this.holder.find('.qodef-e-text-1'),
					text2 = this.holder.find('.qodef-e-text-2'),
					text3 = this.holder.find('.qodef-e-text-3'),
					textHolder = this.holder.find('.qodef-m-textual'),
					
				    docStyle = getComputedStyle(document.documentElement),
					spinnerElement = document.querySelector('#qodef-page-spinner .qodef-m-inner'),
					spinnerStyle = getComputedStyle(spinnerElement),
					spinnerColor = spinnerStyle.color,
					
					textColorInitial = spinnerColor,
					textColorAnimated = docStyle.getPropertyValue("--qode-secondary-color");
				
				var tl = gsap.timeline({
					paused: true,
					onUpdate: ()=> {
						if (this.holder.hasClass('qodef--animation-paused')){
							tl.pause();
						}
					}
				})
				
				tl
					.addLabel("lineAppeared", ">")
					.fromTo(line ,{
						xPercent: -101,
						opacity: 1,
					},{
						duration: .7,
						delay: .3,
						xPercent: 0,
						ease: 'power3.out',
						onComplete: () => {
							gsap.to( text1 , {
								opacity: 0,
								clearProps: "color",
								duration: 0
							});
							gsap.set( text2 , {
								opacity: 1,
								color: textColorAnimated,
							});
						}
					})
					.to(text1, {
						color: textColorAnimated,
						duration: .4,
					},'<')
					.to(line , {
						duration: .7,
						xPercent: 101,
						ease: 'power3.inOut',
					})
					.to(text2, {
						color: textColorInitial,
						duration: .4,
					},'>-0.2')
					.fromTo(line ,{
						xPercent: -101,
					},{
						duration: .7,
						xPercent: 0,
						delay: .2,
						ease: 'power3.out',
						onComplete: () => {
							gsap.to( text2 , {
								opacity: 0,
								clearProps: "color",
								duration: 0
							});
							gsap.set( text3 , {
								opacity: 1,
								color: textColorAnimated,
							});
						}
					})
					.to(line , {
						duration: .9,
						xPercent: 101,
						ease: 'power3.inOut',
					})
					.to(text3, {
						color: textColorInitial,
						duration: .4,
						onComplete: () => {
							if (qodefSpinner.windowLoaded) {
								this.holder.removeClass('qodef--textual-spinner-animating');
								qodefSpinner.fadeOutLoader();
								tl.pause();
							}
						},
					},'>-0.2')
					.fromTo(line ,{
						xPercent: -101,
					},{
						duration: .7,
						delay: .2,
						xPercent: 0,
						ease: 'power3.out',
						onComplete: () => {
							gsap.to( text3 , {
								opacity: 0,
								clearProps: "color",
								duration: 0
							});
							gsap.set( text1 , {
								opacity: 1,
								color: textColorAnimated,
							});
						}
					})
					.to(line , {
						duration: .9,
						xPercent: 101,
						ease: 'power3.inOut',
					})
					.to(text1, {
						color: textColorInitial,
						duration: .4,
						onComplete: () => {
							tl.play("lineAppeared");
						},
					},'>-0.2')
				
				
				gsap.to(textHolder,{
					opacity: 1,
					duration: .7,
					onStart: () =>{
						this.holder.addClass('qodef--textual-spinner-animating');
					},
					onComplete: () => {
						tl.play();
					},
				})
			}
		},
		fadeOutLoader: function ( speed, delay, easing ) {
			speed  = speed ? speed : 1000;
			delay  = delay? delay : 100;
			easing = easing ? easing : 'swing';
			
			var $holder = qodefSpinner.holder.length ? qodefSpinner.holder : $( '#qodef-page-spinner:not(.qodef--custom-spinner)' ),
				mainRevHolder = $('#qodef-main-rev-holder');
			
			
			if (!$holder.hasClass('qodef--textual-spinner-animating')){
				$holder.delay( delay ).fadeOut( speed, easing );
				
				if(mainRevHolder.length){
					setTimeout(function(){
						mainRevHolder.find('rs-module').revstart();
					}, delay + 300);
				}
				
				$( window ).on(
					'bind',
					'pageshow',
					function ( event ) {
						if ( event.originalEvent.persisted ) {
							$holder.fadeOut( speed, easing );
						}
					}
				);
			}
		}
	};
	
})( jQuery );