<?php

if ( ! function_exists( 'micdrop_core_add_page_title_options' ) ) {
	/**
	 * Function that add general options for this module
	 */
	function micdrop_core_add_page_title_options() {
		$qode_framework = qode_framework_get_framework_root();

		$page = $qode_framework->add_options_page(
			array(
				'scope'       => MICDROP_CORE_OPTIONS_NAME,
				'type'        => 'admin',
				'slug'        => 'title',
				'icon'        => 'fa fa-cog',
				'title'       => esc_html__( 'Title', 'micdrop-core' ),
				'description' => esc_html__( 'Global Title Options', 'micdrop-core' ),
			)
		);

		if ( $page ) {
			$page->add_field_element(
				array(
					'field_type'    => 'yesno',
					'name'          => 'qodef_enable_page_title',
					'title'         => esc_html__( 'Enable Page Title', 'micdrop-core' ),
					'description'   => esc_html__( 'Use this option to enable/disable page title', 'micdrop-core' ),
					'default_value' => 'yes',
				)
			);

			$page_title_section = $page->add_section_element(
				array(
					'name'       => 'qodef_page_title_section',
					'title'      => esc_html__( 'Title Area', 'micdrop-core' ),
					'dependency' => array(
						'hide' => array(
							'qodef_enable_page_title' => array(
								'values'        => 'no',
								'default_value' => '',
							),
						),
					),
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_title_layout',
					'title'         => esc_html__( 'Title Layout', 'micdrop-core' ),
					'description'   => esc_html__( 'Choose a title layout', 'micdrop-core' ),
					'options'       => apply_filters( 'micdrop_core_filter_title_layout_options', array() ),
					'default_value' => 'standard',
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'    => 'yesno',
					'name'          => 'qodef_set_page_title_area_in_grid',
					'title'         => esc_html__( 'Page Title In Grid', 'micdrop-core' ),
					'description'   => esc_html__( 'Enabling this option will set page title area to be in grid', 'micdrop-core' ),
					'default_value' => 'yes',
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_set_full_width_title_area_side_padding',
					'title'       => esc_html__( 'Full Width Title Side Padding', 'micdrop-core' ),
					'description' => esc_html__( 'Enter side padding for full width title area', 'micdrop-core' ),
					'args'        => array(
						'suffix' => esc_html__( 'px or %', 'micdrop-core' ),
					),
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_page_title_height',
					'title'       => esc_html__( 'Height', 'micdrop-core' ),
					'description' => esc_html__( 'Enter title height', 'micdrop-core' ),
					'args'        => array(
						'suffix' => esc_html__( 'px', 'micdrop-core' ),
					),
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_page_title_height_on_smaller_screens',
					'title'       => esc_html__( 'Height on Smaller Screens', 'micdrop-core' ),
					'description' => esc_html__( 'Enter title height to be displayed on smaller screens with active mobile header', 'micdrop-core' ),
					'args'        => array(
						'suffix' => esc_html__( 'px', 'micdrop-core' ),
					),
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'  => 'color',
					'name'        => 'qodef_page_title_background_color',
					'title'       => esc_html__( 'Background Color', 'micdrop-core' ),
					'description' => esc_html__( 'Enter page title area background color', 'micdrop-core' ),
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'  => 'image',
					'name'        => 'qodef_page_title_background_image',
					'title'       => esc_html__( 'Background Image', 'micdrop-core' ),
					'description' => esc_html__( 'Enter page title area background image', 'micdrop-core' ),
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type' => 'select',
					'name'       => 'qodef_page_title_background_image_behavior',
					'title'      => esc_html__( 'Background Image Behavior', 'micdrop-core' ),
					'options'    => array(
						''           => esc_html__( 'Default', 'micdrop-core' ),
						'responsive' => esc_html__( 'Set Responsive Image', 'micdrop-core' ),
						'parallax'   => esc_html__( 'Set Parallax Image', 'micdrop-core' ),
					),
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type' => 'color',
					'name'       => 'qodef_page_title_color',
					'title'      => esc_html__( 'Title Color', 'micdrop-core' ),
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_page_title_tag',
					'title'         => esc_html__( 'Title Tag', 'micdrop-core' ),
					'description'   => esc_html__( 'Enabling this option will set title tag', 'micdrop-core' ),
					'options'       => micdrop_core_get_select_type_options_pool( 'title_tag', false ),
					'default_value' => 'h1',
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_page_title_text_alignment',
					'title'         => esc_html__( 'Text Alignment', 'micdrop-core' ),
					'options'       => array(
						'left'   => esc_html__( 'Left', 'micdrop-core' ),
						'center' => esc_html__( 'Center', 'micdrop-core' ),
						'right'  => esc_html__( 'Right', 'micdrop-core' ),
					),
					'default_value' => 'left',
				)
			);

			$page_title_section->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_page_title_vertical_text_alignment',
					'title'         => esc_html__( 'Vertical Text Alignment', 'micdrop-core' ),
					'options'       => array(
						'vertical-center' => esc_html__( 'Vertical Center', 'micdrop-core' ),
						'header-bottom'   => esc_html__( 'From Bottom of Header', 'micdrop-core' ),
						'window-top'      => esc_html__( 'From Window Top', 'micdrop-core' ),
					),
					'default_value' => 'vertical-center',
				)
			);

			// Hook to include additional options after module options
			do_action( 'micdrop_core_action_after_page_title_options_map', $page_title_section );
		}
	}

	add_action( 'micdrop_core_action_default_options_init', 'micdrop_core_add_page_title_options', micdrop_core_get_admin_options_map_position( 'title' ) );
}
