<?php

if ( ! function_exists( 'micdrop_core_add_author_info_widget' ) ) {
	/**
	 * Function that add widget into widgets list for registration
	 *
	 * @param array $widgets
	 *
	 * @return array
	 */
	function micdrop_core_add_author_info_widget( $widgets ) {
		$widgets[] = 'MicdropCore_Author_Info_Widget';

		return $widgets;
	}

	add_filter( 'micdrop_core_filter_register_widgets', 'micdrop_core_add_author_info_widget' );
}

if ( class_exists( 'QodeFrameworkWidget' ) ) {
	class MicdropCore_Author_Info_Widget extends QodeFrameworkWidget {

		public function map_widget() {
			$this->set_base( 'micdrop_core_author_info' );
			$this->set_name( esc_html__( 'Micdrop Author Info', 'micdrop-core' ) );
			$this->set_description( esc_html__( 'Add author info element into widget areas', 'micdrop-core' ) );
			$this->set_widget_option(
				array(
					'field_type' => 'text',
					'name'       => 'author_username',
					'title'      => esc_html__( 'Author Username', 'micdrop-core' ),
				)
			);
			$this->set_widget_option(
				array(
					'field_type' => 'color',
					'name'       => 'author_color',
					'title'      => esc_html__( 'Author Color', 'micdrop-core' ),
				)
			);
		}

		public function render( $atts ) {
			$author_id = 1;
			if ( ! empty( $atts['author_username'] ) ) {
				$author = get_user_by( 'login', $atts['author_username'] );

				if ( ! empty( $author ) ) {
					$author_id = $author->ID;
				}
			}

			$author_link   = get_author_posts_url( $author_id );
			$author_bio    = get_the_author_meta( 'description', $author_id );
			$email_enabled = 'yes' === micdrop_core_get_post_value_through_levels( 'qodef_blog_single_enable_author_info_email' );
			$user_socials  = micdrop_core_get_author_social_networks( $author_id );
			?>
			<div class="widget qodef-author-info">
				<a itemprop="url" class="qodef-author-info-image" href="<?php echo esc_url( $author_link ); ?>">
					<?php echo get_avatar( $author_id, 138 ); ?>
				</a>
				<?php if ( ! empty( $author_bio ) ) { ?>
					<h5 class="qodef-author-info-name vcard author">
						<span class="qodef-m-author-label"><?php esc_html_e( 'by', 'micdrop-core' ); ?></span>
						<a itemprop="url" href="<?php echo esc_url( $author_link ); ?>">
							<span class="fn"><?php echo esc_html( get_the_author_meta( 'display_name', $author_id ) ); ?></span>
						</a>
					</h5>
					<?php if ( $email_enabled && is_email( get_the_author_meta( 'email' ) ) ) { ?>
						<p itemprop="email" class="qodef-m-email"><?php echo sanitize_email( get_the_author_meta( 'email' ) ); ?></p>
					<?php } ?>
					<p itemprop="description" class="qodef-author-info-description"><?php echo esc_html( $author_bio ); ?></p>
				<?php } ?>
				<?php if ( ! empty( $user_socials ) ) { ?>
					<div class="qodef-m-social-icons">
						<?php foreach ( $user_socials as $social ) { ?>
							<a itemprop="url" class="<?php echo esc_attr( $social['class'] ); ?>" href="<?php echo esc_url( $social['url'] ); ?>" target="_blank">
								<?php echo qode_framework_icons()->get_specific_icon_from_pack( $social['icon'], 'font-awesome' ); ?>
							</a>
						<?php } ?>
					</div>
				<?php } ?>
			</div>
			<?php
		}
	}
}
